define(['underscore', 'jquery', 'backbone', 'marionette', 'services/social', 'services/payments', 'services/file', 'controllers/quests', 'controllers/push-notifications', 'controllers/server', 'controllers/screens', 'controllers/menu', 'controllers/short-info', 'controllers/user-events', 'controllers/modal', 'controllers/tutorial', 'controllers/shop', 'fastclick', 'views/components/swipe-2-refresh', 'models/translation', 'models/patchedViews', 'models/level-access-config'], function(_, $, Backbone, Marionette, SocialService, PaymentsService, FileService, QuestsController, PushNotificationsController, ServerController, ScreensController, MenuController, ShortInfoController, EventsController, ModalController, TutorialController, ShopController, FastClick, Swipe2Refresh, Translations, PatchedViews, LevelAccessConfig) {
  var app;
  app = new Marionette.Application({
    regions: {
      'canvas': '#js-canvas',
      'menuRegion': '#js-menu',
      'shortInfoRegion': '#js-short-info',
      'modalRegion': '#js-modal-container'
    }
  });
  app.addInitializer(function(options) {
    var adjustConfig, getQueryParams, params, progress_bar, progress_info, progress_msg, progress_values, q_popup, ref, startLogin, transitionEvent, whichTransitionEvent;
    app.launch = true;
    app.userId = 0;
    app.config = options;
    app.version = options.version.value;
    app.translations = new Translations([], {
      app: app
    });
    app.patchedViews = new PatchedViews([], {
      app: app
    });
    app.patchedViews.fetch();
    setTimeout((function() {
      return $('#startup-loader').hide();
    }), 15000);
    window.__scrollPointerOffHover = null;
    window.addEventListener('scroll', function() {
      clearTimeout(window.__scrollPointerOffHover);
      if (!document.body.classList.contains('disable-hover')) {
        document.body.classList.add('disable-hover');
      }
      return window.__scrollPointerOffHover = setTimeout((function() {
        return document.body.classList.remove('disable-hover');
      }), 800);
    }, false);
    app.tr = function(variable, locale) {
      if (locale == null) {
        locale = null;
      }
      return app.translations.tr(variable, locale);
    };
    app.shortInfo = new ShortInfoController({
      app: app
    });
    app.modalDialog = new ModalController({
      app: app
    });
    app.screens = new ScreensController({
      app: app
    });
    app.server = new ServerController({
      app: app
    });
    app.menu = new MenuController({
      app: app
    });
    app.userEvents = new EventsController({
      app: app
    });
    app.pushNotifications = new PushNotificationsController({
      app: app
    });
    app.tutorial = new TutorialController({
      app: app
    });
    app.shop = new ShopController({
      app: app
    });
    app.quests = new QuestsController({
      app: app
    });
    app.levelAccessConfig = new LevelAccessConfig();
    app.levelAccessConfig.url = app.config.serverURLProtocol + '://' + app.config.serverURL + '/levels/level_access/get.json';
    app.levelAccessConfig.fetch();
    app.isAvailable = function(level, action) {
      return app.levelAccessConfig.isAvailable(level, action);
    };
    app.availableFrom = function(action) {
      return app.levelAccessConfig.availableFrom(action);
    };
    app.fileService = new FileService(app);
    app.socialService = new SocialService(app.config.social, app.config.serverURL, app.config.serverURLProtocol);
    app.paymentsService = new PaymentsService(app, app.config.payments, app.config.serverURL, app.config.serverURLProtocol);
    app.paymentsService.setPendingPurchaseCallbacks(function(data) {
      return app.screens.modal('common/success-popup', {
        msg: app.tr("Purchase completed"),
        currency: 'vgold',
        amount: data.amount
      });
    }, null);
    app.vent.on('auth:login', function() {
      return app.paymentsService.readyAll();
    });
    app.devicePlatform = app.detectPlatform();
    app.gaEnabled = false;
    if (app.config.googleAnalyticsEnabled) {
      app.gaEnabled = true;
      require(['ga'], function(ga) {
        var initGA;
        ga('require', 'ecommerce');
        app.gaEnabled = true;
        app.ga = ga;
        app.ga('create', app.config.googleAnalyticsTrackingCode, 'none');
        app.ga('set', 'checkProtocolTask', null);
        app.ga('set', 'checkStorageTask', null);
        if (app.config.serverURLProtocol === 'https') {
          app.ga('set', 'forceSSL', true);
        }
        app.ga('send', 'pageview');
        window.referrer = null;
        app.referrerString = "";
        initGA = function() {
          return app.ga = function(command, param, value) {
            var tax, taxAmount;
            if (command === 'set' && param === 'userId') {
              return window.analytics.setUserId(value);
            }
            if (command === 'send' && param === 'pageview') {
              return window.analytics.trackView(value.page, app.referrerString);
            }
            if (command === 'send' && param === 'event') {
              return window.analytics.trackEvent(arguments[2], app.referrerString, arguments[3], arguments[4], arguments[5]);
            }
            if (command === 'set' && param === 'dimension') {
              return window.analytics.addCustomDimension(value, arguments[3]);
            }
            if (command === 'ecommerce:addTransaction') {
              tax = (app.referrerString != null) && app.referrerString ? 0.65 : 0.3;
              taxAmount = param.revenue * tax;
              window.analytics.addTransaction(param.id, app.referrerString, param.revenue, taxAmount, 0, param.currency);
              return window.analytics.currency = param.currency;
            }
            if (command === 'ecommerce:addItem') {
              return window.analytics.addTransactionItem(param.id, param.name, param.sku, param.category, param.price, 1, window.analytics.currency);
            }
            return ga.apply(this, arguments);
          };
        };
        if (window.analytics != null) {
          window.analytics.debugMode();
          window.analytics.startTrackerWithId(app.config.googleAnalyticsTrackingCode);
          return initGA();
        } else {
          return app.ga = function(command, param, value) {
            if (command === 'set' && param === 'dimension') {
              return ga.apply(this, ['set', "dimension" + value, arguments[3]]);
            }
            return ga.apply(this, arguments);
          };
        }
      });
    }
    app.adjustEnabled = false;
    if (app.config.adjustEnabled && (typeof AdjustConfig !== "undefined" && AdjustConfig !== null)) {
      adjustConfig = new AdjustConfig(app.config.adjustApiKey, AdjustConfig.EnvironmentProduction);
      Adjust.create(adjustConfig);
      app.adjustEnabled = true;
      app.adjust = {
        Adjust: Adjust,
        AdjustEvent: AdjustEvent
      };
    }
    app.setUserId = function(userId) {
      app.userId = userId;
      if (app.config.googleAnalyticsEnabled && app.ga) {
        return app.ga('set', 'userId', app.userId);
      }
    };
    app.setUserRegistrationSource = function(userRegistrationSource) {
      if (window.applicationPreferences != null) {
        return window.applicationPreferences.get("referrer", function(value) {
          window.referrer = value;
          return app.referrerString = "my-scheme://content/?" + referrer;
        }, function(err) {
          app.referrerString = String(userRegistrationSource);
          return console.log("PREFERENCES ERROR", err);
        });
      } else {
        return app.referrerString = String(userRegistrationSource);
      }
    };
    getQueryParams = function(queryString) {
      var a, b, query;
      query = {};
      a = queryString.substr(1).split('&');
      b = a[0].split('=');
      query[decodeURIComponent(b[0])] = decodeURIComponent(b[1] || '');
      return query;
    };

    /*
    		This id debug hook to redirrect to specified screen right after the page is loaded.
    			localStorage.redirect = 'screen id' # to specify screen to be redirected to
    
    			delete localStorage.redirect # to reset
     */
    if ((app.config.locked != null) && app.config.locked) {
      app.screens.main('app_locked');
    } else if (app.config.debug && (localStorage.redirect != null)) {
      app.server.reauth({
        success: function(data) {
          app.userId = data.userId;
          app.menu.init();
          app.shortInfo.init();
          return app.screens.main(localStorage.redirect);
        },
        error: function() {
          return app.screens.main('login');
        }
      });
    } else if ((localStorage.auth != null) || (localStorage.auth_token != null)) {
      params = getQueryParams(window.location.search);
      if (params.user_id != null) {
        app.screens.main('auto_login', {
          user_id: params.user_id
        });
      } else {
        app.screens.main('auto_login');
      }
    } else {
      startLogin = function() {
        params = getQueryParams(window.location.search);
        if (params.user_id != null) {
          return app.screens.main('login', {
            user_id: params.user_id
          });
        } else {
          return app.screens.main('login');
        }
      };
      if (((ref = window.navigator) != null ? ref.globalization : void 0) != null) {
        window.navigator.globalization.getLocaleName(function(locale) {
          var localization;
          localization = (function() {
            switch (locale.value) {
              case "pl-PL":
                return "pol";
              case "ru-RU":
                return "rus";
              default:
                return "eng";
            }
          })();
          return app.translations.setLocaleAndFetch(localization, startLogin);
        }, function() {
          return app.translations.setLocaleAndFetch('eng', startLogin);
        });
      } else {
        app.translations.setLocaleAndFetch('eng', startLogin);
      }
    }
    Backbone.history.start();
    window.app = app;
    if (app.config.debug) {
      require.onResourceLoad = function(context, map) {
        if (map.id !== 'app' && map.id !== 'text') {
          return require.undef(map.id);
        }
      };
    }
    document.addEventListener("backbutton", (function(_this) {
      return function() {
        if (app.tutorial.isActive()) {
          navigator.Backbutton.goHome(function() {
            return console.log('success');
          }, function() {
            return console.log('fail');
          });
          return;
        }
        if (!$('body').hasClass('no-swipe')) {
          return _this.trigger("device:back");
        }
      };
    })(this));
    window.addEventListener("native.keyboardshow", (function(_this) {
      return function(event) {
        return _this.trigger("keyboard:show", event.keyboardHeight);
      };
    })(this));
    window.addEventListener("native.keyboardhide", (function(_this) {
      return function(event) {
        return _this.trigger("keyboard:hide");
      };
    })(this));
    this.listenTo(app.server, 'app:locked', (function(_this) {
      return function() {
        return app.screens.main('app_locked');
      };
    })(this));
    this.listenTo(app.server, 'app:need_reauth', (function(_this) {
      return function() {
        return app.screens.main('app_need_reauth');
      };
    })(this));
    this.listenTo(app.server, 'app:quick_reg_lock', (function(_this) {
      return function() {
        return app.screens.main('quick_reg_lock');
      };
    })(this));
    FastClick.attach(document.body);
    app.loaderElement = document.getElementById('ajax-loader');
    app.showLoader = function() {
      return app.loaderElement.style.display = 'block';
    };
    app.hideLoader = function() {
      var currentTime;
      if (app.config.debug) {
        currentTime = new Date();
        console.log('Loading timer: ' + (currentTime.getTime() - app.timer.getTime()) + ' ms');
      }
      return app.loaderElement.style.display = 'none';
    };
    app.menuElement = document.getElementById('js-menu');
    app.canvasElement = document.getElementById('js-canvas');
    app.resetLayoutSizes = function() {
      app.menuElement.style.height = (window.innerHeight - 76) + 'px';
      app.canvasElement.style.height = (window.innerHeight - 76) + 'px';
      if ($('#js-canvas').width() > 625) {
        $('#js-canvas').addClass('tablet');
      } else {
        $('#js-canvas').removeClass('tablet');
      }
      return app.vent.trigger('layout:resize');
    };
    app.resetLayoutSizes();
    window.addEventListener('resize', app.resetLayoutSizes);
    app.questsProgress = document.getElementById('quests-progress');
    progress_msg = document.getElementById('progress-msg');
    progress_info = document.getElementById('progress-info');
    progress_values = document.getElementById('progress-values');
    progress_bar = document.getElementById('progress-bar');
    q_popup = document.getElementById('q-popup');
    whichTransitionEvent = function() {
      var el, t, transitions;
      el = document.createElement('div');
      transitions = {
        'transition': 'transitionend',
        'OTransition': 'oTransitionEnd',
        'MozTransition': 'transitionend',
        'WebkitTransition': 'webkitTransitionEnd'
      };
      for (t in transitions) {
        if (el.style[t] != null) {
          return transitions[t];
        }
      }
    };
    transitionEvent = whichTransitionEvent();
    app.showProgress = function(data) {
      var progress_bar_width;
      progress_msg.innerHTML = data.title;
      progress_info.innerHTML = data.subcondition;
      if (!data.prev_value) {
        data.prev_value = 0;
      }
      if (data.need_value > 0) {
        progress_values.innerHTML = data.prev_value + ' / ' + data.need_value;
      } else {
        progress_values.innerHTML = data.prev_value;
      }
      progress_bar_width = 0;
      if (data.prev_value > 0) {
        progress_bar_width = data.prev_value / data.need_value * 100;
      }
      progress_bar.setAttribute("style", "width: " + progress_bar_width + "%;");
      q_popup.addEventListener(transitionEvent, function() {
        progress_bar.style.transition = 'width 1s';
        progress_bar.setAttribute("style", "-webkit-transition: width 1s;");
        if (data.current_value >= data.need_value) {
          progress_bar_width = 100;
        } else {
          progress_bar_width = data.current_value / data.need_value * 100;
        }
        progress_bar.setAttribute("style", "width: " + progress_bar_width + "%;");
        if (data.need_value > 0) {
          progress_values.innerHTML = data.current_value + ' / ' + data.need_value;
        } else {
          progress_values.innerHTML = data.current_value;
        }
        return setTimeout(app.hideProgress, 1500);
      });
      return q_popup.setAttribute("style", "transform: translate(-50%, 0);");
    };
    app.hideProgress = function() {
      q_popup.addEventListener(transitionEvent, function() {
        progress_bar.style.transition = 'none';
        return progress_bar.setAttribute("style", "-webkit-transition: none;");
      });
      return q_popup.setAttribute("style", "transform: translate(-50%, -150px);");
    };
    app.__s2r = new Swipe2Refresh(document.getElementById('js-short-info'), function() {
      return app.vent.trigger('swipe:reload');
    });
    return app.translations.on('sync', function() {
      var ref1, ref2;
      if (((ref1 = app.menu) != null ? ref1.view : void 0) != null) {
        app.menu.view.render();
      }
      if (((ref2 = app.shortInfo) != null ? ref2.view : void 0) != null) {
        return app.shortInfo.view.render();
      }
    });
  });
  app.scrollTop = function(el, num) {
    var overflow, overflowS, overflowY;
    if (!el) {
      return;
    }
    if (window.isCordova) {
      overflow = el.style.overflow;
      overflowY = el.style['overflow-y'];
      overflowS = el.style['-webkit-overflow-scrolling'];
      el.style.overflow = 'hidden !important';
      el.style['overflow-y'] = 'hidden !important';
      el.style['-webkit-overflow-scrolling'] = 'auto !important';
      el.scrollTop = num;
      el.style.overflow = overflow;
      el.style['overflow-y'] = overflowY;
      el.style['-webkit-overflow-scrolling'] = overflowS;
    } else {
      el.scrollTop = num;
    }
  };
  app.scrollElToCenter = function(wrapper, el) {
    var elTop, offset;
    if (wrapper && el) {
      elTop = (el.getBoundingClientRect()).top;
      offset = (el.getBoundingClientRect()).top - ((window.innerHeight + wrapper.offsetTop) - el.clientHeight) / 2;
      return app.scrollTop(wrapper, wrapper.scrollTop + offset);
    }
  };
  app.getVersion = function() {
    return app.version;
  };
  app.getDeviceOs = function() {
    var os;
    try {
      os = device.platform.toLowerCase();
    } catch (_error) {
      os = 'unknown';
    }
    return os;
  };
  app.detectPlatform = function() {
    var ua;
    if ((typeof device !== "undefined" && device !== null) && device.platform) {
      return device.platform.toLowerCase();
    }
    ua = navigator.userAgent;
    if (ua.match(/Android/i)) {
      return 'android';
    }
    if (ua.match(/Windows Phone|WPDesktop/i)) {
      return 'windows phone';
    }
    if (ua.match(/iPad|iPod|iPhone/)) {
      return 'ios';
    }
    return 'browser';
  };
  return app;
});
