var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['jquery', 'marionette'], function(jquery, Marionette) {
  var ServerController, _buildUrlQuery;
  _buildUrlQuery = function(data) {
    var name, parts, value;
    if (!data) {
      return '';
    }
    parts = [];
    for (name in data) {
      value = data[name];
      if (value !== null && value !== '') {
        parts.push(encodeURIComponent(name) + "=" + encodeURIComponent(value));
      }
    }
    return (parts.length ? parts.join('&') : '');
  };
  ServerController = (function(superClass) {
    extend(ServerController, superClass);

    function ServerController() {
      this._ajax = bind(this._ajax, this);
      this.ajax = bind(this.ajax, this);
      return ServerController.__super__.constructor.apply(this, arguments);
    }

    ServerController.prototype.defaultCacheValidityInMs = 60 * 1000;

    ServerController.prototype.activeRequests = {};

    ServerController.prototype.cache = {};

    ServerController.prototype.cachePointerToUrl = {};

    ServerController.prototype.reload = function() {
      require.undef('controllers/server');
      return require(['controllers/server'], (function(_this) {
        return function(ServerController) {
          if (_this.app.config.debug) {
            console.log("reload server controller");
          }
          return _this.app.server = new ServerController({
            app: _this.app
          });
        };
      })(this));
    };

    ServerController.prototype.required = function(options, fields) {
      if (options == null) {
        throw new Error('options should be specified');
      }
      return fields.forEach(function(field) {
        if (!((options[field] != null) && options[field] !== '')) {
          throw new Error("options." + field + " should be specified");
        }
      });
    };

    ServerController.prototype.ajax = function(options) {
      var deferred;
      deferred = this._ajax(options);
      if (options.success != null) {
        deferred.done(function(data) {
          return options.success(data.json, data.xhr);
        });
      }
      if (options.error != null) {
        deferred.fail(function(data) {
          return options.error(data.err, data.xhr);
        });
      }
      return deferred;
    };

    ServerController.prototype._ajax = function(options) {
      var data, deferred, headerName, headerValue, isFormData, method, ref, ref1, ref2, self, url, xhr;
      method = options.method || 'GET';
      url = this.app.config.serverURLProtocol + '://' + this.app.config.serverURL + options.url;
      self = this;
      if (options.method === 'GET' && (this.activeRequests[options.url] != null)) {
        return this.activeRequests[options.url];
      }
      deferred = $.Deferred();
      if (url in this.cache === false) {
        this.cache[url] = {
          _valid: false,
          date: 0,
          lastRes: null,
          isValid: function() {
            var ref;
            return this._valid && (Date.now() - this.date) < ((ref = options.cacheValidityInMs) != null ? ref : self.defaultCacheValidityInMs);
          },
          invalidate: function(err) {
            this._valid = false;
            return this.lastRes = err;
          },
          set: function(data) {
            this._valid = true;
            this.date = Date.now();
            return this.lastRes = data;
          }
        };
        this.cachePointerToUrl[options.pointer] = url;
      }
      if ((((options.cache == null) && !options.required) || options.cache === true) && ((ref = this.cache[url]) != null ? ref.isValid() : void 0)) {
        if (this.app.config.debug) {
          console.log("Info: return cached response for " + url);
        }
        if (options.success != null) {
          setTimeout(((function(_this) {
            return function() {
              return deferred.resolve(_this.cache[url].lastRes);
            };
          })(this)), 0);
        } else if (this.app.config.debug) {
          console.log((ref1 = this.cache[url]) != null ? ref1.lastRes : void 0);
        }
        return deferred;
      }
      if (!options.noRequestGrouping) {
        this.activeRequests[options.url] = deferred;
        deferred.always((function(_this) {
          return function() {
            return delete _this.activeRequests[options.url];
          };
        })(this));
      }
      xhr = new XMLHttpRequest();
      xhr.open(method, url, true);
      data = null;
      isFormData = false;
      if (options.data) {
        if (options.data.toString() === '[object FormData]') {
          isFormData = true;
          if (this.app.config.debug) {
            console.log("FormData sended to '" + url + "'");
          }
          data = options.data;
        } else {
          if (this.app.config.debug) {
            console.log("data '" + (JSON.stringify(options.data)) + " sended to '" + url + "'");
          }
          data = $.param(options.data);
        }
      }
      if (options.headers != null) {
        ref2 = options.headers;
        for (headerName in ref2) {
          headerValue = ref2[headerName];
          xhr.setRequestHeader(headerName, headerValue);
        }
      }
      if (!isFormData) {
        xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
      }
      xhr.withCredentials = true;
      xhr.onreadystatechange = (function(_this) {
        return function() {
          var err, errorObject, i, isServerError, json, len, pointer, ref3, showLoader, successResult, url2;
          successResult = null;
          if (xhr.readyState === 4) {
            if (xhr.getResponseHeader('Content-Type') === '' || xhr.getResponseHeader('Content-Type') === null) {
              isServerError = true;
            } else if (xhr.getResponseHeader('Content-Type').indexOf("application/json") === -1) {
              isServerError = true;
            }
            if (isServerError) {
              errorObject = {
                error: 1,
                isConnectionError: true,
                setFlash: {
                  0: {
                    msg: app.tr('Server connection error')
                  }
                }
              };
              return deferred.reject({
                xhr: xhr,
                err: errorObject
              });
            }
            try {
              json = xhr.responseText !== '' ? JSON.parse(xhr.responseText) : null;
            } catch (_error) {
              err = _error;
              return deferred.reject({
                err: 'JSON parse error',
                xhr: xhr
              });
            }
            if (xhr.status === 200 || xhr.status === 0) {
              try {
                self.cache[url].set({
                  json: json,
                  xhr: xhr
                });
                if (options.invalidate != null) {
                  ref3 = options.invalidate;
                  for (i = 0, len = ref3.length; i < len; i++) {
                    pointer = ref3[i];
                    url2 = self.cachePointerToUrl[pointer];
                    if (url2 in self.cache) {
                      self.cache[url2].invalidate();
                      if (_this.app.config.debug) {
                        console.log("Info: invalidate cache for " + url2);
                      }
                    }
                  }
                  if (!options.doesNotReload) {
                    showLoader = true;
                    if (options.showLoader != null) {
                      showLoader = options.showLoader;
                    }
                    self.app.screens.current.checkDataCacheAndReload(showLoader);
                  }
                }
                return deferred.resolve({
                  json: json,
                  xhr: xhr
                });
              } catch (_error) {
                err = _error;
                if (app.config.debug) {
                  return console.log(err);
                }
              }
            } else {
              try {
                self.cache[url].invalidate(json);
                return deferred.reject({
                  err: json,
                  xhr: xhr
                });
              } catch (_error) {
                err = _error;
                if (app.config.debug) {
                  return console.log(err);
                }
              }
            }
          }
        };
      })(this);
      if (data) {
        xhr.send(data);
      } else {
        xhr.send();
      }
      return deferred;
    };

    ServerController.prototype.createRequest = function(description, pointer) {
      var fun;
      fun = (function(_this) {
        return function(options) {
          var actionName, err, os, query, ref, version, vpageUrl;
          if (_this.app.config.googleAnalyticsEnabled && _this.app.ga) {
            if (!description.googleAnalyticsIgnore && description.method === 'POST') {
              actionName = pointer;
              if (description.vpageUrl) {
                vpageUrl = description.vpageUrl(options);
              } else {
                vpageUrl = '/api/' + actionName;
              }
              _this.app.ga('send', 'pageview', {
                page: vpageUrl,
                title: ''
              });
            }
          }
          if (description.required != null) {
            _this.required(options, description.required);
          } else {
            options = options != null ? options : {};
          }
          query = {
            method: (ref = description.method) != null ? ref : 'GET',
            cache: description.cache,
            cacheValidityInMs: description.cacheValidityInMs,
            invalidate: description.invalidate,
            required: description.required,
            doesNotReload: options.doesNotReload,
            showLoader: description.showLoader,
            pointer: pointer
          };
          query.reauth = false;
          query.success = function(data, xhr) {
            if (data.error === 1) {
              query.error(data, xhr);
            }
            if ((data.error != null) && (parseInt(data.error) === 403) && (!query.reauth)) {
              if (_this.app.config.debug) {
                console.log('Info: reauth');
              }
              query.reauth = true;
              if (options.reauth != null) {
                options.reauth();
              }
              _this.reauth({
                success: function() {
                  return _this.ajax(query);
                },
                error: function() {
                  return query.error;
                }
              });
              return;
            }
            if (data.setFlash != null) {
              _.forEach(data.setFlash, function(msg) {
                if (app.config.debug) {
                  return console.log(msg.msg);
                }
              });
            }
            return setTimeout((function() {
              var err;
              if ((description.after != null) && !options.skipAfter) {
                try {
                  description.after(options, data);
                } catch (_error) {
                  err = _error;
                  if (app.config.debug) {
                    console.log(err);
                  }
                }
              }
              if (options.success != null) {
                return options.success(data, false);
              } else if (_this.app.config.debug) {
                return console.log(data);
              }
            }), 0);
          };
          query.error = function(err, xhr) {
            if (xhr && (xhr.status === 403) && err.setFlash[0].msg !== "not_last_session" && query.reauth && (options.reauth !== true)) {
              app.screens.main('app_ban');
              return;
            }
            if (xhr && (xhr.status === 403) && err.setFlash[0].msg === "not_last_session") {
              if (_this.app.config.debug) {
                console.log('Info: need reauth');
              }
              _this.trigger('app:need_reauth');
              return;
            }
            if (xhr && (xhr.status === 403) && (!query.reauth) && (options.reauth !== false)) {
              if (_this.app.config.debug) {
                console.log('Info: reauth');
              }
              query.reauth = true;
              if (options.reauth != null) {
                options.reauth();
              }
              _this.reauth({
                success: function() {
                  return _this.ajax(query);
                },
                error: function() {
                  return query.error;
                }
              });
              return;
            }
            if (xhr && (xhr.status === 402 || xhr.status === 503 || xhr.status === 521)) {
              if (pointer !== 'user.node.longpoll') {
                _this.trigger('app:locked');
              }
              return;
            }
            if (xhr && err.setFlash && err.setFlash[0].msg === "quick_reg_lock") {
              return _this.trigger('app:quick_reg_lock');
            }
            if (options.error != null) {
              options.error(err, xhr);
            } else if (_this.app.config.debug) {
              console.log([query, arguments]);
            }
            if ((options.error == null) && (err.setFlash != null)) {
              if (pointer !== 'user.node.longpoll') {
                return _.forEach(err.setFlash, function(msg) {
                  if (app.config.debug) {
                    console.log('error in response: ', msg.msg);
                  }
                  return app.screens.modal('common/info-popup', {
                    msg: msg.msg
                  });
                });
              }
            }
          };
          if (description.before != null) {
            try {
              description.before(options);
            } catch (_error) {
              err = _error;
              query.error(err);
              return;
            }
          }
          if ((description.noRequestGrouping != null) && description.noRequestGrouping) {
            query.noRequestGrouping = true;
          } else {
            query.noRequestGrouping = false;
          }
          if (typeof description.url === 'string') {
            query.url = description.url;
          } else {
            query.url = description.url(options);
          }
          os = app.getDeviceOs();
          version = app.getVersion();
          if (query.url.indexOf('?') === -1) {
            query.url += '?';
          } else {
            query.url += '&';
          }
          query.url += "os=" + os + "&v=" + version;
          if (description.data) {
            query.data = description.data(options);
          }
          if (description.headers) {
            query.headers = description.headers;
          }
          return _this.ajax(query);
        };
      })(this);
      return fun;
    };

    ServerController.prototype.initialize = function(arg) {
      var description, i, key, len, pointer, ref, ref1, ref2, root, splittedPointer;
      this.app = arg.app;
      this.defaultCacheValidityInMs = (ref = this.app.config.defaultCacheValidityInMs) != null ? ref : this.defaultCacheValidityInMs;
      ref1 = this.requests;
      for (pointer in ref1) {
        description = ref1[pointer];
        root = this;
        splittedPointer = pointer.split('.');
        ref2 = splittedPointer.slice(0, splittedPointer.length - 1);
        for (i = 0, len = ref2.length; i < len; i++) {
          key = ref2[i];
          if (root[key] == null) {
            root[key] = {};
          }
          root = root[key];
        }
        if (typeof description === 'string') {
          description = {
            url: description
          };
        } else if (description.url == null) {
          throw new Error("Error: URL not specified for " + pointer);
        }
        root[splittedPointer[splittedPointer.length - 1]] = this.createRequest(description, pointer);
        this[pointer] = this.createRequest(description, pointer);
      }
      if (this.app.config.debug) {
        return this.checkPointersExistance();
      }
    };

    ServerController.prototype.checkPointersExistance = function() {
      var description, fun, invalidatePointer, pointer, ref, results;
      ref = this.requests;
      results = [];
      for (pointer in ref) {
        description = ref[pointer];
        if (description.invalidate != null) {
          results.push((function() {
            var i, len, ref1, results1;
            ref1 = description.invalidate;
            results1 = [];
            for (i = 0, len = ref1.length; i < len; i++) {
              invalidatePointer = ref1[i];
              fun = this[invalidatePointer];
              if ((fun == null) || typeof fun !== 'function') {
                if (app.config.debug) {
                  results1.push(console.error("Error: undefined pointer " + invalidatePointer + " in app.server.requests." + pointer + ".invalidate"));
                } else {
                  results1.push(void 0);
                }
              } else {
                results1.push(void 0);
              }
            }
            return results1;
          }).call(this));
        } else {
          results.push(void 0);
        }
      }
      return results;
    };

    ServerController.prototype.invalidateAllCache = function() {
      var results, url;
      results = [];
      for (url in this.cache) {
        results.push(this.cache[url].invalidate());
      }
      return results;
    };

    ServerController.prototype.invalidateCache = function(pointer) {
      return app.server.cache[app.server.cachePointerToUrl[pointer]].invalidate();
    };


    /*
    			Description of all requests.
    			Each request is accessible by app.server.#{key} after initialization.
    			Request description may be in 2 forms:
    				- url only, supposed that it's GET request without parameters
    				- hash
    
    			Hash description fields are:
    				- cache - does responce caching, true by default if doesn't have required field
    				- cacheValidityInMs - how long cache is "safe", after that interval cache is invalide
    				- before hook - called before request, if throw, error goes to options.error, may mutate options
    				- after hook - called after request, if throw, error goes to options.error, may mutate options
    				- method - by default it's 'GET'
    				- url - string or function which takes passed to request options and return url
    			_cost	- required - array of fields names that are required
    				- data - function that takes options passed to request and return data hash
    
    			Also in debug mode, each request function has field .lastRes with last responce.
     */

    ServerController.prototype.requests = {
      auth: {
        cache: false,
        before: function(options) {
          app.server.invalidateAllCache();
          return localStorage.auth = JSON.stringify({
            login: options.login,
            password: options.password
          });
        },
        after: function(options, data) {
          if (app.translations.getLocale() !== data.locale) {
            return app.translations.setLocaleAndFetch(data.locale, function() {
              var ref, ref1;
              if ((typeof app !== "undefined" && app !== null ? (ref = app.menu) != null ? ref.view : void 0 : void 0) != null) {
                app.menu.view.render();
              }
              if ((typeof app !== "undefined" && app !== null ? (ref1 = app.shortInfo) != null ? ref1.view : void 0 : void 0) != null) {
                return app.shortInfo.view.render();
              }
            });
          }
        },
        method: 'POST',
        url: '/users/app_auth.json',
        data: function(arg) {
          var login, password;
          login = arg.login, password = arg.password;
          return {
            'data[User][username]': login,
            'data[User][password]': password,
            'token': app.config.version.token
          };
        }
      },
      auth_token: {
        cache: false,
        before: function(options) {
          return app.server.invalidateAllCache();
        },
        after: function(options, data) {
          if (app.translations.getLocale() !== data.locale) {
            return app.translations.setLocaleAndFetch(data.locale, function() {
              var ref, ref1;
              if ((typeof app !== "undefined" && app !== null ? (ref = app.menu) != null ? ref.view : void 0 : void 0) != null) {
                app.menu.view.render();
              }
              if ((typeof app !== "undefined" && app !== null ? (ref1 = app.shortInfo) != null ? ref1.view : void 0 : void 0) != null) {
                return app.shortInfo.view.render();
              }
            });
          }
        },
        method: 'POST',
        url: '/users/app_auth.json',
        data: function(arg) {
          var auth_token;
          auth_token = arg.auth_token;
          return {
            'auth_token': auth_token,
            'token': app.config.version.token
          };
        }
      },
      'quickStart': {
        cache: false,
        method: 'POST',
        url: "/users/quick_reg.json",
        data: function(arg) {
          var device_uuid;
          device_uuid = arg.device_uuid;
          return {
            'data[device_uuid]': device_uuid
          };
        }
      },
      quick_reg_unlock: {
        cache: false,
        url: "/users/quick_reg_unlock.json",
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'reauth': {
        cache: false,
        before: function(options) {
          var login, password, ref;
          if (localStorage.auth != null) {
            ref = JSON.parse(localStorage.auth), login = ref.login, password = ref.password;
            options.login = login;
            return options.password = password;
          } else {
            throw "Error: Can't reauth to " + login + " account";
          }
        },
        after: function(options, data) {
          return app.setUserId(data.userId);
        },
        method: 'POST',
        url: '/users/app_auth.json',
        data: function(arg) {
          var login, password;
          login = arg.login, password = arg.password;
          return {
            'data[User][username]': login,
            'data[User][password]': password,
            'token': app.config.version.token
          };
        }
      },
      'logout': {
        before: function() {
          app.server.invalidateAllCache();
          delete localStorage.auth;
          return localStorage.removeItem("auth");
        },
        cache: false,
        method: 'POST',
        url: '/users/logout.json'
      },
      'user.registrationInfo': {
        url: '/users/register_info.json',
        cacheValidityInMs: 6000 * 1000
      },
      'user.registration': {
        before: function() {
          app.showLoader();
          return $('.js-back').hide();
        },
        after: function() {
          app.hideLoader();
          return $('.js-back').show();
        },
        url: '/users/register.json',
        method: 'POST',
        data: function(arg) {
          var avatar, city_id, email, passwd, passwd_confirm, ref_id, sex, username;
          username = arg.username, email = arg.email, passwd = arg.passwd, passwd_confirm = arg.passwd_confirm, avatar = arg.avatar, sex = arg.sex, city_id = arg.city_id, ref_id = arg.ref_id;
          return {
            'data[User][username]': username,
            'data[User][email]': email,
            'data[User][passwd]': passwd,
            'data[User][passwd_confirm]': passwd_confirm,
            'data[User][avatar]': avatar,
            'data[User][sex]': sex,
            'data[User][city_id]': city_id,
            'data[User][ref_id]': ref_id,
            'data[User][agreement]': 1
          };
        }
      },
      'user.passwordRecovery': {
        url: '/users/forgot_password.json',
        cache: false,
        method: 'POST',
        data: function(arg) {
          var email;
          email = arg.email;
          return {
            'data[User][email]': email
          };
        }
      },
      'user.payments_count': {
        url: '/users/payments_count.json',
        cache: false,
        method: 'GET'
      },

      /*
      				Social
       */
      'social.getLoginUrls': {
        cache: false,
        method: 'GET',
        url: '/social/api/getLoginUrl.json'
      },
      'social.getLinkedAccounts': {
        cache: false,
        url: '/social/api/getLinkedAccounts.json',
        method: 'GET'
      },
      'social.register': {
        cache: false,
        url: '/social/api/register.json',
        data: function(arg) {
          var provider, socialUser, token, user;
          provider = arg.provider, user = arg.user, token = arg.token, socialUser = arg.socialUser;
          return {
            'data[User]': user,
            'data[token]': token,
            'data[socialUser]': socialUser,
            'data[provider]': provider
          };
        },
        method: 'POST'
      },
      'social.auth': {
        cache: false,
        url: '/social/api/auth.json',
        data: function(arg) {
          var provider, token, userId;
          provider = arg.provider, userId = arg.userId, token = arg.token;
          return {
            'data[token]': token,
            'data[user_id]': userId,
            'data[provider]': provider
          };
        },
        method: 'POST'
      },
      'social.linkAccount': {
        cache: false,
        url: '/social/api/linkAccount.json',
        data: function(arg) {
          var provider, socialUser, token;
          provider = arg.provider, socialUser = arg.socialUser, token = arg.token;
          return {
            'data[token]': token,
            'data[socialUser]': socialUser,
            'data[provider]': provider
          };
        },
        method: 'POST'
      },
      'translations': {
        url: function(arg) {
          var locale;
          locale = arg.locale;
          if (locale != null) {
            return "/translations/get/" + locale + ".json";
          } else {
            return "/translations/get.json";
          }
        }
      },
      'translations.rules': {
        cache: false,
        url: function(arg) {
          var locale;
          locale = arg.locale;
          if (locale != null) {
            return "/translations/getRulesPage/" + locale + ".json";
          } else {
            return "/translations/getRulesPage.json";
          }
        }
      },
      'translations.agreement': {
        cache: false,
        url: function(arg) {
          var locale;
          locale = arg.locale;
          if (locale != null) {
            return "/translations/getAgreementPage/" + locale + ".json";
          } else {
            return "/translations/getAgreementPage.json";
          }
        }
      },
      'user.startPushNotifications': {
        url: '/users/start_push_notifications.json',
        cache: false,
        method: 'POST',
        data: function(arg) {
          var device_platform, device_token;
          device_platform = arg.device_platform, device_token = arg.device_token;
          return {
            'data[User][device_platform]': device_platform,
            'data[User][device_token]': device_token
          };
        }
      },
      'user.saveUtcOffset': {
        url: '/users/save_utcOffset.json',
        cache: false,
        method: 'POST',
        data: function(arg) {
          var utcOffset;
          utcOffset = arg.utcOffset;
          return {
            'data[User][utc_offset]': utcOffset
          };
        }
      },

      /*
      				User
       */
      'user.info': {
        cache: false,
        url: '/users/infos.json'
      },
      'user.info.short': {
        cacheValidityInMs: 5 * 1000,
        url: '/users/short_infos.json'
      },
      'user.notification_badges': {
        cache: false,
        url: '/users/notification_badges.json'
      },
      'user.menu.planks': {
        cache: true,
        url: '/users/menu_planks.json'
      },
      'user.notificationSettings': {
        cache: false,
        url: '/users/notification_settings.json'
      },
      'user.setNotificationSettings': {
        cache: false,
        url: '/users/notification_settings.json',
        method: 'POST',
        data: function(arg) {
          var settings;
          settings = arg.settings;
          return {
            'data[settings]': settings
          };
        }
      },
      'user.profile': {
        cache: false,
        required: ['userId'],
        url: function(arg) {
          var userId;
          userId = arg.userId;
          return "/users/short_infos/" + userId + ".json";
        }
      },
      'user.profile.equippedItems': {
        cache: false,
        required: ['userId'],
        url: function(arg) {
          var userId;
          userId = arg.userId;
          return "/user_items/equipped/" + userId + ".json";
        }
      },
      'user.info.profession': {
        url: '/users/profession.json'
      },
      'user.info.sport': {
        cache: false,
        url: '/users/sport.json'
      },
      'user.status': {
        url: '/users/get_user_social_status.json'
      },
      'user.blocks': {
        url: '/users/blocks.json',
        cache: true
      },
      'user.updateEnergyTrigger': {
        cache: false,
        url: '/users/updateEnergyTrigger.json',
        method: 'POST',
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'user.levelUp': {
        cache: false,
        url: '/levels/user_bonuses/get.json',
        method: 'POST'
      },
      'user.registrationBonus': {
        cache: false,
        url: '/partner_registration/user_bonuses/get.json',
        method: 'POST'
      },
      'user.addRegistrationBonus': {
        cache: false,
        url: '/partner_registration/user_bonuses/add.json',
        method: 'POST',
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'user.levelUp.getAdditionBonuses': {
        cache: false,
        required: ['bonusId'],
        method: 'POST',
        url: '/levels/user_bonuses/add.json',
        data: function(arg) {
          var bonusId;
          bonusId = arg.bonusId;
          return {
            'data[UserBonus][bonus_id]': bonusId
          };
        }
      },
      'user.checkEvents': {
        cache: false,
        url: '/users/check.json'
      },
      'user.node.longpoll': {
        cache: false,
        reauth: false,
        googleAnalyticsIgnore: true,
        noRequestGrouping: true,
        url: function() {
          return "/longpoll?lastTime=0";
        }
      },
      'user.email': {
        cache: false,
        url: '/users/get_email.json'
      },
      'user.changeEmail': {
        url: '/users/change_email.json',
        cache: false,
        method: 'POST',
        data: function(arg) {
          var email;
          email = arg.email;
          return {
            'data[User][email]': email
          };
        }
      },
      'user.changePassword': {
        url: '/users/change_password.json',
        cache: false,
        method: 'POST',
        data: function(arg) {
          var old_password, passwd, passwd_confirm;
          passwd = arg.passwd, passwd_confirm = arg.passwd_confirm, old_password = arg.old_password;
          return {
            'data[User][passwd]': passwd,
            'data[User][passwd_confirm]': passwd_confirm,
            'data[User][old_password]': old_password
          };
        }
      },
      'user.usernameChangeInfo': {
        cache: false,
        url: '/users/get_username_change_info.json'
      },
      'user.changeUsername': {
        url: '/users/change_nickname.json',
        cache: false,
        invalidate: ['user.info'],
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var username;
          username = arg.username;
          return {
            'data[User][username]': username
          };
        },
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'user.changeAvatarPrice': {
        cache: false,
        url: '/users/get_avatar_change_price.json'
      },
      'user.changeAvatar': {
        url: '/users/change_avatar.json',
        cache: false,
        invalidate: ['user.info'],
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var avatar, sex;
          avatar = arg.avatar, sex = arg.sex;
          return {
            'data[User][avatar]': avatar,
            'data[User][sex]': sex
          };
        },
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'user.languages': {
        url: '/users/get_localeList.json'
      },
      'user.setLanguage': {
        url: '/users/change_user_localization.json',
        cache: false,
        invalidate: ['user.info', 'user.info.short'],
        method: 'POST',
        data: function(arg) {
          var localization;
          localization = arg.localization;
          return {
            'data[User][localization]': localization
          };
        }
      },
      'user.get_referrals': {
        url: '/users/get_referrals.json',
        cacheValidityInMs: 300 * 1000
      },
      'user.get_referrals_share_data': {
        cache: true,
        url: '/users/get_referrals_share_data.json'
      },
      'user.search': {
        cache: false,
        required: ['page'],
        url: function(arg) {
          var name, onlineOnly, page;
          page = arg.page, name = arg.name, onlineOnly = arg.onlineOnly;
          return "/users/search.json?page=" + (page || 1) + "&name=" + (name || '-') + (onlineOnly ? '&online=1' : '');
        }
      },
      'user.redeem_code': {
        cache: false,
        invalidate: ['user.info.short'],
        required: ['code'],
        url: "/users/redeem_code.json",
        method: 'POST',
        data: function(arg) {
          var code;
          code = arg.code;
          return {
            'data[RedeemCode][code]': code
          };
        },
        after: function() {
          return app.shortInfo.view.reload();
        }
      },
      'user.take_tutorial': {
        cache: false,
        url: "/users/take_tutorial.json",
        method: "GET"
      },
      'friends.list': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var name;
          name = arg.name;
          return "/user_friends/index.json?name=" + (name || '-');
        }
      },
      'friends.search': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var name, page;
          name = arg.name, page = arg.page;
          return "/user_friends/search.json?page=" + (page || 1) + "&name=" + (name || '-');
        }
      },
      'friends.search_social': {
        cache: false,
        method: 'POST',
        url: function() {
          return "/user_friends/search_social.json";
        },
        vpageUrl: function(arg) {
          var provider;
          provider = arg.provider;
          return "/api/user_friends/search_social/" + provider;
        },
        data: function(arg) {
          var friendIds, provider;
          provider = arg.provider, friendIds = arg.friendIds;
          return {
            'data[provider]': provider,
            'data[friendIds]': friendIds
          };
        }
      },
      'friends.requests': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var name, type;
          type = arg.type, name = arg.name;
          return "/user_friends/requests.json?type=" + (type || 'all') + "&name=" + (name || '-');
        }
      },
      'friends.requests_count': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var type;
          type = arg.type;
          return "/user_friends/requests_count.json?type=" + (type || 'to');
        }
      },
      'friends.remove_friend': {
        cache: false,
        required: ['friendId'],
        method: 'POST',
        url: '/user_friends/remove_friend.json',
        data: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return {
            'data[UserFriend][friend_id]': friendId
          };
        },
        vpageUrl: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return "/api/user_friends/remove_friend/" + friendId;
        }
      },
      'friends.add_request': {
        cache: false,
        required: ['friendId'],
        method: 'POST',
        url: '/user_friends/add_request.json',
        data: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return {
            'data[UserFriend][friend_id]': friendId
          };
        },
        vpageUrl: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return "/api/user_friends/add_request/" + friendId;
        }
      },
      'friends.accept_request': {
        cache: false,
        invalidate: ['user.notification_badges'],
        required: ['friendId'],
        method: 'POST',
        url: '/user_friends/accept_request.json',
        data: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return {
            'data[UserFriend][friend_id]': friendId
          };
        },
        vpageUrl: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return "/api/user_friends/accept_request/" + friendId;
        },
        after: function() {
          return app.menu.view.reload();
        }
      },
      'friends.reject_request': {
        cache: false,
        required: ['friendId'],
        method: 'POST',
        url: '/user_friends/reject_request.json',
        data: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return {
            'data[UserFriend][friend_id]': friendId
          };
        },
        vpageUrl: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return "/api/user_friends/reject_request/" + friendId;
        }
      },
      'friends.revoke_request': {
        cache: false,
        required: ['friendId'],
        method: 'POST',
        url: '/user_friends/revoke_request.json',
        data: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return {
            'data[UserFriend][friend_id]': friendId
          };
        },
        vpageUrl: function(arg) {
          var friendId;
          friendId = arg.friendId;
          return "/api/user_friends/revoke_request/" + friendId;
        }
      },
      'bonus.info': {
        required: ['type', 'id'],
        cacheValidityInMs: 300 * 1000,
        url: function(arg) {
          var id, type;
          type = arg.type, id = arg.id;
          return "/levels/user_bonuses/info/" + type + "/" + id + ".json";
        }
      },
      'fightPoints.info': {
        cache: false,
        url: "/user_fight_skills/fight_skill_inhabitant.json"
      },
      'fightPoints.upLevel': {
        cache: false,
        required: ['fightSkillTypeId'],
        method: 'POST',
        url: '/user_fight_skills/up_level.json',
        data: function(arg) {
          var fightSkillTypeId;
          fightSkillTypeId = arg.fightSkillTypeId;
          return {
            'data[UserFightSkill][type_id]': fightSkillTypeId
          };
        },
        vpageUrl: function(arg) {
          var fightSkillTypeId;
          fightSkillTypeId = arg.fightSkillTypeId;
          return "/api/user_fight_skills/up_level/" + fightSkillTypeId;
        }
      },
      'fightPoints.upLevelBulk': {
        cache: false,
        required: ['skillPoints'],
        method: 'POST',
        url: '/user_fight_skills/up_level_bulk.json',
        data: function(arg) {
          var skillPoints;
          skillPoints = arg.skillPoints;
          return {
            'data[UserFightSkill][skillPoints]': skillPoints
          };
        },
        vpageUrl: function(arg) {
          var fightSkillTypeId;
          fightSkillTypeId = arg.fightSkillTypeId;
          return "/api/user_fight_skills/up_level/" + fightSkillTypeId;
        }
      },

      /*
      				Hospital
       */
      'hospital.service': {
        cacheValidityInMs: 300 * 1000,
        url: '/hospitals/heal.json'
      },
      'hospital.service.healFullHP': {
        cache: false,
        invalidate: ['hospital.service', 'user.info.short'],
        method: 'POST',
        url: '/hospitals/heal_full_hp.json',
        showLoader: false,
        after: function() {
          return app.shortInfo.view.reload(null, false);
        }
      },
      'hospital.service.healTrauma': {
        cache: false,
        invalidate: ['hospital.service', 'user.info.short'],
        required: ['traumaId'],
        url: "/hospitals/trauma_heal.json",
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var traumaId;
          traumaId = arg.traumaId;
          return {
            'data[Trauma][id]': traumaId
          };
        },
        after: function() {
          return app.shortInfo.view.reload(null, false);
        }
      },

      /*
      				Stadium
       */
      'stadium.train': {
        cache: false,
        required: ['energy', 'skillId'],
        invalidate: ['stadium.trainers', 'user.info.sport', 'hospital.service', 'user.info', 'user.info.short'],
        url: '/sport_activities/start_sport_activity.json',
        method: 'POST',
        showLoader: false,
        vpageUrl: function(arg) {
          var energy, skillId;
          energy = arg.energy, skillId = arg.skillId;
          return "/api/sport_activities/start_sport_activity/" + skillId;
        },
        data: function(arg) {
          var energy, skillId;
          energy = arg.energy, skillId = arg.skillId;
          return {
            'data[SportActivity][energy]': energy,
            'data[SportActivity][sport_skill_type_id]': skillId
          };
        },
        after: function(options) {
          app.shortInfo.changeEnergy(-options.energy);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'stadium.trainWithTrainer': {
        cache: false,
        required: ['licenseId', 'programId', 'skillId', 'energy'],
        invalidate: ['stadium.trainers', 'user.info.sport', 'hospital.service', 'user.info'],
        method: 'POST',
        url: '/sport_activities/use_program.json',
        vpageUrl: function(arg) {
          var energy, licenseId, programId, skillId;
          licenseId = arg.licenseId, programId = arg.programId, skillId = arg.skillId, energy = arg.energy;
          return "/api/sport_activities/use_program/" + skillId;
        },
        data: function(arg) {
          var energy, licenseId, programId, skillId;
          licenseId = arg.licenseId, programId = arg.programId, skillId = arg.skillId, energy = arg.energy;
          return {
            'data[CoachProgram][license_id]': licenseId,
            'data[CoachProgram][id]': programId,
            'data[SportActivity][sport_skill_type_id]': skillId,
            'data[SportActivity][energy]': energy
          };
        },
        after: function(options) {
          app.shortInfo.changeEnergy(-options.energy);
          return app.shortInfo.view.reload();
        }
      },
      'stadium.trainers': {
        cache: false,
        required: ['page', 'sortField', 'order'],
        url: function(arg) {
          var order, page, sortField;
          page = arg.page, sortField = arg.sortField, order = arg.order;
          return "/sport_activities/train/page:" + page + "/sort:" + sortField + "/direction:" + order + ".json";
        }
      },
      'stadium.trainersByParam': {
        cache: false,
        required: ['page', 'sortField', 'order'],
        method: 'POST',
        url: function(arg) {
          var order, page, sortField;
          page = arg.page, sortField = arg.sortField, order = arg.order;
          return "/sport_activities/trainers_by_param/page:" + page + "/sort:" + sortField + "/direction:" + order + ".json";
        },
        data: function(arg) {
          var coefficient, name;
          coefficient = arg.coefficient, name = arg.name;
          return {
            'data[coefficient]': coefficient,
            'data[name]': name
          };
        }
      },
      'stadium.coefficientsAndMinPrice': {
        cache: false,
        url: "/sport_activities/get_min_price_for_coeffients.json"
      },

      /*
      				Military
       */
      'military.info': '/military/info',
      'military.pve.gangs': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var bandId;
          bandId = arg.bandId;
          return "/military/pve/gangs" + (bandId ? '/' + bandId : '');
        }
      },
      'military.pve.gangProgress': {
        cache: false,
        method: 'GET',
        required: ['bandId'],
        url: function(arg) {
          var bandId;
          bandId = arg.bandId;
          return "/military/pve/gangs/info/" + bandId;
        }
      },
      'military.pve.fight': {
        cache: false,
        required: ['bandId', 'complexity', 'rank'],
        invalidate: ['user.info', 'user.info.short', 'inventory', 'hospital.service', 'military.info'],
        method: 'POST',
        showLoader: false,
        url: function(arg) {
          var bandId, complexity, rank;
          bandId = arg.bandId, complexity = arg.complexity, rank = arg.rank;
          return "/military/pve/gangs/" + bandId + "/" + complexity + "/ranks/" + rank + "/fight";
        },
        vpageUrl: function(arg) {
          var complexity, rank;
          complexity = arg.complexity, rank = arg.rank;
          return "/api/military/pve/gangs/fight/" + complexity + "/" + rank;
        },
        after: function() {
          return app.shortInfo.view.reload(null, false);
        }
      },
      'military.pvp.info': '/military/pvp/info',
      'military.pvp.fight': {
        cache: false,
        invalidate: ['user.info', 'military.info', 'military.pvp.info', 'hospital.service'],
        method: 'POST',
        url: '/military/pvp/fight',
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'military.pvp.fight.cancel': {
        cache: false,
        method: 'POST',
        url: '/military/pvp/fight/cancel'
      },
      'military.at.areas': {
        cache: false,
        url: '/military/areas_takeover/areas'
      },
      'rebel.items.categories': {
        cache: true,
        url: '/military/rebel_wars/rebel_wars_items_categories'
      },
      'rebel.lotsList': {
        cache: false,
        url: function(arg) {
          var categoryId;
          categoryId = arg.categoryId;
          return "/military/rebel_wars/rebel_wars_shop/" + categoryId;
        }
      },
      'military.at.areas.map': {
        cache: false,
        required: ['areaId'],
        url: function(arg) {
          var areaId;
          areaId = arg.areaId;
          return "/military/areas_takeover/areas/" + areaId + "/map";
        }
      },
      'military.at.areas.post': {
        cache: false,
        required: ['areaId', 'postId'],
        url: function(arg) {
          var areaId, postId;
          areaId = arg.areaId, postId = arg.postId;
          return "/military/areas_takeover/areas/" + areaId + "/posts/" + postId;
        }
      },
      'military.at.areas.scout': {
        cache: false,
        required: ['areaId', 'postId'],
        invalidate: ['user.info', 'military.info', 'military.pvp.info', 'hospital.service'],
        url: function(arg) {
          var areaId, postId;
          areaId = arg.areaId, postId = arg.postId;
          return "/military/areas_takeover/areas/" + areaId + "/posts/" + postId + "/scout";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'military.at.areasArchive': '/areas_takeover/takeovers/archive.json',
      'military.at.checkActiveTakeover': '/areas_takeover/takeovers/check_takeover.json',
      'military.at.sendClone': {
        cache: false,
        required: ['areaId', 'postId'],
        invalidate: ['user.info', 'military.info', 'military.pvp.info', 'hospital.service'],
        method: 'POST',
        url: function(arg) {
          var areaId, postId;
          areaId = arg.areaId, postId = arg.postId;
          return "/military/areas_takeover/areas/" + areaId + "/posts/" + postId + "/clone";
        },
        data: function(arg) {
          var tactics;
          tactics = arg.tactics;
          return {
            tactics: tactics
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'military.at.checkClone': {
        cache: false,
        method: 'POST',
        url: "/military/areas_takeover/areas/posts/clone/check"
      },
      'military.at.roundResult': {
        cache: false,
        invalidate: ['military.at.areasArchive'],
        required: ['roundId'],
        url: function(arg) {
          var roundId;
          roundId = arg.roundId;
          return "/military/areas_takeover/rounds/" + roundId + "/result";
        }
      },
      'military.at.postResult': {
        cache: false,
        required: ['roundId', 'postId'],
        url: function(arg) {
          var postId, roundId;
          roundId = arg.roundId, postId = arg.postId;
          return "/military/areas_takeover/rounds/" + roundId + "/posts/" + postId + "/result";
        }
      },
      'military.at.result': {
        cache: false,
        required: ['areaTakeoverId'],
        url: function(arg) {
          var areaTakeoverId;
          areaTakeoverId = arg.areaTakeoverId;
          return "/military/areas_takeover/" + areaTakeoverId + "/result";
        }
      },
      'military.at.register': {
        cache: false,
        method: 'POST',
        required: ['areaId'],
        url: '/areas_takeover/bills/add.json',
        data: function(arg) {
          var areaId;
          areaId = arg.areaId;
          return {
            'data[AreasTakeoverBill][cities_area_id]': areaId
          };
        }
      },
      'military.rebelWars.raiseInfo': {
        cache: true,
        method: 'GET',
        url: function() {
          return "/military/rebel_wars/raise_info";
        }
      },
      'military.rebelWars.raise_uprising': {
        cache: false,
        method: 'POST',
        required: ['areaId', 'currency', 'financialStrength'],
        invalidate: ['military.districts.get'],
        data: function(arg) {
          var areaId, currency, financialStrength;
          areaId = arg.areaId, financialStrength = arg.financialStrength, currency = arg.currency;
          return {
            'areaId': areaId,
            'financialStrength': financialStrength,
            'currency': currency
          };
        },
        url: "/military/rebel_wars/raise_uprising"
      },
      'military.rebelWars.sendClones': {
        cache: false,
        required: ['rebelWarId', 'areaId', 'postId', 'count'],
        invalidate: [],
        method: 'POST',
        url: function(arg) {
          var areaId, postId, rebelWarID;
          rebelWarID = arg.rebelWarID, areaId = arg.areaId, postId = arg.postId;
          return "/military/rebel_wars/send_clones";
        },
        data: function(arg) {
          var areaId, count, postId, rebelWarId, tactics;
          rebelWarId = arg.rebelWarId, areaId = arg.areaId, postId = arg.postId, count = arg.count, tactics = arg.tactics;
          return {
            rebelWarId: rebelWarId,
            areaId: areaId,
            postId: postId,
            count: count,
            tactics: tactics
          };
        }
      },
      'rebel.buyLot': {
        cache: false,
        method: 'POST',
        data: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return {
            'data[itemId]': itemId
          };
        },
        url: function(arg) {
          var rebelWarId;
          rebelWarId = arg.rebelWarId;
          return "/military/rebel_wars/rebel_wars_buy_item/" + rebelWarId;
        }
      },
      'military.rebelWar.agitation': {
        cache: false,
        method: 'POST',
        data: function(arg) {
          var amountVd, amountVg;
          amountVd = arg.amountVd, amountVg = arg.amountVg;
          return {
            'data[vdAmount]': amountVd,
            'data[vgAmount]': amountVg
          };
        },
        url: function(arg) {
          var rebelWarId;
          rebelWarId = arg.rebelWarId;
          return "/military/rebel_wars/" + rebelWarId + "/agitation";
        }
      },
      'military.rebelWar.beginArming': {
        cache: false,
        method: 'POST',
        data: function(arg) {
          var rebelWarId;
          rebelWarId = arg.rebelWarId;
          return {
            'rebelWarId': rebelWarId
          };
        },
        url: "/military/rebel_wars/begin_arming"
      },
      'military.rebelWar.beginCombat': {
        cache: false,
        method: 'POST',
        data: function(arg) {
          var rebelWarId;
          rebelWarId = arg.rebelWarId;
          return {
            'rebelWarId': rebelWarId
          };
        },
        url: "/military/rebel_wars/begin_combat"
      },
      'military.rebelWar.trainRebels': {
        cache: false,
        method: 'POST',
        data: function(arg) {
          var currency, rebelWarId, stats;
          rebelWarId = arg.rebelWarId, currency = arg.currency, stats = arg.stats;
          return {
            'rebelWarId': rebelWarId,
            'stats': stats,
            'currency': currency
          };
        },
        url: "/military/rebel_wars/train_rebels"
      },
      'military.rebelWar.agitation_donate': {
        cache: false,
        method: 'POST',
        required: ['rebelWarId', 'vdAmount', 'vgAmount'],
        invalidate: ['military.districts.get', 'military.rebelWar.getInfo'],
        data: function(arg) {
          var rebelWarId, vdAmount, vgAmount;
          rebelWarId = arg.rebelWarId, vdAmount = arg.vdAmount, vgAmount = arg.vgAmount;
          return {
            'rebelWarId': rebelWarId,
            'amountData[vd]': vdAmount,
            'amountData[vg]': vgAmount
          };
        },
        url: "/military/rebel_wars/agitation_donate"
      },
      'military.rebelWar.donate': {
        cache: false,
        method: 'POST',
        required: ['rebelWarId', 'vdAmount', 'vgAmount'],
        data: function(arg) {
          var rebelWarId, vdAmount, vgAmount;
          rebelWarId = arg.rebelWarId, vdAmount = arg.vdAmount, vgAmount = arg.vgAmount;
          return {
            'rebelWarId': rebelWarId,
            'amountData[vd]': vdAmount,
            'amountData[vg]': vgAmount
          };
        },
        url: "/military/rebel_wars/donate"
      },
      'military.rebelWar.getInfo': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var rebelWarId;
          rebelWarId = arg.rebelWarId;
          return "/military/rebel_wars/info/" + rebelWarId;
        }
      },
      'military.districts.get': {
        cache: false,
        url: function() {
          return "/areas_takeover/districts/all.json";
        }
      },
      'military.districts.available_for_takeover': {
        cache: false,
        url: function() {
          return "/areas_takeover/districts/districts_for_takeover.json";
        }
      },
      'military.cloneTactics': {
        cacheValidityInMs: 6000 * 1000,
        url: function() {
          return "/areas_takeover/tactics/clone_tactics.json";
        }
      },
      'military.saveCustomTactics': {
        cache: false,
        invalidate: ['military.cloneTactics'],
        method: 'POST',
        required: ['associationsData'],
        url: '/areas_takeover/tactics/save_custom.json',
        data: function(arg) {
          var associationsData;
          associationsData = arg.associationsData;
          return {
            'data[associationsData]': associationsData
          };
        }
      },

      /*
      				Airport
       */
      'airport.flights': {
        cacheValidityInMs: 300 * 1000,
        url: '/airport/flights.json'
      },
      'airport.flyToCity': {
        required: ['cityId'],
        invalidate: ['airport.flights', 'house.info'],
        method: 'POST',
        url: '/users/fly.json',
        data: function(arg) {
          var cityId;
          cityId = arg.cityId;
          return {
            'data[User][to_city]': cityId
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'airport.price': {
        cacheValidityInMs: 300 * 1000,
        required: ['cityId'],
        url: function(arg) {
          var cityId;
          cityId = arg.cityId;
          return "/airport/price/" + cityId + ".json";
        }
      },

      /*
      				Port
       */
      'port': {
        cacheValidityInMs: 300 * 1000,
        url: '/seaports/index.json'
      },
      'port.fish': {
        cache: false,
        invalidate: ['inventory', 'port'],
        url: '/seaports/begin_fishing.json',
        method: 'POST',
        showLoader: false,
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'port.ship.buy': {
        cache: false,
        invalidate: ['port'],
        url: '/seaports/buy_ship.json',
        method: 'POST',
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'port.ship.rename': {
        method: 'POST',
        required: ['shipId', 'name'],
        cache: false,
        invalidate: ['port', 'inventory'],
        url: '/seaports/rename_ship.json',
        data: function(arg) {
          var name, shipId;
          shipId = arg.shipId, name = arg.name;
          return {
            'data[UserShip][id]': shipId,
            'data[UserShip][name]': name
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },

      /*
      				Suggestions
       */
      'suggestions.newSuggestions': {
        cache: false,
        url: function(arg) {
          var page;
          page = arg.page;
          return "/suggestions/new_suggestions/page:" + page + ".json";
        }
      },
      'suggestions.mySuggestions': {
        cache: false,
        url: function(arg) {
          var page;
          page = arg.page;
          return "/suggestions/my_suggestions/page:" + page + ".json";
        }
      },
      'suggestions.popularSuggestions': {
        cache: false,
        url: function(arg) {
          var page;
          page = arg.page;
          return "/suggestions/popular_suggestions/page:" + page + ".json";
        }
      },
      'suggestions.post': {
        cache: false,
        invalidate: [],
        url: function(arg) {
          var suggestionId;
          suggestionId = arg.suggestionId;
          return "/suggestions/view/" + suggestionId + ".json";
        }
      },
      'suggestions.createSuggestion': {
        cache: false,
        invalidate: ['suggestions.newSuggestions', 'suggestions.mySuggestions', 'suggestions.popularSuggestions'],
        method: 'POST',
        data: function(arg) {
          var description, title;
          title = arg.title, description = arg.description;
          return {
            'data[Suggestion][title]': title,
            'data[Suggestion][description]': description
          };
        },
        url: '/suggestions/add_suggestion.json'
      },
      'suggestions.addComment': {
        required: ['suggestionId', 'message'],
        method: 'POST',
        cache: false,
        invalidate: ['suggestions.newSuggestions', 'suggestions.mySuggestions', 'suggestions.popularSuggestions'],
        url: '/suggestions/add_comment.json',
        data: function(arg) {
          var message, suggestionId;
          suggestionId = arg.suggestionId, message = arg.message;
          return {
            'data[SuggestionComment][suggestion_id]': suggestionId,
            'data[SuggestionComment][body]': message
          };
        }
      },
      'suggestions.comment.edit': {
        required: ['commentId'],
        method: 'GET',
        cache: false,
        url: function(arg) {
          var commentId;
          commentId = arg.commentId;
          return "/suggestions/edit_comment/" + commentId + ".json";
        }
      },
      'suggestions.comment.delete': {
        required: ['commentId'],
        invalidate: ['suggestions.newSuggestions', 'suggestions.mySuggestions', 'suggestions.popularSuggestions'],
        method: 'POST',
        cache: false,
        url: function(arg) {
          var commentId;
          commentId = arg.commentId;
          return "/suggestions/delete_comment/" + commentId + ".json";
        }
      },
      'suggestions.comment.update': {
        required: ['commentId', 'body'],
        method: 'POST',
        cache: false,
        invalidate: ['suggestions.newSuggestions', 'suggestions.mySuggestions', 'suggestions.popularSuggestions'],
        url: function(arg) {
          var commentId;
          commentId = arg.commentId;
          return "/suggestions/edit_comment/" + commentId + ".json";
        },
        data: function(arg) {
          var body;
          body = arg.body;
          return {
            'data[SuggestionComment][body]': body
          };
        }
      },
      'suggestions.addLike': {
        cache: false,
        invalidate: ['suggestions.newSuggestions', 'suggestions.mySuggestions', 'suggestions.popularSuggestions', 'suggestions.post'],
        url: function() {
          return "/suggestions/like.json";
        },
        required: ['suggestionId'],
        method: 'POST',
        data: function(arg) {
          var suggestionId;
          suggestionId = arg.suggestionId;
          return {
            'data[Suggestion][id]': suggestionId
          };
        }
      },
      'suggestions.addDislike': {
        cache: false,
        invalidate: ['suggestions.newSuggestions', 'suggestions.mySuggestions', 'suggestions.popularSuggestions', 'suggestions.post'],
        url: function() {
          return "/suggestions/dislike.json";
        },
        required: ['suggestionId'],
        method: 'POST',
        data: function(arg) {
          var suggestionId;
          suggestionId = arg.suggestionId;
          return {
            'data[Suggestion][id]': suggestionId
          };
        }
      },

      /*
      				Messages
       */
      messages: {
        url: '/messages/message_list.json',
        cache: false
      },
      'messages.fromUser': {
        cache: false,
        invalidate: ['messages', 'user.notification_badges'],
        required: ['userId', 'page'],
        url: function(arg) {
          var page, userId;
          userId = arg.userId, page = arg.page;
          return "/messages/new_msg/" + userId + "/page:" + page + ".json";
        }
      },
      'messages.usersSearch': {
        cache: false,
        method: 'GET',
        required: ['query', 'onlyOnline'],
        url: function(arg) {
          var onlyOnline, query;
          query = arg.query, onlyOnline = arg.onlyOnline;
          return "/users/ajax_search_user.json?query=" + query + "&onlyOnline=" + onlyOnline;
        },
        data: function(arg) {
          var onlyOnline, query;
          query = arg.query, onlyOnline = arg.onlyOnline;
          return {
            'data[Search][query]': query,
            'data[Search][onlyOnline]': onlyOnline
          };
        },
        after: function() {
          return app.menu.view.reload();
        }
      },
      'messages.send': {
        required: ['userId', 'message'],
        method: 'POST',
        invalidate: ['messages', 'messages.fromUser'],
        url: '/messages/new_message.json',
        data: function(arg) {
          var message, userId;
          userId = arg.userId, message = arg.message;
          return {
            'data[Message][receiver_id]': userId,
            'data[Message][body]': message
          };
        }
      },
      'messages.deleteDialog': {
        required: ['userId'],
        method: 'POST',
        invalidate: ['messages', 'messages.fromUser'],
        url: '/messages/delete.json',
        data: function(arg) {
          var userId;
          userId = arg.userId;
          return {
            'data[Message][receiver_id]': userId
          };
        }
      },
      'messages.hideDialog': {
        required: ['userId'],
        method: 'POST',
        invalidate: ['messages', 'messages.fromUser'],
        url: '/messages/hide.json',
        data: function(arg) {
          var userId;
          userId = arg.userId;
          return {
            'data[Message][receiver_id]': userId
          };
        }
      },

      /*
      				Cities
       */
      cities: {
        cache: false,
        url: '/city_hall/cities.json'
      },

      /*
      				Feed
       */
      feed: {
        cacheValidityInMs: 300 * 1000,
        url: '/event_logs/get.json'
      },
      groupFeed: {
        invalidate: ['user.notification_badges'],
        required: ['group'],
        url: function(arg) {
          var group, subgroup;
          group = arg.group, subgroup = arg.subgroup;
          return "/feed/get.json?group=" + group + (subgroup ? '&sub_group=' + subgroup : '');
        },
        cacheValidityInMs: 300 * 1000,
        after: function(options) {
          if (options.group === 'personal') {
            return app.menu.view.reload();
          }
        }
      },
      countGroupEvents: {
        url: "/event_logs/count_group_events.json",
        cache: false
      },

      /*
      				Inventory
       */
      'inventory': {
        cache: false,
        url: '/user_items/storage.json'
      },
      'inventory.unequipped': {
        cache: false,
        url: '/user_items/unequippedStorage.json'
      },
      'inventory.buySlots': {
        cache: false,
        required: ['size'],
        invalidate: ['inventory'],
        url: function() {
          return "/users/inv_size.json";
        },
        method: 'POST',
        data: function(arg) {
          var size;
          size = arg.size;
          return {
            'data[UserItem][size]': size
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'inventory.itemInfo': {
        cache: false,
        required: ['itemId'],
        url: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return "/user_items/get_info/" + itemId + ".json";
        }
      },
      'corporation.corporationItemInfo': {
        cache: false,
        required: ['itemId'],
        url: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return "/corporation_items/get_info_corporation/" + itemId + ".json";
        }
      },
      'inventory.itemTypeInfo': {
        cache: false,
        required: ['itemTypeId'],
        url: function(arg) {
          var itemTypeId;
          itemTypeId = arg.itemTypeId;
          return "/user_items/get_type_info/" + itemTypeId + ".json";
        }
      },
      'inventory.availableItemInfo': {
        cache: false,
        required: ['itemId'],
        url: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return "/user_items/get_info/" + itemId + ".json?available_only=1";
        }
      },
      'inventory.putOn': {
        cache: false,
        required: ['itemId', 'slotId'],
        invalidate: ['inventory', 'tradeCenter.itemsToSell'],
        url: function() {
          return "/user_items/put_item_on.json";
        },
        method: 'POST',
        data: function(arg) {
          var itemId, slotId;
          itemId = arg.itemId, slotId = arg.slotId;
          return {
            'data[UserItem][id]': itemId,
            'data[UserItem][slot_id]': slotId
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'inventory.useSpecial': {
        cache: false,
        required: ['itemId'],
        method: 'POST',
        invalidate: ['inventory', 'tradeCenter.itemsToSell'],
        url: '/user_items/use_special_item.json',
        showLoader: false,
        data: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return {
            'data[UserItem][item_id]': itemId
          };
        },
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'inventory.use': {
        cache: false,
        required: ['itemId', 'cityId', 'typeId'],
        method: 'POST',
        showLoader: false,
        invalidate: ['inventory', 'tradeCenter.itemsToSell'],
        url: '/user_items/use_item.json',
        data: function(arg) {
          var cityId, itemId, typeId;
          itemId = arg.itemId, cityId = arg.cityId, typeId = arg.typeId;
          return {
            'data[UserItem][item_id]': itemId,
            'data[UserItem][city_id]': cityId,
            'data[UserItem][type]': typeId
          };
        },
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'corporation.use': {
        cache: false,
        required: ['itemId', 'cityId', 'typeId', 'corporationId'],
        method: 'POST',
        showLoader: false,
        url: '/corporation_items/use_item.json',
        data: function(arg) {
          var cityId, corporationId, itemId, typeId;
          itemId = arg.itemId, cityId = arg.cityId, typeId = arg.typeId, corporationId = arg.corporationId;
          return {
            'data[CorporationItem][item_type_id]': itemId,
            'data[CorporationItem][city_id]': cityId,
            'data[CorporationItem][type]': typeId,
            'data[CorporationItem][corporationId]': corporationId
          };
        },
        invalidate: ['business.corporationStorage', 'business.corporationInfo']
      },
      'inventory.useForm': {
        cache: false,
        required: ['itemId'],
        url: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return "/user_items/get_use_form/" + itemId + ".json";
        }
      },
      'corporation.useForm': {
        cache: false,
        required: ['itemId'],
        url: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return "/corporation_items/get_use_form/" + itemId + ".json";
        }
      },
      'inventory.eat': {
        cache: false,
        required: ['itemId'],
        method: 'POST',
        invalidate: ['inventory', 'tradeCenter.itemsToSell'],
        url: '/user_items/eat_user_item.json',
        data: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return {
            'data[UserItem][item_id]': itemId
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'inventory.remove': {
        cache: false,
        required: ['itemId'],
        method: 'POST',
        invalidate: ['inventory', 'tradeCenter.itemsToSell'],
        url: '/user_items/delete_items.json',
        data: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return {
            'data[UserItem][item_id]': itemId
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'inventory.putOff': {
        cache: false,
        required: ['itemId'],
        method: 'POST',
        invalidate: ['inventory', 'tradeCenter.itemsToSell'],
        url: '/user_items/put_item_off.json',
        data: function(arg) {
          var itemId;
          itemId = arg.itemId;
          return {
            'data[UserItem][item_id]': itemId
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'inventory.furniture': {
        url: '/user_items/get_furniture.json'
      },
      'inventory.getEnergyDrink': {
        cache: false,
        invalidate: ['inventory', 'user.info', 'user.info.short', 'user.info.sport', 'stadium.trainers'],
        url: '/user_items/get_energy_drink.json'
      },
      'inventory.useEnergyDrink': {
        cache: false,
        required: ['itemTypeId', 'itemId', 'count'],
        method: 'POST',
        invalidate: ['inventory', 'user.info', 'user.info.short', 'user.info.sport', 'stadium.trainers'],
        data: function(arg) {
          var itemId, itemTypeId;
          itemTypeId = arg.itemTypeId, itemId = arg.itemId;
          return {
            'data[UserItem][item_id]': itemId,
            'data[UserItem][item_type_id]': itemTypeId
          };
        },
        url: function(arg) {
          var count;
          count = arg.count;
          return "/user_items/use_energy_drink/" + count + ".json";
        },
        after: function() {
          return app.shortInfo.view.reload();
        }
      },

      /*
      				Trade Center
       */
      'tradeCenter.itemGroups': {
        url: '/exchanges/items_groups_categories.json'
      },
      'tradeCenter.businessGroups': {
        url: '/exchanges/items_groups_categories_business.json'
      },
      'tradeCenter.availableItemGroups': {
        cache: false,
        url: '/exchanges/available_items_groups_categories.json'
      },
      'tradeCenter.availableBusinessGroups': {
        cache: false,
        url: '/exchanges/available_categories_business.json'
      },
      'tradeCenter.availableItems': {
        cache: false,
        required: ['category'],
        url: function(arg) {
          var category;
          category = arg.category;
          return "/exchanges/available_items/" + category + ".json";
        }
      },
      'tradeCenter.availableStock': {
        cache: false,
        url: '/stock_exchanges/available_stock.json'
      },
      'tradeCenter.availableCurrency': {
        cache: false,
        url: '/currency/available.json'
      },
      'tradeCenter.stocksByCorporation': {
        cache: false,
        url: function(arg) {
          var itemName;
          itemName = arg.itemName;
          if (itemName != null) {
            return "/stock_exchanges/grouped_by_corporation.json?corporationName=" + itemName;
          } else {
            return '/stock_exchanges/grouped_by_corporation.json';
          }
        }
      },
      'tradeCenter.currencyLotsList': {
        cache: false,
        url: function() {
          return "/currency/index.json";
        }
      },
      'tradeCenter.currencyLotsByType': {
        cache: false,
        url: function(arg) {
          var type;
          type = arg.type;
          if (type === 1) {
            return "/currency/lots/vg.json";
          } else {
            return "/currency/lots/vd.json";
          }
        }
      },
      'tradeCenter.currencyVgLots': {
        cache: false,
        url: function() {
          return "/currency/lots/vg.json";
        }
      },
      'tradeCenter.currencyVdLots': {
        cache: false,
        url: function() {
          return "/currency/lots/vd.json";
        }
      },
      'tradeCenter.lotsList': {
        cache: false,
        required: ['category'],
        url: function(arg) {
          var category, itemName;
          category = arg.category, itemName = arg.itemName;
          if (itemName != null) {
            return "/exchanges/lots_by_type_user/" + category + ".json?itemTypeName=" + itemName;
          } else {
            return "/exchanges/lots_by_type_user/" + category + ".json";
          }
        }
      },
      'tradeCenter.lotsListCityHall': {
        cache: false,
        url: "/city_item_proposals/sell_index.json"
      },
      'tradeCenter.sellToCity': {
        required: ['cityLotId', 'number'],
        cache: false,
        invalidate: ['tradeCenter.lotsListCityHall', 'inventory', 'user.info'],
        url: function(arg) {
          var cityLotId;
          cityLotId = arg.cityLotId;
          return "/city_item_proposals/user_buy/" + cityLotId + ".json";
        },
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var number;
          number = arg.number;
          return {
            'data[CityItemProposal][number]': number
          };
        },
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'tradeCenter.itemTypesList': {
        cache: false,
        url: function(arg) {
          var category;
          category = arg.category;
          return "/exchanges/items_by_type/" + category + ".json";
        }
      },
      'tradeCenter.lotsListCompany': {
        cache: false,
        url: function(arg) {
          var category, companyId;
          category = arg.category, companyId = arg.companyId;
          return "/exchanges/lots_by_type_company/" + companyId + "/" + category + ".json";
        }
      },
      'tradeCenter.lotsCompany': {
        cache: false,
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/exchanges/lots_by_company/" + companyId + ".json";
        }
      },
      'tradeCenter.lotsOffer': {
        cache: false,
        url: function(arg) {
          var currency, direction, itemTypeId, sort;
          currency = arg.currency, itemTypeId = arg.itemTypeId, sort = arg.sort, direction = arg.direction;
          if (sort == null) {
            sort = "price";
          }
          if (direction == null) {
            direction = "asc";
          }
          return "/exchanges/lot_offers/" + currency + "/" + itemTypeId + "/" + sort + "/" + direction + ".json";
        }
      },
      'tradeCenter.lotsOfferCompany': {
        cache: false,
        url: function(arg) {
          var companyId, currency, direction, itemTypeId, sort;
          currency = arg.currency, itemTypeId = arg.itemTypeId, companyId = arg.companyId, sort = arg.sort, direction = arg.direction;
          if (sort == null) {
            sort = "price";
          }
          if (direction == null) {
            direction = "asc";
          }
          return "/exchanges/lot_offers_company/" + currency + "/" + itemTypeId + "/" + companyId + "/" + sort + "/" + direction + ".json";
        }
      },
      'tradeCenter.lotsOfferShares': {
        cache: false,
        url: function(arg) {
          var corporationId, currency, direction, sort;
          currency = arg.currency, corporationId = arg.corporationId, sort = arg.sort, direction = arg.direction;
          if (sort == null) {
            sort = "price";
          }
          if (direction == null) {
            direction = "asc";
          }
          return "/stock_exchanges/lot_offers/" + currency + "/" + corporationId + "/" + sort + "/" + direction + ".json";
        }
      },
      'tradeCenter.userLots': {
        cache: false,
        url: "/exchanges/user_lots.json"
      },
      'tradeCenter.userCurrencyLots': {
        cache: false,
        url: "/currency/user_lots.json"
      },
      'tradeCenter.userStockLots': {
        cache: false,
        url: "/stock_exchanges/lots.json"
      },
      'tradeCenter.itemsToBuy': {
        cache: false,
        url: function(arg) {
          var categoryId;
          categoryId = arg.categoryId;
          if (categoryId != null) {
            return "/exchanges/by_type/" + categoryId + ".json";
          } else {
            return '/exchanges/item_buy.json';
          }
        }
      },
      'tradeCenter.itemsToSell': {
        cache: false,
        url: '/exchanges/user_sell.json'
      },
      'tradeCenter.companyItemsToSell': {
        cache: false,
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/exchanges/company_sell/" + companyId + ".json";
        }
      },
      'tradeCenter.corporationItemsToSell': {
        cache: false,
        url: function(arg) {
          var corporationId;
          corporationId = arg.corporationId;
          return "/exchanges/corporation_sell/" + corporationId + ".json";
        }
      },
      'tradeCenter.createLot': {
        required: ['itemTypeId', 'amount', 'price', 'currency'],
        cache: false,
        invalidate: ['tradeCenter.availableItems', 'tradeCenter.lotsList', 'tradeCenter.lotsOffer', 'tradeCenter.userLots', 'inventory', 'user.info'],
        url: '/exchanges/add_user_exchange.json',
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, currency, itemTypeId, price;
          itemTypeId = arg.itemTypeId, amount = arg.amount, price = arg.price, currency = arg.currency;
          return {
            'data[Exchange][item_type_id]': itemTypeId,
            'data[Exchange][number]': amount,
            'data[Exchange][price]': price,
            'data[Exchange][currency]': currency
          };
        },
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'tradeCenter.createStockLot': {
        required: ['corporationId', 'amount', 'price', 'currency'],
        cache: false,
        invalidate: ['tradeCenter.availableStock', 'tradeCenter.lotsOffer', 'tradeCenter.userLots', 'inventory', 'user.info'],
        url: '/stock_exchanges/add.json',
        method: 'POST',
        data: function(arg) {
          var amount, corporationId, currency, price;
          corporationId = arg.corporationId, amount = arg.amount, price = arg.price, currency = arg.currency;
          return {
            'data[StockExchange][corporation_id]': corporationId,
            'data[StockExchange][number]': amount,
            'data[StockExchange][price]': price,
            'data[StockExchange][currency]': currency
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'tradeCenter.createLotCompany': {
        required: ['itemTypeId', 'amount', 'price', 'currency'],
        cache: false,
        invalidate: ['tradeCenter.companyItemsToSell', 'business.storage', 'business.companyInfo', 'tradeCenter.lotsCompany'],
        url: '/exchanges/add_company_exchange.json',
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, companyId, currency, itemTypeId, price;
          companyId = arg.companyId, itemTypeId = arg.itemTypeId, amount = arg.amount, price = arg.price, currency = arg.currency;
          return {
            'data[Exchange][company_id]': companyId,
            'data[Exchange][item_type_id]': itemTypeId,
            'data[Exchange][number]': amount,
            'data[Exchange][price]': price,
            'data[Exchange][currency]': currency
          };
        }
      },
      'tradeCenter.createLotCorporation': {
        required: ['itemTypeId', 'amount', 'price', 'currency'],
        cache: false,
        invalidate: ['tradeCenter.corporationItemsToSell', 'business.corporationStorage'],
        url: '/exchanges/add_corporation_exchange.json',
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, corporationId, currency, itemTypeId, price;
          corporationId = arg.corporationId, itemTypeId = arg.itemTypeId, amount = arg.amount, price = arg.price, currency = arg.currency;
          return {
            'data[Exchange][corporation_id]': corporationId,
            'data[Exchange][item_type_id]': itemTypeId,
            'data[Exchange][number]': amount,
            'data[Exchange][price]': price,
            'data[Exchange][currency]': currency
          };
        }
      },
      'tradeCenter.createCurrencyLot': {
        required: ['amount', 'price', 'type'],
        cache: false,
        invalidate: ['tradeCenter.availableCurrency', 'tradeCenter.lotsList', 'tradeCenter.lotsOffer', 'tradeCenter.userLots', 'inventory', 'user.info'],
        url: '/currency/add_exchange.json',
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, price, type;
          amount = arg.amount, price = arg.price, type = arg.type;
          return {
            'data[CurrencyExchange][number]': amount,
            'data[CurrencyExchange][price]': price,
            'data[CurrencyExchange][type]': type
          };
        },
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'tradeCenter.buyCurrencyLot': {
        required: ['exchangeId', 'number'],
        cache: false,
        invalidate: ['tradeCenter.currencyVdLots', 'tradeCenter.currencyVgLots', 'tradeCenter.currencyLotsList', 'tradeCenter.currencyLotsByType', 'user.info'],
        url: function() {
          return '/currency/buy.json';
        },
        method: 'POST',
        data: function(arg) {
          var corporationId, exchangeId, number;
          exchangeId = arg.exchangeId, number = arg.number, corporationId = arg.corporationId;
          return {
            'data[CurrencyExchange][id]': exchangeId,
            'data[CurrencyExchange][number]': number
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'tradeCenter.buyLot': {
        required: ['exchangeId', 'number', 'corporationId'],
        cache: false,
        invalidate: ['tradeCenter.lotsOffer', 'tradeCenter.lotsList', 'user.info', 'inventory', 'inventory.furniture', 'business.corporationStorage'],
        url: function(arg) {
          var corporationId;
          corporationId = arg.corporationId;
          if ((corporationId != null) && corporationId !== 0) {
            return '/exchanges/corporation_buy.json';
          } else {
            return '/exchanges/user_buy.json';
          }
        },
        method: 'POST',
        data: function(arg) {
          var corporationId, exchangeId, number;
          exchangeId = arg.exchangeId, number = arg.number, corporationId = arg.corporationId;
          return {
            'data[Exchange][id]': exchangeId,
            'data[Exchange][number]': number,
            'data[Corporation][id]': corporationId
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'tradeCenter.editLot': {
        required: ['exchangeId', 'price', 'currency'],
        cache: false,
        invalidate: ['tradeCenter.lotsOffer', 'tradeCenter.lotsList', 'tradeCenter.userLots'],
        url: '/exchanges/edit_user_exchange.json',
        method: 'POST',
        data: function(arg) {
          var currency, exchangeId, price;
          exchangeId = arg.exchangeId, price = arg.price, currency = arg.currency;
          return {
            'data[Exchange][id]': exchangeId,
            'data[Exchange][price]': price,
            'data[Exchange][currency]': currency
          };
        }
      },
      'tradeCenter.editCompanyLot': {
        required: ['exchangeId', 'price', 'currency'],
        cache: false,
        invalidate: ['tradeCenter.lotsOffer', 'tradeCenter.lotsList', 'tradeCenter.lotsCompany'],
        url: '/exchanges/edit_company_exchange.json',
        method: 'POST',
        data: function(arg) {
          var companyId, currency, exchangeId, price;
          exchangeId = arg.exchangeId, price = arg.price, currency = arg.currency, companyId = arg.companyId;
          return {
            'data[Exchange][id]': exchangeId,
            'data[Exchange][price]': price,
            'data[Exchange][currency]': currency,
            'data[Exchange][company_id]': companyId
          };
        }
      },
      'tradeCenter.editCurrencyLot': {
        required: ['exchangeId', 'price'],
        cache: false,
        invalidate: ['tradeCenter.lotsOffer', 'tradeCenter.lotsList', 'tradeCenter.userLots'],
        url: '/currency/edit_exchange.json',
        method: 'POST',
        data: function(arg) {
          var exchangeId, price;
          exchangeId = arg.exchangeId, price = arg.price;
          return {
            'data[CurrencyExchange][id]': exchangeId,
            'data[CurrencyExchange][price]': price
          };
        }
      },
      'tradeCenter.editStockLot': {
        required: ['exchangeId', 'price', 'currency'],
        cache: false,
        invalidate: ['tradeCenter.lotsOffer', 'tradeCenter.lotsList', 'tradeCenter.userLots'],
        url: '/stock_exchanges/edit.json',
        method: 'POST',
        data: function(arg) {
          var currency, exchangeId, price;
          exchangeId = arg.exchangeId, price = arg.price, currency = arg.currency;
          return {
            'data[StockExchange][id]': exchangeId,
            'data[StockExchange][price]': price,
            'data[StockExchange][currency]': currency
          };
        }
      },
      'tradeCenter.buySharesLot': {
        required: ['exchangeId', 'number'],
        cache: false,
        invalidate: ['tradeCenter.lotsOfferShares', 'tradeCenter.stocksByCorporation', 'user.info.short'],
        url: '/stock_exchanges/buy.json',
        method: 'POST',
        data: function(arg) {
          var exchangeId, number;
          exchangeId = arg.exchangeId, number = arg.number;
          return {
            'data[StockExchange][id]': exchangeId,
            'data[StockExchange][number]': number
          };
        }
      },
      'tradeCenter.buyLotCompany': {
        required: ['exchangeId', 'number', 'companyId'],
        cache: false,
        invalidate: ['tradeCenter.lotsOfferCompany', 'tradeCenter.lotsListCompany', 'business.storage', 'business.companyInfo'],
        url: function(arg) {
          var companyId, exchangeId;
          companyId = arg.companyId, exchangeId = arg.exchangeId;
          return "/exchanges/company_buy/" + companyId + "/" + exchangeId + ".json";
        },
        method: 'POST',
        data: function(arg) {
          var number;
          number = arg.number;
          return {
            'data[Exchange][number]': number
          };
        }
      },

      /*
      				Work
       */
      'work.current': {
        cache: false,
        url: '/users/user_work.json'
      },
      'work.current.resign': {
        required: ['workerId'],
        cache: false,
        invalidate: ['work.current', 'work.vacancies', 'work.vacancies.forProfession', 'user.info.profession'],
        method: 'POST',
        showLoader: false,
        url: '/company_workers/resign_from_work.json',
        data: function(arg) {
          var workerId;
          workerId = arg.workerId;
          return {
            'data[CompanyWorker][worker_id]': workerId
          };
        }
      },
      'work.vacancies': {
        url: '/vacancies/index.json',
        cacheValidityInMs: 10 * 1000
      },
      'work.vacancies.forProfession': {
        url: '/vacancies/index.json',
        required: ['professionId'],
        cache: false,
        method: 'POST',
        googleAnalyticsIgnore: true,
        data: function(arg) {
          var professionId;
          professionId = arg.professionId;
          return {
            'data[CompanyVacancy][profession_type_id]': professionId
          };
        }
      },
      'work.vacancies.accept': {
        required: ['vacancyId'],
        invalidate: ['work.current', 'user.info.profession', 'work.vacancies.forProfession'],
        cache: false,
        url: function() {
          return "/vacancies/work_vacancy.json";
        },
        method: 'POST',
        data: function(arg) {
          var vacancyId;
          vacancyId = arg.vacancyId;
          return {
            'data[CompanyVacancy][id]': vacancyId
          };
        }
      },
      'work.licenses': {
        cacheValidityInMs: 30 * 1000,
        url: '/libraries/licenses.json'
      },
      'work.licenses.info': {
        cache: false,
        url: '/libraries/licences_info.json'
      },
      'work.licenses.updateSettings': {
        required: ['licenseId', 'currency', 'price'],
        invalidate: ['work.licenses', 'work.licenses.info'],
        method: 'POST',
        cache: false,
        url: '/sport_activities/update_program.json',
        data: function(arg) {
          var currency, licenseId, price;
          licenseId = arg.licenseId, currency = arg.currency, price = arg.price;
          return {
            'data[CoachProgram][licence_id]': licenseId,
            'data[CoachProgram][price]': price,
            'data[CoachProgram][currency]': currency
          };
        }
      },
      'work.licenses.buyDoctorLicense': {
        required: ['licenseId', 'confirm'],
        cache: false,
        invalidate: ['work.licenses', 'work.licenses.info'],
        url: function() {
          return "/libraries/buy_medical_license.json";
        },
        method: 'POST',
        data: function(arg) {
          var confirm, licenseId;
          licenseId = arg.licenseId, confirm = arg.confirm;
          return {
            'data[DoctorLicenseType][id]': licenseId,
            'data[DoctorLicense][confirm]': confirm
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'work.licenses.buyTrainerLicense': {
        required: ['licenseId', 'confirm'],
        cache: false,
        invalidate: ['work.licenses', 'work.licenses.info'],
        url: function() {
          return "/libraries/buy_license.json";
        },
        method: 'POST',
        data: function(arg) {
          var confirm, licenseId;
          licenseId = arg.licenseId, confirm = arg.confirm;
          return {
            'data[GrantType][id]': licenseId,
            'data[License][confirm]': confirm
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'work.doctorLicense.start': {
        cache: false,
        invalidate: ['work.licenses.info'],
        method: 'POST',
        url: '/hospitals/start_license.json'
      },
      'work.doctorLicense.stop': {
        cache: false,
        invalidate: ['work.licenses.info'],
        method: 'POST',
        url: '/hospitals/stop_license.json'
      },
      'work.doctorLicense.renew': {
        cache: false,
        invalidate: ['work.licenses.info'],
        method: 'POST',
        url: '/hospitals/renew.json'
      },
      'work.trainerLicense.start': {
        required: ['licenseId'],
        invalidate: ['work.licenses.info'],
        method: 'POST',
        cache: false,
        url: '/sport_activities/update_program.json',
        data: function(arg) {
          var licenseId;
          licenseId = arg.licenseId;
          return {
            'data[CoachProgram][licence_id]': licenseId,
            'data[CoachProgram][active]': true
          };
        }
      },
      'work.trainerLicense.stop': {
        required: ['licenseId'],
        invalidate: ['work.licenses.info'],
        method: 'POST',
        cache: false,
        url: '/sport_activities/update_program.json',
        data: function(arg) {
          var licenseId;
          licenseId = arg.licenseId;
          return {
            'data[CoachProgram][licence_id]': licenseId,
            'data[CoachProgram][active]': false
          };
        }
      },
      'work.trainerLicense.renew': {
        cache: false,
        invalidate: ['work.licenses.info'],
        method: 'POST',
        url: '/sport_activities/renew.json'
      },
      'work.work': {
        required: ['energy', 'companyId'],
        cache: false,
        invalidate: ['work.current', 'user.info.profession'],
        method: 'POST',
        url: '/users/begin_work.json',
        showLoader: false,
        data: function(arg) {
          var companyId, energy;
          energy = arg.energy, companyId = arg.companyId;
          return {
            'data[User][energy]': energy,
            'data[Company][id]': companyId
          };
        },
        after: function(options) {
          app.menu.view.reload(null, false);
          app.shortInfo.changeEnergy(-options.energy);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'work.beginWork': {
        required: ['energy', 'companyId'],
        invalidate: ['business.companyInfo', 'user.info', 'user.info.short'],
        cache: false,
        method: 'POST',
        url: '/users/begin_work_master.json',
        data: function(arg) {
          var companyId, energy;
          energy = arg.energy, companyId = arg.companyId;
          return {
            'data[User][energy]': energy,
            'data[Company][id]': companyId
          };
        },
        after: function(options) {
          app.menu.view.reload();
          app.shortInfo.changeEnergy(-options.energy);
          return app.shortInfo.view.reload();
        }
      },

      /*
      				Bussines
       */
      'business': {
        cacheValidityInMs: 30 * 1000,
        url: '/companies/user_companies_list.json'
      },
      'business.generateReport': {
        url: '/company_reports/generate_report.json',
        invalidate: ['business.getReports'],
        required: ['companyId', 'reportType'],
        method: 'POST',
        data: function(arg) {
          var companyId, reportType;
          companyId = arg.companyId, reportType = arg.reportType;
          return {
            'data[CompanyReport][companyId]': companyId,
            'data[CompanyReport][reportType]': reportType
          };
        }
      },
      'business.getReports': {
        cache: 30 * 1000,
        required: ['companyId'],
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/company_reports/get_reports/" + companyId + ".json";
        }
      },
      'business.hireBot': {
        url: '/company_bots/hire_bot.json',
        required: ['companyId', 'botType'],
        method: 'POST',
        data: function(arg) {
          var botType, companyId;
          companyId = arg.companyId, botType = arg.botType;
          return {
            'data[CompanyBot][companyId]': companyId,
            'data[CompanyBot][botType]': botType
          };
        }
      },
      'business.updateAccountant': {
        url: '/company_bots/update_accountant.json',
        required: ['companyId', 'sum'],
        method: 'POST',
        data: function(arg) {
          var companyId, sum;
          companyId = arg.companyId, sum = arg.sum;
          return {
            'data[CompanyBot][companyId]': companyId,
            'data[CompanyBot][sum]': sum
          };
        }
      },
      'business.updateLogistican': {
        url: '/company_bots/update_logistican.json',
        required: ['companyId', 'values'],
        method: 'POST',
        data: function(arg) {
          var companyId, values;
          companyId = arg.companyId, values = arg.values;
          return {
            'data[CompanyBot][companyId]': companyId,
            'data[CompanyBot][values]': values
          };
        }
      },
      'business.toggleActive': {
        url: '/company_bots/toggle_active.json',
        required: ['companyId', 'botType'],
        method: 'POST',
        data: function(arg) {
          var botType, companyId;
          companyId = arg.companyId, botType = arg.botType;
          return {
            'data[CompanyBot][companyId]': companyId,
            'data[CompanyBot][botType]': botType
          };
        }
      },
      'business.botLvlUp': {
        url: '/company_bots/lvl_up.json',
        required: ['companyId', 'botType'],
        method: 'POST',
        data: function(arg) {
          var botType, companyId;
          companyId = arg.companyId, botType = arg.botType;
          return {
            'data[CompanyBot][companyId]': companyId,
            'data[CompanyBot][botType]': botType
          };
        }
      },
      'business.addBlueprintToProduction': {
        url: '/companies/add_blueprint_to_production.json',
        required: ['companyId', 'userItemId'],
        method: 'POST',
        data: function(arg) {
          var companyId, userItemId;
          companyId = arg.companyId, userItemId = arg.userItemId;
          return {
            'data[Company][id]': companyId,
            'data[Company][user_item_id]': userItemId
          };
        }
      },
      'business.companyList': {
        cache: false,
        required: ['page'],
        url: function(arg) {
          var page;
          page = arg.page;
          return "/companies/user_companies_list/page:" + (page || 1) + ".json";
        }
      },
      'business.companyListShort': {
        cacheValidityInMs: 30 * 1000,
        url: '/companies/user_companies_list_short.json'
      },
      'business.corporationList': {
        cache: false,
        url: function(arg) {
          var page;
          page = arg.page;
          return "/corporations/corporation_list/page:" + (page || 1) + ".json";
        }
      },
      'business.corporationOpenPrice': {
        cache: 300 * 1000,
        url: '/corporations/get_corporation_open_price.json'
      },
      'business.companyInfo': {
        required: ['companyId'],
        cacheValidityInMs: 30 * 1000,
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/companies/info/" + companyId + ".json";
        }
      },
      'business.companyShortInfo': {
        required: ['companyId'],
        cacheValidityInMs: 30 * 1000,
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/companies/short_info/" + companyId + ".json";
        }
      },
      'business.сompanyWorkersInfo': {
        cache: false,
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/company_workers/workers_info/" + companyId + ".json";
        }
      },
      'business.сompanyWorkersList': {
        cache: false,
        required: ['companyId'],
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/company_workers/list_workers/" + companyId + ".json";
        }
      },
      'business.companyForeignWorkers': {
        cache: false,
        required: ['companyId'],
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/company_foreign_workers/available/" + companyId + ".json";
        }
      },
      'business.hireForeignWorkers': {
        cache: false,
        invalidate: ['business.сompanyWorkersInfo', 'business.сompanyWorkersList', 'business'],
        required: ['companyId', 'workerId', 'quantity'],
        method: 'POST',
        showLoader: false,
        url: function(arg) {
          var companyId, quantity, workerId;
          companyId = arg.companyId, workerId = arg.workerId, quantity = arg.quantity;
          return "/company_foreign_workers/add/" + companyId + "/" + workerId + "/" + quantity + ".json";
        }
      },
      'business.saveVacancy': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.сompanyWorkersInfo', 'business.companyList'],
        required: ['companyId', 'salary', 'level', 'is_hiring'],
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var companyId, is_hiring, level, salary;
          companyId = arg.companyId, salary = arg.salary, level = arg.level, is_hiring = arg.is_hiring;
          return {
            'data[CompanyVacancy][company_id]': companyId,
            'data[CompanyVacancy][salary]': salary,
            'data[CompanyVacancy][level]': level,
            'data[CompanyVacancy][is_hiring]': is_hiring
          };
        },
        url: "/vacancies/save_vacancy.json"
      },
      'business.addFundsVd': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.companyList'],
        required: ['companyId', 'amount'],
        showLoader: false,
        method: 'POST',
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[Company][amount_add]': amount
          };
        },
        url: "/companies/add_funds_vd.json",
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'business.addFundsVg': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.companyList'],
        required: ['companyId', 'amount'],
        showLoader: false,
        method: 'POST',
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[Company][amount_add]': amount
          };
        },
        url: "/companies/add_funds_vg.json",
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'business.company.transfer': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.companyList'],
        required: ['corporationId', 'companyId'],
        method: 'POST',
        data: function(arg) {
          var companyId, corporationId;
          corporationId = arg.corporationId, companyId = arg.companyId;
          return {
            'data[Corporation][id]': corporationId,
            'data[Company][id]': companyId
          };
        },
        url: "/companies/transfer.json"
      },
      'business.corporative_company.addFundsVd': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.corporationInfo'],
        required: ['companyId', 'amount'],
        method: 'POST',
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[Company][amount_add]': amount
          };
        },
        url: "/corporation_companies/add_funds_vd.json",
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'business.corporative_company.addFundsVg': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.corporationInfo'],
        required: ['companyId', 'amount'],
        method: 'POST',
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[Company][amount_add]': amount
          };
        },
        url: "/corporation_companies/add_funds_vg.json",
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'business.proposeDividents': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationVotes'],
        required: ['amount', 'currency', 'corporationId'],
        method: 'POST',
        data: function(arg) {
          var amount, corporationId, currency;
          amount = arg.amount, currency = arg.currency, corporationId = arg.corporationId;
          return {
            'data[Corporation][dividend_per_share]': amount,
            'data[Corporation][currency]': currency,
            'data[Corporation][id]': corporationId
          };
        },
        url: "/corporations/propose_dividends.json"
      },
      'business.proposeEmmision': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationVotes'],
        required: ['corporationId', 'amount'],
        method: 'POST',
        data: function(arg) {
          var amount, corporationId;
          corporationId = arg.corporationId, amount = arg.amount;
          return {
            'data[Corporation][id]': corporationId,
            'data[Corporation][emission]': amount
          };
        },
        url: "/corporations/propose_emission.json"
      },
      'business.proposeCorpRename': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationVotes', 'business.corporationList'],
        required: ['corporationId', 'name_ru', 'name_en'],
        method: 'POST',
        data: function(arg) {
          var corporationId, name_en, name_ru;
          corporationId = arg.corporationId, name_ru = arg.name_ru, name_en = arg.name_en;
          return {
            'data[Corporation][id]': corporationId,
            'data[Corporation][new_name_ru]': name_ru,
            'data[Corporation][new_name_en]': name_en
          };
        },
        url: "/corporations/rename_corporation.json"
      },
      'business.proposeChangeManagerUp': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationVotes'],
        required: ['corporationId', 'userId'],
        method: 'POST',
        data: function(arg) {
          var corporationId, userId;
          corporationId = arg.corporationId, userId = arg.userId;
          return {
            'data[Corporation][id]': corporationId,
            'data[Corporation][stockholder]': userId
          };
        },
        url: "/corporations/change_manager_up.json"
      },
      'business.proposeChangeManagerDown': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationVotes'],
        required: ['corporationId', 'userId'],
        method: 'POST',
        data: function(arg) {
          var corporationId, userId;
          corporationId = arg.corporationId, userId = arg.userId;
          return {
            'data[Corporation][id]': corporationId,
            'data[Corporation][manager]': userId
          };
        },
        url: "/corporations/change_manager_down.json"
      },
      'business.proposeCorpCompanyClose': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationVotes', 'business.corporationList'],
        required: ['corporationId', 'companyId'],
        method: 'POST',
        data: function(arg) {
          var companyId, corporationId;
          corporationId = arg.corporationId, companyId = arg.companyId;
          return {
            'data[Corporation][id]': corporationId,
            'data[Corporation][company_id]': companyId
          };
        },
        url: "/corporation_companies/close.json"
      },
      'business.stocksBuyoutAccept': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationList', 'user.info'],
        required: ['solutionId', 'corporationId'],
        method: 'POST',
        showLoader: false,
        url: function(arg) {
          var corporationId, solutionId;
          solutionId = arg.solutionId, corporationId = arg.corporationId;
          return "/corporations/buyout_stocks_accept/" + solutionId + "/" + corporationId + ".json";
        },
        after: function() {
          return app.shortInfo.view.reload();
        }
      },
      'business.stocksBuyoutReject': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationList'],
        required: ['solutionId', 'corporationId'],
        method: 'POST',
        showLoader: false,
        url: function(arg) {
          var corporationId, solutionId;
          solutionId = arg.solutionId, corporationId = arg.corporationId;
          return "/corporations/buyout_stocks_reject/" + solutionId + "/" + corporationId + ".json";
        }
      },
      'business.proposeStocksBuyout': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationList', 'user.info'],
        required: ['corporationId', 'currency', 'price'],
        method: 'POST',
        data: function(arg) {
          var currency, price, stockCount;
          currency = arg.currency, price = arg.price, stockCount = arg.stockCount;
          return {
            'data[Corporation][currency]': currency,
            'data[Corporation][price_per_stock]': price,
            'data[Corporation][stock_count]': stockCount
          };
        },
        url: function(arg) {
          var corporationId, shareholderId;
          corporationId = arg.corporationId, shareholderId = arg.shareholderId;
          return "/corporations/propose_stocks_buyout/" + corporationId + "/" + shareholderId + ".json";
        },
        after: function() {
          return app.shortInfo.view.reload();
        }
      },
      'business.proposeVotePositive': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationVotes', 'business.corporationList'],
        required: ['solutionId', 'corporationId'],
        method: 'POST',
        showLoader: false,
        url: function(arg) {
          var corporationId, solutionId;
          solutionId = arg.solutionId, corporationId = arg.corporationId;
          return "/corporations/vote_positive/" + solutionId + "/" + corporationId + ".json";
        }
      },
      'business.proposeVoteNegative': {
        cache: false,
        invalidate: ['business.corporationInfo', 'business.corporationVotes', 'business.corporationList'],
        required: ['solutionId', 'corporationId'],
        method: 'POST',
        showLoader: false,
        url: function(arg) {
          var corporationId, solutionId;
          solutionId = arg.solutionId, corporationId = arg.corporationId;
          return "/corporations/vote_negative/" + solutionId + "/" + corporationId + ".json";
        }
      },
      'business.getCorpRenamePrice': {
        cacheValidityInMs: 3000 * 1000,
        url: "/corporations/get_rename_price.json"
      },
      'business.getEmissionPrice': {
        cacheValidityInMs: 3000 * 1000,
        url: "/corporations/get_emission_price.json"
      },
      'business.editCompanyName': {
        cache: false,
        invalidate: ['business.companyInfo'],
        required: ['companyId', 'name'],
        method: 'POST',
        data: function(arg) {
          var companyId, name;
          companyId = arg.companyId, name = arg.name;
          return {
            'data[Company][id]': companyId,
            'data[Company][name]': name
          };
        },
        url: "/companies/edit_company_name.json"
      },
      'business.takeFundsVd': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.companyList'],
        required: ['companyId', 'amount'],
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[Company][amount_take]': amount
          };
        },
        url: "/companies/take_funds_vd.json"
      },
      'business.takeFundsVg': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.companyList'],
        required: ['companyId', 'amount'],
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[Company][amount_take]': amount
          };
        },
        url: "/companies/take_funds_vg.json"
      },
      'business.corporative_company.takeFundsVd': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.corporationInfo'],
        required: ['companyId', 'amount'],
        method: 'POST',
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[Company][amount_take]': amount
          };
        },
        url: "/corporation_companies/take_funds_vd.json"
      },
      'business.corporative_company.takeFundsVg': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.corporationInfo'],
        required: ['companyId', 'amount'],
        method: 'POST',
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[Company][amount_take]': amount
          };
        },
        url: "/corporation_companies/take_funds_vg.json"
      },
      'business.upLevel': {
        cache: false,
        invalidate: ['business', 'business.companyInfo', 'business.сompanyWorkersInfo'],
        required: ['companyId'],
        method: 'POST',
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/companies/up_level/" + companyId + ".json";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'business.corporative_company.upLevel': {
        cache: false,
        invalidate: ['business', 'business.companyInfo', 'business.сompanyWorkersInfo', 'business.corporationInfo'],
        required: ['companyId'],
        method: 'POST',
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/corporation_companies/up_level/" + companyId + ".json";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'business.upStorageLevel': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.storage', 'user.info.short'],
        required: ['companyId'],
        method: 'POST',
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/companies/up_storage_level/" + companyId + ".json";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'business.corporative_company.upStorageLevel': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.storage', 'user.info.short'],
        required: ['companyId'],
        method: 'POST',
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/corporation_companies/up_storage_level/" + companyId + ".json";
        }
      },
      'business.deleteWorker': {
        cache: false,
        invalidate: ['business.сompanyWorkersInfo', 'business.сompanyWorkersList', 'business.companyInfo', 'business'],
        required: ['workerId'],
        method: 'POST',
        url: function(arg) {
          var workerId;
          workerId = arg.workerId;
          return "/company_workers/delete_worker/" + workerId + ".json";
        }
      },
      'business.deleteForeignWorker': {
        cache: false,
        invalidate: ['business.сompanyWorkersInfo', 'business.сompanyWorkersList'],
        required: ['companyId', 'workerId', 'quantity'],
        method: 'POST',
        url: function(arg) {
          var companyId, quantity, workerId, workerTypeId;
          companyId = arg.companyId, workerTypeId = arg.workerTypeId, workerId = arg.workerId, quantity = arg.quantity;
          return "/company_foreign_workers/delete/" + companyId + "/" + workerTypeId + "/" + workerId + "/" + quantity + ".json";
        }
      },
      'business.ForeignWorkerTotalSallary': {
        cache: false,
        required: ['companyId', 'workerId'],
        method: 'GET',
        url: function(arg) {
          var companyId, workerId, workerTypeId;
          companyId = arg.companyId, workerTypeId = arg.workerTypeId, workerId = arg.workerId;
          return "/company_foreign_workers/total_worker_sallary/" + companyId + "/" + workerTypeId + "/" + workerId + ".json";
        }
      },
      'business.storage': {
        cache: false,
        required: ['companyId'],
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/company_items/storage/" + companyId + ".json";
        }
      },
      'business.moveItemsToCompany': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.storage'],
        required: ['companyId', 'itemTypeId', 'quantity'],
        method: 'POST',
        url: function(arg) {
          var companyId, itemTypeId, quantity;
          companyId = arg.companyId, itemTypeId = arg.itemTypeId, quantity = arg.quantity;
          return "/user_items/move_items_to_company/" + companyId + "/" + itemTypeId + "/" + quantity + ".json";
        }
      },
      'business.moveItemsFromCorporation': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.storage', 'business.corporationStorage.byCompany'],
        required: ['companyId', 'itemTypeId', 'quantity'],
        method: 'POST',
        url: function(arg) {
          var companyId, itemTypeId, quantity;
          companyId = arg.companyId, itemTypeId = arg.itemTypeId, quantity = arg.quantity;
          return "/corporation_items/move_items_to_company/" + companyId + "/" + itemTypeId + "/" + quantity + ".json";
        }
      },
      'business.moveItemsToUser': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.storage', 'inventory', 'inventory.furniture'],
        required: ['companyId', 'itemTypeId', 'quantity'],
        method: 'POST',
        url: function(arg) {
          var companyId, itemTypeId, quantity;
          companyId = arg.companyId, itemTypeId = arg.itemTypeId, quantity = arg.quantity;
          return "/company_items/move_items_to_user/" + companyId + "/" + itemTypeId + "/" + quantity + ".json";
        }
      },
      'business.moveItemsToCorporation': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.storage', 'business.corporationStorage.byCompany'],
        required: ['companyId', 'itemTypeId', 'quantity'],
        method: 'POST',
        url: function(arg) {
          var companyId, itemTypeId, quantity;
          companyId = arg.companyId, itemTypeId = arg.itemTypeId, quantity = arg.quantity;
          return "/company_items/move_items_to_corporation/" + companyId + "/" + itemTypeId + "/" + quantity + ".json";
        }
      },
      'business.moveItemsFromCityToCompany': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.storage', 'cityHall.storage'],
        required: ['companyId', 'itemTypeId', 'quantity'],
        method: 'POST',
        url: function(arg) {
          var companyId, itemTypeId, quantity;
          companyId = arg.companyId, itemTypeId = arg.itemTypeId, quantity = arg.quantity;
          return "/city_items/move_items_to_company/" + companyId + "/" + itemTypeId + "/" + quantity + ".json";
        }
      },
      'business.moveItemsToCity': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.storage', 'cityHall.storage'],
        required: ['companyId', 'itemTypeId', 'quantity'],
        method: 'POST',
        url: function(arg) {
          var companyId, itemTypeId, quantity;
          companyId = arg.companyId, itemTypeId = arg.itemTypeId, quantity = arg.quantity;
          return "/company_items/move_items_to_city/" + companyId + "/" + itemTypeId + "/" + quantity + ".json";
        }
      },
      'business.corporationInfo': {
        cacheValidityInMs: 300 * 1000,
        required: ['corporationId'],
        url: function(arg) {
          var corporationId;
          corporationId = arg.corporationId;
          return "/corporations/corporation_office/" + corporationId + ".json";
        }
      },
      'business.corporationDividends': {
        cacheValidityInMs: 300 * 1000,
        required: ['corporationId'],
        url: function(arg) {
          var corporationId, limit;
          corporationId = arg.corporationId, limit = arg.limit;
          return "/corporations/corporation_dividends/" + corporationId + "/" + limit + ".json";
        }
      },
      'business.corporationShortInfo': {
        cacheValidityInMs: 300 * 1000,
        required: ['corporationId'],
        url: function(arg) {
          var corporationId;
          corporationId = arg.corporationId;
          return "/corporations/corporation_short_info/" + corporationId + ".json";
        }
      },
      'business.corporationVotes': {
        cache: false,
        required: ['corporationId'],
        url: function(arg) {
          var corporationId;
          corporationId = arg.corporationId;
          return "/corporations/corporation_votes/" + corporationId + ".json";
        }
      },
      'business.corporationStorage': {
        cache: false,
        required: ['corporationId'],
        url: function(arg) {
          var corporationId;
          corporationId = arg.corporationId;
          return "/corporation_items/storage/" + corporationId + ".json";
        }
      },
      'business.corporationStorage.byCompany': {
        cache: false,
        required: ['companyId'],
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/corporation_items/storage_by_company/" + companyId + ".json";
        }
      },
      'business.shareHolders': {
        cacheValidityInMs: 300 * 1000,
        required: ['corporationId'],
        url: function(arg) {
          var corporationId;
          corporationId = arg.corporationId;
          return "/corporations/corporation_stockholders/" + corporationId + ".json";
        }
      },
      'business.searchManager': {
        cache: false,
        required: ['page'],
        url: function(arg) {
          var name, page;
          page = arg.page, name = arg.name;
          return "/companies/search_manager.json?page=" + (page || 1) + "&name=" + (name || '-');
        }
      },
      'business.corporative_company.searchManager': {
        cache: false,
        required: ['companyId'],
        url: function(arg) {
          var companyId, name, page;
          page = arg.page, companyId = arg.companyId, name = arg.name;
          return "/corporation_companies/search_manager.json?company_id=" + companyId + "&page=" + (page || 1) + "&name=" + (name || '-');
        }
      },
      'business.setManager': {
        cache: false,
        invalidate: ['business.сompanyWorkersInfo'],
        required: ['managerId', 'companyId'],
        method: 'POST',
        data: function(arg) {
          var companyId, managerId;
          managerId = arg.managerId, companyId = arg.companyId;
          return {
            'data[Company][manager_id]': managerId,
            'data[Company][id]': companyId
          };
        },
        url: "/companies/set_manager.json"
      },
      'business.corporative_company.setManager': {
        cache: false,
        invalidate: ['business.сompanyWorkersInfo'],
        required: ['managerId', 'companyId'],
        method: 'POST',
        data: function(arg) {
          var companyId, managerId;
          managerId = arg.managerId, companyId = arg.companyId;
          return {
            'data[Company][manager_id]': managerId,
            'data[Company][id]': companyId
          };
        },
        url: "/corporation_companies/set_manager.json"
      },
      'business.setProduction': {
        cache: false,
        invalidate: ['business.companyInfo', 'business.companyList'],
        required: ['companyId', 'itemId'],
        method: 'POST',
        data: function(arg) {
          var companyId, itemId;
          companyId = arg.companyId, itemId = arg.itemId;
          return {
            'data[Company][id]': companyId,
            'data[Company][current_production]': itemId
          };
        },
        url: "/companies/set_production.json"
      },
      'business.getProductionList': {
        cache: false,
        invalidate: ['business.companyInfo', 'business'],
        required: ['companyId'],
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/companies/production_list/" + companyId + ".json";
        }
      },
      'business.getCompanyTypeList': {
        cache: false,
        url: "/companies/getCompanyTypes.json"
      },
      'business.getProductionListCompanyType': {
        url: "/companies/production_list_company_type.json"
      },
      'business.createCompany': {
        cache: false,
        invalidate: ['business.companyList'],
        required: ['type', 'name'],
        method: 'POST',
        data: function(arg) {
          var currency, itemId, name, type;
          type = arg.type, name = arg.name, currency = arg.currency, itemId = arg.itemId;
          return {
            'data[CompanyType][type]': type,
            'data[CompanyType][name]': name,
            'data[CompanyType][currency]': currency,
            'data[CompanyType][itemId]': itemId
          };
        },
        url: "/companies/create_new.json",
        after: function() {
          return app.shortInfo.view.reload();
        }
      },
      'business.createCorporationCompany': {
        cache: false,
        required: ['corporationId', 'type', 'name'],
        invalidate: ['business.corporationInfo', 'business.corporationList'],
        method: 'POST',
        data: function(arg) {
          var corporationId, currency, itemId, name, type;
          corporationId = arg.corporationId, type = arg.type, name = arg.name, currency = arg.currency, itemId = arg.itemId;
          return {
            'data[CompanyType][corporation_master]': corporationId,
            'data[CompanyType][id]': type,
            'data[CompanyType][name]': name,
            'data[CompanyType][currency]': currency,
            'data[CompanyType][itemId]': itemId
          };
        },
        url: "/corporation_companies/create.json"
      },
      'business.createCorporation': {
        cache: false,
        invalidate: ['business.corporationList'],
        required: ['name_ru', 'name_en', 'logo'],
        method: 'POST',
        data: function(arg) {
          var logo, name_en, name_ru;
          name_ru = arg.name_ru, name_en = arg.name_en, logo = arg.logo;
          return {
            'data[Corporation][name_ru]': name_ru,
            'data[Corporation][name_en]': name_en,
            'data[Corporation][logo]': logo
          };
        },
        url: "/corporations/create.json"
      },
      'business.corporationInvestVd': {
        cache: false,
        invalidate: ['business.corporationInfo'],
        required: ['corporationId', 'amount'],
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, corporationId;
          corporationId = arg.corporationId, amount = arg.amount;
          return {
            'data[Corporation][id]': corporationId,
            'data[Corporation][vd_invest]': amount
          };
        },
        url: "/corporations/invest_vd.json",
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'business.corporationInvestVg': {
        cache: false,
        invalidate: ['business.corporationInfo'],
        required: ['corporationId', 'amount'],
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, corporationId;
          corporationId = arg.corporationId, amount = arg.amount;
          return {
            'data[Corporation][id]': corporationId,
            'data[Corporation][vg_invest]': amount
          };
        },
        url: "/corporations/invest_vg.json",
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'business.itemInfo': {
        cache: false,
        required: ['itemTypeId'],
        url: function(arg) {
          var itemTypeId;
          itemTypeId = arg.itemTypeId;
          return "/company_items/get_info/" + itemTypeId + ".json";
        }
      },
      'business.company.effects': {
        cache: false,
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          if (companyId != null) {
            return "/companies/effects/" + companyId + ".json";
          } else {
            return "/companies/effects.json";
          }
        }
      },
      'corporation.itemInfo': {
        cache: false,
        required: ['itemTypeId'],
        url: function(arg) {
          var itemTypeId;
          itemTypeId = arg.itemTypeId;
          return "/corporation_items/get_info/" + itemTypeId + ".json";
        }
      },

      /*
      				Quests
       */
      'quests': {
        cache: false,
        url: '/quests/quests/user_quests.json'
      },
      'quests.info': {
        cacheValidityInMs: 300 * 1000,
        required: ['questId'],
        url: function(arg) {
          var questId;
          questId = arg.questId;
          return "/quests/quests/info/" + questId + ".json";
        },
        gaPostfix: function() {
          return 'postfix';
        }
      },
      'quests.takeQuest': {
        cache: false,
        required: ['questId'],
        invalidate: ['quests', 'quests.info', 'inventory'],
        method: 'POST',
        url: function(arg) {
          var questId;
          questId = arg.questId;
          return "/quests/quests/take/" + questId + ".json";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'quests.completeQuest': {
        cache: false,
        required: ['questId'],
        invalidate: ['quests', 'quests.info', 'inventory'],
        method: 'POST',
        url: function(arg) {
          var questId;
          questId = arg.questId;
          return "/quests/quests/complete/" + questId + ".json";
        },
        vpageUrl: function(arg) {
          var questId;
          questId = arg.questId;
          return "/api/quests/quests/complete/" + questId;
        },
        after: function() {
          app.quests.clearCache();
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'quests.check_completed': {
        cache: false,
        required: ['cid'],
        url: function(arg) {
          var cid;
          cid = arg.cid;
          return "/quests/quests/check_completed.json?cid=" + cid;
        },
        vpageUrl: function(arg) {
          var cid;
          cid = arg.cid;
          return "/api/quests/quests/check_completed/" + cid;
        }
      },

      /*
      			events
       */
      'events.ot': {
        cache: false,
        url: "/prestige_wars/view.json"
      },
      'events.ot.silent': {
        cacheValidityInMs: 300 * 1000,
        url: "/prestige_wars/silent_view.json"
      },
      'events.ot.kick': {
        cache: false,
        required: ['teamId'],
        invalidate: ['events.ot', 'house.info'],
        url: function(arg) {
          var teamId;
          teamId = arg.teamId;
          return "/prestige_wars/kick.json";
        },
        method: 'POST',
        data: function(arg) {
          var teamId;
          teamId = arg.teamId;
          return {
            'data[PrestigeWarTeam][id]': teamId
          };
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'events.bb': {
        cache: false,
        url: '/big_fights/view.json'
      },
      'events.bb.silent': {
        cacheValidityInMs: 300 * 1000,
        url: '/big_fights/silent_view.json'
      },
      'events.bb.kick': {
        cache: false,
        required: ['bbId'],
        invalidate: ['events.bb', 'house.info'],
        url: function(arg) {
          var bbId;
          bbId = arg.bbId;
          return "/big_fights/kick.json";
        },
        method: 'POST',
        data: function(arg) {
          var bbId;
          bbId = arg.bbId;
          return {
            'data[BigFight][id]': bbId
          };
        },
        showLoader: false,
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'events.election.silent': {
        cacheValidityInMs: 120 * 1000,
        url: '/city_elections/silent_view.json'
      },

      /*
      				CityHall
       */
      'cityHall': {
        cacheValidityInMs: 30 * 1000,
        url: '/city_hall/info.json'
      },
      'cityHall.activeCitizensCount': {
        cacheValidityInMs: 30 * 1000,
        url: '/city_hall/getActiveCitizensCount.json'
      },
      'cityHall.cups': {
        cacheValidityInMs: 60 * 1000,
        url: '/city_hall/cups.json'
      },
      'cityHall.titles': {
        cacheValidityInMs: 300 * 1000,
        url: '/city_hall/titles.json'
      },
      'cityHall.government': {
        cacheValidityInMs: 300 * 1000,
        url: '/city_hall/goverment.json'
      },
      'cityHall.bills': {
        cache: false,
        url: '/city_bills/all.json'
      },
      'cityHall.areasTakeover.bills': {
        cache: false,
        url: '/areas_takeover/bills/all.json'
      },
      'cityHall.voteForBill': {
        invalidate: ['cityHall.bills', 'cityHall'],
        required: ['billId'],
        method: 'POST',
        url: function(arg) {
          var billId;
          billId = arg.billId;
          return "/city_bills/vote_positive/" + billId + ".json";
        }
      },
      'cityHall.voteForInitiative': {
        invalidate: ['cityHall.bills', 'cityHall'],
        required: ['billId'],
        method: 'POST',
        url: function(arg) {
          var billId;
          billId = arg.billId;
          return "/city_bills/vote_initiative_positive/" + billId + ".json";
        }
      },
      'cityHall.areasTakeover.vote': {
        invalidate: ['cityHall.areasTakeover.bills', 'cityHall'],
        cache: false,
        required: ['billId', 'vote'],
        method: 'POST',
        data: function(arg) {
          var billId, vote;
          billId = arg.billId, vote = arg.vote;
          return {
            'data[AreasTakeoverBill][id]': billId,
            'data[AreasTakeoverBill][vote]': vote
          };
        },
        url: "/areas_takeover/bills/vote.json"
      },
      'cityHall.voteAgainstBill': {
        invalidate: ['cityHall.bills', 'cityHall'],
        cache: false,
        required: ['billId'],
        method: 'POST',
        url: function(arg) {
          var billId;
          billId = arg.billId;
          return "/city_bills/vote_negative/" + billId + ".json";
        }
      },
      'cityHall.voteAgainstInitiative': {
        invalidate: ['cityHall.bills', 'cityHall'],
        cache: false,
        required: ['billId'],
        method: 'POST',
        url: function(arg) {
          var billId;
          billId = arg.billId;
          return "/city_bills/vote_initiative_negative/" + billId + ".json";
        }
      },
      'cityHall.itemsBills': {
        url: '/city_hall/city_items_consideration.json'
      },
      'cityHall.voteForItemBill': {
        invalidate: ['cityHall.itemsBills', 'cityHall'],
        required: ['billId'],
        method: 'POST',
        url: function(arg) {
          var billId;
          billId = arg.billId;
          return "/city_item_proposal_votes/vote_positive/" + billId + ".json";
        }
      },
      'cityHall.voteAgainstItemBill': {
        invalidate: ['cityHall.itemsBills', 'cityHall'],
        cache: false,
        required: ['billId'],
        method: 'POST',
        url: function(arg) {
          var billId;
          billId = arg.billId;
          return "/city_item_proposal_votes/vote_negative/" + billId + ".json";
        }
      },
      'cityHall.companies': {
        cacheValidityInMs: 300 * 1000,
        url: '/state_companies/all.json'
      },
      'cityHall.createCompany': {
        cache: false,
        invalidate: ['cityHall.companies'],
        required: ['type', 'name'],
        method: 'POST',
        data: function(arg) {
          var currency, itemId, name, type;
          type = arg.type, name = arg.name, currency = arg.currency, itemId = arg.itemId;
          return {
            'data[CompanyType][type]': type,
            'data[CompanyType][name]': name,
            'data[CompanyType][currency]': currency,
            'data[CompanyType][itemId]': itemId
          };
        },
        url: "/state_companies/create_new.json"
      },
      'cityHall.company.upStorageLevel': {
        cache: false,
        required: ['companyId'],
        method: 'POST',
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/state_companies/up_storage_level/" + companyId + ".json";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'cityHall.storage.itemInfo': {
        cache: false,
        required: ['itemTypeId'],
        url: function(arg) {
          var itemTypeId;
          itemTypeId = arg.itemTypeId;
          return "/city_items/get_item_info/" + itemTypeId + ".json";
        }
      },
      'cityHall.billList': {
        cache: false,
        url: '/city_bills/bill_list.json'
      },
      'cityHall.newBill': {
        invalidate: ['cityHall', 'cityHall.bills'],
        required: ['billId', 'amount'],
        method: 'POST',
        showLoader: false,
        data: function(arg) {
          var amount, billId, description;
          billId = arg.billId, amount = arg.amount, description = arg.description;
          return {
            'data[CityValue][id]': billId,
            'data[CityValue][value]': amount,
            'data[CityValue][short_description]': description
          };
        },
        url: "/city_bills/add.json"
      },
      'cityHall.initiative': {
        cache: false,
        required: ['billId'],
        url: function(arg) {
          var billId;
          billId = arg.billId;
          return "/city_bills/view_bill/" + billId + ".json";
        }
      },
      'cityHall.initiative.addComment': {
        cache: false,
        invalidate: ['cityHall.initiative'],
        required: ['billId', 'body'],
        method: 'POST',
        data: function(arg) {
          var billId, body;
          billId = arg.billId, body = arg.body;
          return {
            'data[BillComment][bill_id]': billId,
            'data[BillComment][body]': body
          };
        },
        url: "/city_bill_comments/add_comment.json"
      },
      'cityHall.initiative.update': {
        cache: false,
        invalidate: ['cityHall.initiative'],
        required: ['billId', 'amount'],
        method: 'POST',
        data: function(arg) {
          var amount, description;
          amount = arg.amount, description = arg.description;
          return {
            'data[Bill][value]': amount,
            'data[Bill][short_description]': description
          };
        },
        url: function(arg) {
          var billId;
          billId = arg.billId;
          return "/city_bills/edit_initiative/" + billId + ".json";
        }
      },
      'cityHall.comment.delete': {
        cache: false,
        required: ['billId', 'commentId'],
        invalidate: ['cityHall.initiative'],
        method: 'POST',
        url: function(arg) {
          var billId, commentId;
          billId = arg.billId, commentId = arg.commentId;
          return "/city_bill_comments/delete_comment/" + billId + "/" + commentId + ".json";
        }
      },
      'cityHall.comment.edit': {
        cache: false,
        required: ['billId', 'commentId'],
        method: 'GET',
        url: function(arg) {
          var billId, commentId;
          billId = arg.billId, commentId = arg.commentId;
          return "/city_bill_comments/edit_comment/" + billId + "/" + commentId + ".json";
        }
      },
      'cityHall.comment.update': {
        cache: false,
        invalidate: ['cityHall.initiative'],
        required: ['billId', 'commentId', 'body'],
        method: 'POST',
        data: function(arg) {
          var body;
          body = arg.body;
          return {
            'data[BillComment][body]': body
          };
        },
        url: function(arg) {
          var billId, commentId;
          billId = arg.billId, commentId = arg.commentId;
          return "/city_bill_comments/edit_comment/" + billId + "/" + commentId + ".json";
        }
      },
      'cityHall.companyInfo': {
        required: ['companyId'],
        url: function(arg) {
          var companyId;
          companyId = arg.companyId;
          return "/companies/info/" + companyId + ".json";
        }
      },
      'cityHall.donate': {
        cache: false,
        invalidate: ['cityHall'],
        required: ['cityId', 'amount', 'currency'],
        method: 'POST',
        data: function(arg) {
          var amount, cityId, currency;
          cityId = arg.cityId, amount = arg.amount, currency = arg.currency;
          return {
            'data[CityHall][id]': cityId,
            'data[CityHall][amount]': amount,
            'data[CityHall][currency]': currency
          };
        },
        url: "/city_hall/donate_money.json",
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'cityHall.addFunds': {
        invalidate: ['business.companyInfo', 'cityHall'],
        required: ['companyId', 'amount'],
        method: 'POST',
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[StateCompany][amount_add]': amount
          };
        },
        url: "/state_companies/add_funds.json"
      },
      'cityHall.takeFunds': {
        invalidate: ['business.companyInfo', 'cityHall'],
        required: ['companyId', 'amount'],
        method: 'POST',
        data: function(arg) {
          var amount, companyId;
          companyId = arg.companyId, amount = arg.amount;
          return {
            'data[Company][id]': companyId,
            'data[StateCompany][amount_take]': amount
          };
        },
        url: "/state_companies/take_funds.json"
      },
      'cityHall.evolutionActive': {
        cacheValidityInMs: 30 * 1000,
        url: '/city_evolutions/active.json'
      },
      'cityHall.evolutionTree': {
        cacheValidityInMs: 300 * 1000,
        url: '/city_evolutions/tree.json'
      },
      'cityHall.evolutionInfo': {
        required: ['evolutionId'],
        method: 'GET',
        url: function(arg) {
          var evolutionId;
          evolutionId = arg.evolutionId;
          return "/city_evolutions/info/" + evolutionId + ".json";
        }
      },
      'cityHall.evolutionVotes': {
        cache: false,
        url: '/city_evolution_votes/show.json'
      },
      'cityHall.evolutionStartVoting': {
        cache: false,
        invalidate: ['cityHall.evolutionActive', 'cityHall.evolutionTree', 'cityHall.evolutionVotes'],
        required: ['evolutionId'],
        method: 'POST',
        data: function(arg) {
          var evolutionId;
          evolutionId = arg.evolutionId;
          return {
            'data[Evolution][id]': evolutionId
          };
        },
        url: '/city_evolution_votes/start_voting.json'
      },
      'cityHall.evolutionVote': {
        cache: false,
        invalidate: ['cityHall.evolutionActive', 'cityHall.evolutionTree', 'cityHall.evolutionVotes'],
        required: ['cityEvolutionId', 'vote'],
        method: 'POST',
        data: function(arg) {
          var cityEvolutionId, vote;
          cityEvolutionId = arg.cityEvolutionId, vote = arg.vote;
          return {
            'data[CityEvolutionVote][city_evolution_id]': cityEvolutionId,
            'data[CityEvolutionVote][vote]': vote
          };
        },
        url: '/city_evolution_votes/add.json'
      },
      'cityHall.buyout': {
        required: ['itemTypeId', 'amount', 'price', 'currency'],
        cache: false,
        invalidate: [],
        url: '/city_item_proposals/add.json',
        method: 'POST',
        data: function(arg) {
          var amount, currency, itemTypeId, price;
          itemTypeId = arg.itemTypeId, amount = arg.amount, price = arg.price, currency = arg.currency;
          return {
            'data[CityItemProposal][item_type_id]': itemTypeId,
            'data[CityItemProposal][need]': amount,
            'data[CityItemProposal][price]': price,
            'data[CityItemProposal][currency]': currency
          };
        }
      },
      'cityHall.mayorElection.info': {
        cacheValidityInMs: 30 * 1000,
        invalidate: [],
        url: '/city_mayor_elections/info.json'
      },
      'cityHall.mayorElection.candidates': {
        cacheValidityInMs: 30 * 1000,
        invalidate: [],
        url: '/city_mayor_elections/candidate_list.json'
      },
      'cityHall.snapElection.vote': {
        cache: false,
        invalidate: ['cityHall.government'],
        required: ['type'],
        method: 'POST',
        data: function(arg) {
          var type;
          type = arg.type;
          return {
            'data[Election][type]': type
          };
        },
        url: '/city_elections/snap_election.json'
      },
      'cityHall.mayorElectionAddCandidate': {
        cache: false,
        invalidate: ['cityHall.mayorElection.candidates'],
        method: 'POST',
        url: '/city_mayor_elections/add.json'
      },
      'cityHall.mayorElection.vote': {
        cache: false,
        invalidate: ['cityHall.mayorElection.candidates'],
        required: ['candidateId'],
        method: 'POST',
        data: function(arg) {
          var candidateId;
          candidateId = arg.candidateId;
          return {
            'data[CityMayorElection][candidate_id]': candidateId
          };
        },
        url: '/city_mayor_elections/vote.json'
      },
      'cityHall.cityItemProposals': {
        cache: false,
        method: 'GET',
        url: '/city_item_proposals/show.json'
      },
      'cityHall.deleteCityItemProposal': {
        cache: false,
        required: ['cityItemProposalId'],
        invalidate: ['cityHall.cityItemProposals'],
        method: 'POST',
        url: function(arg) {
          var cityItemProposalId;
          cityItemProposalId = arg.cityItemProposalId;
          return "/city_item_proposals/delete_proposal/" + cityItemProposalId + ".json";
        }
      },
      'cityHall.pauseCityItemProposal': {
        cache: false,
        required: ['cityItemProposalId'],
        invalidate: ['cityHall.cityItemProposals'],
        method: 'POST',
        url: function(arg) {
          var cityItemProposalId;
          cityItemProposalId = arg.cityItemProposalId;
          return "/city_item_proposals/pause/" + cityItemProposalId + ".json";
        }
      },
      'cityHall.storage': {
        cache: false,
        url: "/city_items/storage.json"
      },
      'cityHall.effects': {
        cacheValidityInMs: 30 * 1000,
        url: "/city_hall/effects.json"
      },
      'cityHall.last_signups': {
        cache: false,
        cacheValidityInMs: 60 * 1000,
        url: "/city_hall/last_signups.json"
      },

      /*
      				News
       */
      'news.userSubscriptions': {
        cache: false,
        required: ['page'],
        url: function(arg) {
          var page;
          page = arg.page;
          return "/newspaper_posts/subscriptions/page:" + page + ".json";
        }
      },
      'news.latest': {
        cacheValidityInMs: 30 * 1000,
        required: ['page'],
        url: function(arg) {
          var page;
          page = arg.page;
          return "/newspaper_posts/latest/page:" + page + ".json";
        }
      },
      'news.allNews': {
        cacheValidityInMs: 30 * 1000,
        url: '/newspaper_posts/all.json'
      },
      'news.recommendations': {
        cacheValidityInMs: 30 * 1000,
        required: ['page'],
        url: function(arg) {
          var page;
          page = arg.page;
          return "/newspaper_posts/all_recommendations/page:" + page + ".json";
        }
      },
      'news.all_in_one_request': {
        cacheValidityInMs: 30 * 1000,
        url: '/newspaper_posts/all_in_one_request.json'
      },
      'news.newspaper': {
        cacheValidityInMs: 30 * 1000,
        url: function(arg) {
          var newspaperSlug;
          newspaperSlug = arg.newspaperSlug;
          return "/newspaper_posts/index/" + newspaperSlug + ".json";
        }
      },
      'news.post': {
        cache: false,
        invalidate: ['news.unreadPosts', 'news.unreadFamousPosts', 'news.unreadPostsMenu', 'news.allNews', 'news.recommendations', 'news.newspaper', 'news.userSubscriptions', 'news.latestUnreadPost', 'news.all_in_one_request'],
        url: function(arg) {
          var postId;
          postId = arg.postId;
          return "/newspaper_posts/view_post/" + postId + ".json";
        }
      },
      'news.unreadPostsMenu': {
        cacheValidityInMs: 300 * 1000,
        url: '/newspaper_posts/unread_count.json'
      },
      'news.unreadPosts': {
        cache: false,
        url: '/newspaper_posts/unread_subscription_count.json'
      },
      'news.unreadFamousPosts': {
        cache: false,
        url: '/newspaper_posts/unread_famous_count.json'
      },
      'news.latestPost': {
        cache: false,
        url: "/newspapers/latest_subscriptions_post.json"
      },
      'news.latestUnreadPost': {
        cacheValidityInMs: 300 * 1000,
        url: "/newspapers/latest_unread_post.json"
      },
      'news.userNewspaper': {
        required: ['page'],
        url: function(arg) {
          var page;
          page = arg.page;
          return "/newspapers/mynewspaper/page:" + page + ".json";
        }
      },
      'news.getOpenPrice': {
        cacheValidityInMs: 300 * 1000,
        url: "/newspapers/get_open_price.json"
      },
      'news.openNewspaper': {
        cache: false,
        invalidate: ['news.userNewspaper'],
        required: ['newspaperName'],
        method: 'POST',
        data: function(arg) {
          var newspaperName;
          newspaperName = arg.newspaperName;
          return {
            'data[Newspaper][name]': newspaperName
          };
        },
        url: "/newspapers/create_newspaper.json"
      },
      'news.createArticle': {
        before: function() {
          return app.showLoader();
        },
        after: function() {
          return app.hideLoader();
        },
        cache: false,
        invalidate: ['news.userNewspaper'],
        method: 'POST',
        data: function(arg) {
          var body, mainQuote, shortBody, title;
          title = arg.title, shortBody = arg.shortBody, mainQuote = arg.mainQuote, body = arg.body;
          return {
            'data[NewspaperPost][title]': title,
            'data[NewspaperPost][short_body]': shortBody,
            'data[NewspaperPost][main_quote]': mainQuote,
            'data[NewspaperPost][body]': body
          };
        },
        url: "/newspaper_posts/create_post.json"
      },
      'news.editArticle': {
        cache: false,
        invalidate: ['news.userNewspaper'],
        method: 'POST',
        data: function(arg) {
          var body, mainQuote, postId, shortBody, title;
          postId = arg.postId, title = arg.title, shortBody = arg.shortBody, mainQuote = arg.mainQuote, body = arg.body;
          return {
            'data[NewspaperPost][id]': postId,
            'data[NewspaperPost][title]': title,
            'data[NewspaperPost][short_body]': shortBody,
            'data[NewspaperPost][main_quote]': mainQuote,
            'data[NewspaperPost][body]': body
          };
        },
        url: "/newspaper_posts/edit_post.json"
      },
      'news.editNewspaper': {
        cache: false,
        invalidate: ['news.userNewspaper'],
        method: 'POST',
        data: function(arg) {
          var name;
          name = arg.name;
          return {
            'data[Newspaper][name]': name
          };
        },
        url: "/newspapers/edit.json"
      },
      'news.deleteNewspaper': {
        cache: false,
        invalidate: ['news.userNewspaper'],
        method: 'POST',
        url: "/newspapers/delete.json"
      },
      'news.add_like': {
        cache: false,
        invalidate: ['news.userNewspaper', 'news.userSubscriptions', 'news.allNews', 'news.recommendations', 'news.latestUnreadPost', 'news.unreadPostsMenu', 'news.unreadFamousPosts', 'news.unreadPosts', 'news.all_in_one_request'],
        method: 'POST',
        url: function(arg) {
          var postId;
          postId = arg.postId;
          return "/newspaper_posts/add_like/" + postId + ".json";
        }
      },
      'news.addComment': {
        cache: false,
        invalidate: ['news.userNewspaper', 'news.userSubscriptions', 'news.allNews', 'news.recommendations'],
        required: ['postId', 'body'],
        method: 'POST',
        data: function(arg) {
          var body, postId;
          postId = arg.postId, body = arg.body;
          return {
            'data[NewspaperPostComment][newspaper_post_id]': postId,
            'data[NewspaperPostComment][body]': body
          };
        },
        url: "/newspaper_post_comments/add_comment.json"
      },
      'news.comment.delete': {
        cache: false,
        required: ['commentId'],
        invalidate: ['news.userNewspaper', 'news.userSubscriptions', 'news.allNews', 'news.recommendations', 'news.post'],
        method: 'POST',
        url: function(arg) {
          var commentId;
          commentId = arg.commentId;
          return "/newspaper_post_comments/delete_comment/" + commentId + ".json";
        }
      },
      'news.comment.edit': {
        cache: false,
        required: ['commentId'],
        method: 'GET',
        url: function(arg) {
          var commentId;
          commentId = arg.commentId;
          return "/newspaper_post_comments/edit_comment/" + commentId + ".json";
        }
      },
      'news.comment.update': {
        cache: false,
        invalidate: ['news.userNewspaper', 'news.userSubscriptions', 'news.allNews', 'news.recommendations', 'news.post'],
        required: ['commentId', 'body'],
        method: 'POST',
        data: function(arg) {
          var body;
          body = arg.body;
          return {
            'data[NewspaperPostComment][body]': body
          };
        },
        url: function(arg) {
          var commentId;
          commentId = arg.commentId;
          return "/newspaper_post_comments/edit_comment/" + commentId + ".json";
        }
      },
      'news.subscribe': {
        cache: false,
        invalidate: ['news.userSubscriptions', 'news.allNews', 'news.recommendations', 'news.newspaper'],
        method: 'POST',
        url: function(arg) {
          var newspaperId;
          newspaperId = arg.newspaperId;
          return "/newspapers/subscribe/" + newspaperId + ".json";
        }
      },
      'news.unsubscribe': {
        cache: false,
        invalidate: ['news.userSubscriptions', 'news.allNews', 'news.recommendations', 'news.newspaper'],
        method: 'POST',
        url: function(arg) {
          var subscriptionId;
          subscriptionId = arg.subscriptionId;
          return "/newspapers/delete_subscription/" + subscriptionId + ".json";
        }
      },
      'news.postSearch': {
        cache: false,
        required: ['title'],
        url: function(arg) {
          var title;
          title = arg.title;
          return "/newspaper_posts/post_search_ajax/" + title + ".json";
        }
      },
      'news.donate': {
        cache: false,
        invalidate: ['user.info', 'user.info.short'],
        method: 'POST',
        required: ['user_id', 'vgold', 'vdollar'],
        data: function(arg) {
          var user_id, vdollar, vgold;
          user_id = arg.user_id, vgold = arg.vgold, vdollar = arg.vdollar;
          return {
            'data[user_id]': user_id,
            'data[vgold]': vgold,
            'data[vdollar]': vdollar
          };
        },
        url: function() {
          return "/newspapers/donate.json";
        }
      },

      /*
       			Parties
       */
      'party.list': {
        cacheValidityInMs: 300 * 1000,
        url: '/parties/party_list.json'
      },
      'party.info': {
        cache: false,
        url: function(arg) {
          var partyId;
          partyId = arg.partyId;
          if (partyId != null) {
            return "/parties/info/" + partyId + ".json";
          } else {
            return "/parties/info.json";
          }
        }
      },
      'party.create.price': {
        cacheValidityInMs: 300 * 1000,
        url: '/parties/price.json'
      },
      'party.create': {
        cache: false,
        invalidate: ['party.list'],
        method: 'POST',
        required: ['name', 'description', 'logo'],
        showLoader: false,
        data: function(arg) {
          var description, logo, name;
          name = arg.name, description = arg.description, logo = arg.logo;
          return {
            'data[Party][name]': name,
            'data[Party][party_info]': description,
            'data[Party][logo]': logo
          };
        },
        url: function() {
          return "/parties/create.json";
        }
      },
      'party.update': {
        cache: false,
        invalidate: ['party.list', 'party.info'],
        method: 'POST',
        required: ['name', 'description', 'auto', 'logo'],
        data: function(arg) {
          var auto, description, logo, name;
          name = arg.name, description = arg.description, auto = arg.auto, logo = arg.logo;
          return {
            'data[Party][name]': name,
            'data[Party][party_info]': description,
            'data[Party][auto_approve]': auto,
            'data[Party][logo]': logo
          };
        },
        url: '/parties/edit.json'
      },
      'party.disband': {
        cache: false,
        invalidate: ['party.list'],
        method: 'POST',
        url: function() {
          return "/parties/disband.json";
        }
      },
      'party.unfriendly': {
        cache: false,
        url: function(arg) {
          var name, party, partyId, search;
          partyId = arg.partyId, name = arg.name;
          party = partyId != null ? "/" + partyId : "";
          search = name != null ? "/" + name : "";
          return "/parties/unfriendly" + party + search + ".json";
        }
      },
      'party.friends': {
        cache: false,
        url: function(arg) {
          var partyId;
          partyId = arg.partyId;
          if (partyId != null) {
            return "/parties/friends/" + partyId + ".json";
          } else {
            return "/parties/friends.json";
          }
        }
      },
      'party.friends.remove': {
        cache: false,
        invalidate: ['party.friends', 'party.unfriendly'],
        method: 'POST',
        require: ['partyId'],
        data: function(arg) {
          var partyId;
          partyId = arg.partyId;
          return {
            'data[Party][id]': partyId
          };
        },
        url: function() {
          return "/parties/delete_friend.json";
        }
      },
      'party.friends.add': {
        cache: false,
        invalidate: ['party.friends', 'party.unfriendly'],
        method: 'POST',
        require: ['partyId'],
        data: function(arg) {
          var partyId;
          partyId = arg.partyId;
          return {
            'data[Party][id]': partyId
          };
        },
        url: function() {
          return "/parties/add_friend.json";
        }
      },
      'party.members': {
        cacheValidityInMs: 30 * 1000,
        url: function(arg) {
          var partyId, userName;
          partyId = arg.partyId, userName = arg.userName;
          if (partyId != null) {
            if (userName != null) {
              return "/parties/members/" + partyId + ".json?userName=" + userName;
            } else {
              return "/parties/members/" + partyId + ".json";
            }
          } else {
            return "/parties/members.json";
          }
        }
      },
      'party.leave': {
        cache: false,
        invalidate: ['party.list'],
        method: 'POST',
        url: function() {
          return "/parties/leave_party.json";
        }
      },
      'party.requests': {
        cacheValidityInMs: 30 * 1000,
        url: function() {
          return "/parties/requests.json";
        }
      },
      'party.requests.count': {
        url: function() {
          return "/parties/requests_count.json";
        }
      },
      'party.request.decline': {
        cache: false,
        method: 'POST',
        invalidate: ['party.list', 'party.requests', 'party.requests.count'],
        required: ['requestId'],
        data: function(arg) {
          var requestId;
          requestId = arg.requestId;
          return {
            'data[PartyRequest][id]': requestId
          };
        },
        url: function() {
          return "/parties/decline_request.json";
        }
      },
      'party.request.accept': {
        cache: false,
        method: 'POST',
        required: ['requestId'],
        invalidate: ['party.list', 'party.requests', 'party.requests.count'],
        data: function(arg) {
          var requestId;
          requestId = arg.requestId;
          return {
            'data[PartyRequest][id]': requestId
          };
        },
        url: function() {
          return "/parties/accept_request.json";
        }
      },
      'party.join': {
        cache: false,
        method: 'POST',
        required: ['partyId'],
        invalidate: ['party.list'],
        data: function(arg) {
          var partyId;
          partyId = arg.partyId;
          return {
            'data[PartyRequest][party_id]': partyId
          };
        },
        url: '/parties/join.json'
      },
      'party.level.up': {
        cache: false,
        method: 'POST',
        required: ['partyId'],
        invalidate: ['party.info', 'party.treasure'],
        data: function(arg) {
          var partyId;
          partyId = arg.partyId;
          return {
            'data[Party][id]': partyId
          };
        },
        url: '/parties/level_up.json'
      },
      'party.level.up.price': {
        cacheValidityInMs: 30 * 1000,
        method: 'GET',
        required: ['partyId'],
        url: function(arg) {
          var partyId;
          partyId = arg.partyId;
          return "/parties/level_up_price/" + partyId + ".json";
        }
      },
      'party.treasure': {
        cache: false,
        url: function() {
          return "/parties/treasure.json";
        }
      },
      'party.treasure.donate': {
        cache: false,
        method: 'POST',
        required: ['amount', 'currency', 'partyId'],
        invalidate: ['party.treasure'],
        data: function(arg) {
          var amount, currency, partyId;
          partyId = arg.partyId, amount = arg.amount, currency = arg.currency;
          return {
            'data[Party][id]': partyId,
            'data[Party][amount]': amount,
            'data[Party][currency]': currency
          };
        },
        url: '/parties/donate.json',
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'party.parliamentary': {
        cache: false,
        url: function() {
          return "/parliament/parliamentaries.json";
        }
      },
      'party.member': {
        cache: false,
        required: ['memberId'],
        url: function(arg) {
          var memberId;
          memberId = arg.memberId;
          return "/parties/member/" + memberId + ".json";
        }
      },
      'party.member.remove': {
        cache: false,
        required: ['memberId'],
        method: 'POST',
        data: function(arg) {
          var memberId;
          memberId = arg.memberId;
          return {
            'data[PartyMember][id]': memberId
          };
        },
        url: function() {
          return "/parties/remove_member.json";
        }
      },
      'party.member.remove_from_office': {
        cache: false,
        required: ['memberId'],
        invalidate: ['party.members'],
        method: 'POST',
        data: function(arg) {
          var memberId;
          memberId = arg.memberId;
          return {
            'data[PartyMember][id]': memberId
          };
        },
        url: function() {
          return "/parties/remove_from_office.json";
        }
      },
      'party.member.set.master': {
        cache: false,
        required: ['memberId'],
        invalidate: ['party.members'],
        method: 'POST',
        data: function(arg) {
          var memberId;
          memberId = arg.memberId;
          return {
            'data[PartyMember][id]': memberId
          };
        },
        url: function() {
          return "/parties/set_master.json";
        }
      },
      'party.member.set.submaster': {
        cache: false,
        required: ['memberId'],
        invalidate: ['party.members'],
        method: 'POST',
        data: function(arg) {
          var memberId;
          memberId = arg.memberId;
          return {
            'data[PartyMember][id]': memberId
          };
        },
        url: function() {
          return "/parties/set_submaster.json";
        }
      },
      'party.member.parliament.add': {
        cache: false,
        required: ['memberId'],
        invalidate: ['party.parliamentary'],
        method: 'POST',
        data: function(arg) {
          var memberId;
          memberId = arg.memberId;
          return {
            'data[PartyMember][id]': memberId
          };
        },
        url: function() {
          return "/parliament/add.json";
        }
      },
      'party.member.parliament.remove': {
        cache: false,
        required: ['userId'],
        invalidate: ['party.parliamentary'],
        method: 'POST',
        data: function(arg) {
          var userId;
          userId = arg.userId;
          return {
            'data[User][id]': userId
          };
        },
        url: function() {
          return "/parliament/remove.json";
        }
      },
      'party.parliament.reorder': {
        cache: false,
        required: ['ids'],
        invalidate: ['party.parliamentary'],
        method: 'POST',
        data: function(arg) {
          var ids;
          ids = arg.ids;
          return {
            'data[list]': ids
          };
        },
        url: function() {
          return "/parliament/sort.json";
        }
      },
      'party.parliament.add': {
        invalidate: ['parliament.election.candidates', 'party.parliamentary'],
        method: 'POST',
        url: function() {
          return "/parliament/add_request.json";
        }
      },
      'party.parliament.remove': {
        invalidate: ['parliament.election.candidates', 'party.parliamentary'],
        method: 'POST',
        url: function() {
          return "/parliament/remove_request.json";
        }
      },
      'party.rights.get': {
        cache: false,
        required: ['memberId'],
        url: function(arg) {
          var memberId;
          memberId = arg.memberId;
          return "/party_depeties/get/" + memberId + ".json";
        }
      },
      'party.rights.change': {
        cache: false,
        required: ['memberId', 'permission', 'action'],
        invalidate: ['party.rights.get'],
        method: 'POST',
        data: function(arg) {
          var action, memberId, permission;
          memberId = arg.memberId, permission = arg.permission, action = arg.action;
          return {
            'data[PartyMember][id]': memberId,
            'data[Rights][type]': permission,
            'data[Rights][action]': action
          };
        },
        url: function() {
          return "/party_depeties/change.json";
        }
      },
      'party.rights.remove.all': {
        cache: false,
        required: ['memberId'],
        invalidate: ['party.rights.get'],
        method: 'POST',
        data: function(arg) {
          var memberId;
          memberId = arg.memberId;
          return {
            'data[PartyMember][id]': memberId
          };
        },
        url: function() {
          return "/party_depeties/remove_from_user.json";
        }
      },
      'parliament.election.candidates': {
        url: function() {
          return "/city_elections/candidates.json";
        }
      },
      'parliament.election.result': {
        url: function(arg) {
          var direction;
          direction = arg.direction;
          if (direction == null) {
            direction = "desc";
          }
          return "/city_elections/result/" + direction + ".json";
        }
      },
      'parliament.election.vote': {
        cache: false,
        required: ['partyId'],
        method: 'POST',
        invalidate: ['parliament.election.candidates'],
        data: function(arg) {
          var partyId;
          partyId = arg.partyId;
          return {
            'data[Party][id]': partyId
          };
        },
        url: function() {
          return "/city_elections/vote.json";
        }
      },
      'house.info': {
        cacheValidityInMs: 30 * 1000,
        url: function() {
          return "/user_homes/info.json";
        }
      },
      'house.buy': {
        cache: false,
        method: 'POST',
        invalidate: ['house.info', 'inventory', 'inventory.furniture'],
        showLoader: false,
        data: function(arg) {
          var currency, exchangeId, homeTypeId;
          homeTypeId = arg.homeTypeId, currency = arg.currency, exchangeId = arg.exchangeId;
          return {
            'data[UserHomeType][id]': homeTypeId,
            'data[UserHomeType][currency]': currency,
            'data[UserHomeType][exchangeId]': exchangeId
          };
        },
        url: function() {
          return "/user_homes/buy_home.json";
        },
        after: function() {
          app.menu.view.reload(null, false);
          return app.shortInfo.view.reload(null, false);
        }
      },
      'house.putFurniture': {
        cache: false,
        method: 'POST',
        invalidate: ['house.info', 'inventory', 'inventory.furniture'],
        data: function(arg) {
          var homeId, itemId, placeSlot;
          itemId = arg.itemId, homeId = arg.homeId, placeSlot = arg.placeSlot;
          return {
            'data[UserItem][id]': itemId,
            'data[UserHome][id]': homeId,
            'data[UserHome][slot]': placeSlot
          };
        },
        url: function() {
          return "/user_homes/put_item_to_flat.json";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'house.removeFurniture': {
        cache: false,
        method: 'POST',
        invalidate: ['house.info', 'inventory', 'inventory.furniture'],
        data: function(arg) {
          var homeId, placeSlot;
          homeId = arg.homeId, placeSlot = arg.placeSlot;
          return {
            'data[UserHome][id]': homeId,
            'data[UserHome][slot]': placeSlot
          };
        },
        url: function() {
          return "/user_homes/put_item_from_flat.json";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'house.levelUpFurnitureSlots': {
        cache: false,
        method: 'POST',
        invalidate: ['house.info'],
        required: ['UserHomeId'],
        data: function(arg) {
          var UserHomeId;
          UserHomeId = arg.UserHomeId;
          return {
            'data[UserHome][id]': UserHomeId
          };
        },
        url: function() {
          return "/user_homes/levelup_furniture_slots.json";
        },
        after: function() {
          app.menu.view.reload();
          return app.shortInfo.view.reload();
        }
      },
      'shop.list': {
        cache: false,
        method: 'GET',
        url: "/shop/index.json"
      },
      'shop.militarylist': {
        cache: false,
        method: 'GET',
        url: "/shop/military.json"
      },
      'shop.check_can_buy': {
        cache: false,
        method: 'GET',
        required: ['id'],
        url: function(arg) {
          var currency, id, quantity;
          id = arg.id, quantity = arg.quantity, currency = arg.currency;
          return "/shop/check_can_buy.json?id=" + id + "&quantity=" + (quantity || 1) + "&currency=" + (currency || 1);
        }
      },
      'shop.buy': {
        cache: false,
        method: 'POST',
        url: "/shop/buy.json",
        required: ['id'],
        data: function(arg) {
          var currency, id, quantity;
          id = arg.id, quantity = arg.quantity, currency = arg.currency;
          return {
            'data[ShopGoods][id]': id,
            'data[ShopGoods][quantity]': quantity || 1,
            'data[ShopGoods][currency]': currency || 1
          };
        }
      },
      'ratings.cities': {
        cache: false,
        cacheValidityInMs: 15 * 60 * 1000,
        url: function(arg) {
          var timeFilter;
          timeFilter = arg.timeFilter;
          console.log(timeFilter);
          if (timeFilter != null) {
            return "/ratings/cities.json?timeFilter=" + timeFilter;
          } else {
            return "/ratings/cities.json";
          }
        }
      },
      'ratings.player': {
        cache: false,
        cacheValidityInMs: 15 * 60 * 1000,
        url: function(arg) {
          var cityFilter, timeFilter, usersFilter;
          timeFilter = arg.timeFilter, usersFilter = arg.usersFilter, cityFilter = arg.cityFilter;
          if ((timeFilter != null) && (usersFilter != null) && (cityFilter != null)) {
            return "/ratings/players.json?timeFilter=" + timeFilter + "&usersFilter=" + usersFilter + "&cityFilter=" + cityFilter;
          } else {
            return "/ratings/players.json";
          }
        }
      },
      'ratings.companies': {
        cache: false,
        cacheValidityInMs: 15 * 60 * 1000,
        url: function(arg) {
          var cityFilter, productionType, timeFilter;
          timeFilter = arg.timeFilter, cityFilter = arg.cityFilter, productionType = arg.productionType;
          if ((timeFilter != null) && (cityFilter != null)) {
            return "/ratings/companies.json?timeFilter=" + timeFilter + "&cityFilter=" + cityFilter + "&productionType=" + productionType;
          } else {
            return "/ratings/companies.json";
          }
        }
      },
      'ratings.corporations': {
        cache: false,
        cacheValidityInMs: 15 * 60 * 1000,
        url: function(arg) {
          var cityFilter, timeFilter;
          timeFilter = arg.timeFilter, cityFilter = arg.cityFilter;
          if ((timeFilter != null) && (cityFilter != null)) {
            return "/ratings/corporations.json?timeFilter=" + timeFilter + "&cityFilter=" + cityFilter;
          } else {
            return "/ratings/corporations.json";
          }
        }
      },
      'ratings.profile_rating': {
        cache: false,
        url: function(arg) {
          var tab;
          tab = arg.tab;
          return "/ratings/" + tab;
        }
      },
      'ratings.show': {
        cache: false,
        url: function(arg) {
          var ratingType;
          ratingType = arg.ratingType;
          return "/ratings/show.json?ratingType=" + ratingType;
        }
      },
      'blueprints.create': {
        cache: false,
        required: ['blueprint'],
        method: 'POST',
        invalidate: ['blueprints.list'],
        data: function(arg) {
          var blueprint;
          blueprint = arg.blueprint;
          return {
            'blueprint': blueprint
          };
        },
        url: function() {
          return "/blueprints/create.json";
        }
      },
      'blueprints.duplicate': {
        cache: false,
        required: ['blueprintId'],
        method: 'POST',
        data: function(arg) {
          var blueprintId;
          blueprintId = arg.blueprintId;
          return {
            'blueprintId': blueprintId
          };
        },
        url: function() {
          return "/blueprints/duplicate.json";
        }
      },
      'blueprints.get_config': {
        cache: false,
        method: 'GET',
        url: function() {
          return "/blueprints/get_config.json";
        }
      },
      'blueprints.list': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var page;
          page = arg.page;
          return "/blueprints/list.json?page=" + (page || 1);
        }
      },
      'blueprints.logo.list': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var group, page, query;
          group = arg.group, page = arg.page;
          query = _buildUrlQuery({
            group: group,
            page: page || 1
          });
          return "/blueprints/logo/list.json?" + query;
        }
      },
      'blueprints.logo.moderation_list': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var group, page, query;
          group = arg.group, page = arg.page;
          query = _buildUrlQuery({
            group: group,
            page: page || 1
          });
          return "/blueprints/logo/moderation_list.json?" + query;
        }
      },
      'blueprints.logo.user_list': {
        cache: false,
        method: 'GET',
        url: function(arg) {
          var group, page;
          group = arg.group, page = arg.page;
          return "/blueprints/logo/user_list.json";
        }
      },
      'blueprints.logo.check_code': {
        cache: false,
        required: ['logoId', 'code'],
        method: 'POST',
        data: function(arg) {
          var code, logoId;
          logoId = arg.logoId, code = arg.code;
          return {
            'logo_id': logoId,
            'code': code
          };
        },
        url: function() {
          return "/blueprints/logo/check_code.json";
        }
      },
      'blueprints.logo.create': {
        cache: false,
        required: ['logo'],
        method: 'POST',
        data: function(arg) {
          var logo;
          logo = arg.logo;
          return logo;
        },
        url: function() {
          return "/blueprints/logo/create.json";
        }
      },
      'blueprints.logo.get_config': {
        cache: false,
        method: 'GET',
        url: function() {
          return "/blueprints/logo/get_config.json";
        }
      }
    };

    return ServerController;

  })(Marionette.Controller);
  return ServerController;
});
