define(['marionette'], function(Marionette) {
  return Marionette.Controller.extend({
    initialize: function(arg) {
      this.app = arg.app;
    },
    init: (function(_this) {
      return function() {
        return _this.app.server.user.info({
          success: function(info) {
            return _this.app.notifications.openSocket(info.user.User);
          }
        });
      };
    })(this),
    openSocket: (function(_this) {
      return function(info) {
        var socketLink;
        socketLink = "ws://" + _this.app.config.serverURL + ":" + _this.app.config.notifications.port + "/track?id=" + info.id + "&language=ru&city=" + info.city_id;
        _this.socket = new WebSocket(socketLink);
        _this.socket.onclose = function(event) {};
        _this.socket.onopen = function(event) {
          _this.socket.send(JSON.stringify({
            type: 'register',
            userId: info.id
          }));
          return _this.app.notifications.ping();
        };
        return _this.socket.onmessage = function(event) {
          var data;
          data = $.parseJSON(event.data);
          if (_this.app.config.debug) {
            console.log(data);
          }
          return _this.app.notifications.process(data);
        };
      };
    })(this),
    ping: (function(_this) {
      return function() {
        if (_this.pingTimer != null) {
          clearInterval(_this.pingTimer);
        }
        return _this.pingTimer = setInterval(function() {
          if (_this.socket != null) {
            return _this.socket.send('PING');
          } else {
            if (app.config.debug) {
              return console.log('?? socket ??');
            }
          }
        }, 11000);
      };
    })(this),
    reload: function() {
      if (this.socket != null) {
        this.socket.close();
      }
      require.undef('controllers/notifications');
      return require(['controllers/notifications'], (function(_this) {
        return function(NotificationsController) {
          if (_this.app.config.debug) {
            console.log("reload notifications controller");
          }
          _this.app.notifications = new NotificationsController({
            app: _this.app
          });
          return _this.app.notifications.init();
        };
      })(this));
    },
    process: function(data) {
      if (data.type === 'events') {
        return this.loadEvents(data.events_html);
      } else if (data.type === 'message_count') {
        return this.loadMessageCount(data);
      } else if (data.type === 'energy_timer') {
        return this.energyTimer(data.energyTimeLeft);
      } else if (data.type === 'level_up') {
        return this.levelUp();
      }
    },
    levelUp: function() {
      return this.app.screens.modal('common/level-up-first-popup');
    },
    loadMessageCount: function(data) {},
    loadEvents: function(events_html) {},
    energyTimer: (function(_this) {
      return function(energyFullTimeLeft) {
        if (_this.energyTimer != null) {
          clearInterval(_this.energyTimer);
        }
        return _this.energyTimer = setInterval(function() {
          return _this.app.notifications.renewEnergy();
        }, 15000);
      };
    })(this),
    tickEnergy: function(periods) {},
    renewEnergy: function() {}
  });
});
