define(['jquery'], function($) {
  var FileService, FileWrapper, TYPE_BROWSER, TYPE_CORDOVA, _arrayBufferToBase64, extensionToMime, imageMimes;
  TYPE_BROWSER = 'browser';
  TYPE_CORDOVA = 'cordova';
  imageMimes = ['image/gif', 'image/jpeg', 'image/pjpeg', 'image/png', '.png', '.jpeg', '.gif', '.jpg', '.pjpeg', 'png', 'jpeg', 'gif', 'jpg', 'pjpeg'];
  extensionToMime = {
    'jpg': 'image/jpeg',
    'jpeg': 'image/jpeg',
    'pjpeg': 'image/pjpeg',
    'png': 'image/png',
    'gif': 'image/gif'
  };
  _arrayBufferToBase64 = function(buffer) {
    var binary, bytes, i, j, len, ref;
    binary = '';
    bytes = new Uint8Array(buffer);
    len = bytes.byteLength;
    for (i = j = 0, ref = len; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
      binary += String.fromCharCode(bytes[i]);
    }
    return window.btoa(binary);
  };
  FileWrapper = (function() {
    function FileWrapper(type, data, os) {
      if (os == null) {
        os = 'unknown';
      }
      this._type = type;
      this._data = data;
      this._os = os;
      this._size = 0;
      this._file = null;
      this._mimeType = null;
      this._fileUrl = null;
      this._blob = null;
      this._dataUrl = null;
    }

    FileWrapper.prototype.preloadInfo = function() {
      var promises, self;
      self = this;
      if (this._type === TYPE_BROWSER) {
        this._file = this._data;
        this._size = this._file.size;
        this._mimeType = this._file.type;
        this._fileUrl = this._getUrlBrowser();
        promises = [self._setBlobBrowser(), self._setImageDataUrlBrowser()];
        return $.when(promises).then(function() {
          return true;
        });
      } else {
        this._fileUrl = this._getUrlCordova();
        return this._getFileCordova().then(function() {
          self._size = self._file.size;
          self._mimeType = self._getMimeTypeCordova();
          promises = [self._setBlobCordova(), self._setImageDataUrlCordova()];
          return $.when(promises).then(function() {
            return true;
          });
        });
      }
    };

    FileWrapper.prototype.destroy = function() {
      var URL;
      if (this._type === TYPE_BROWSER) {
        URL = window.URL || window.webkitURL;
        if (URL && this._fileUrl) {
          URL.revokeObjectURL(this._fileUrl);
        }
      }
      this._data = null;
      this._type = null;
      this._size = 0;
      this._file = null;
      this._mimeType = null;
      this._fileUrl = null;
      this._blob = null;
      return this._dataUrl = null;
    };

    FileWrapper.prototype.isImage = function() {
      return imageMimes.indexOf(this._mimeType) !== -1;
    };

    FileWrapper.prototype.getType = function() {
      return this._type;
    };

    FileWrapper.prototype.getUrl = function() {
      return this._fileUrl;
    };

    FileWrapper.prototype.getImageDataUrl = function() {
      if (this.isImage()) {
        return this._dataUrl;
      } else {
        return null;
      }
    };

    FileWrapper.prototype.getSize = function() {
      return this._size;
    };

    FileWrapper.prototype.getMimeType = function() {
      return this._mimeType;
    };

    FileWrapper.prototype.getFile = function() {
      return this._file;
    };

    FileWrapper.prototype.getUrl = function() {
      return this._fileUrl;
    };

    FileWrapper.prototype.getImageDataUrl = function() {
      return this._dataUrl;
    };

    FileWrapper.prototype.getBlob = function() {
      return this._blob;
    };

    FileWrapper.prototype._getUrlCordova = function() {
      var url;
      url = this._data;
      if (this._os === 'android' && url.indexOf('com.android') !== -1 && url.indexOf('%3A') !== -1) {
        url = url.replace("%", "%25");
      }
      return url;
    };

    FileWrapper.prototype._getUrlBrowser = function() {
      var URL;
      if (this._fileUrl) {
        return this._fileUrl;
      }
      URL = window.URL || window.webkitURL;
      if (!URL) {
        return null;
      }
      this._fileUrl = URL.createObjectURL(this._data);
      return this._fileUrl;
    };

    FileWrapper.prototype._getMimeTypeCordova = function() {
      var dotIndex, extension;
      if (!this._file && !this._fileUrl) {
        return null;
      }
      if (this._file && this._file.type && this._file.type.indexOf('/') !== -1) {
        return this._file.type.toLowerCase();
      }
      extension = null;
      if (!this._file || !(this._file.type && this._file.name)) {
        dotIndex = this._fileUrl.lastIndexOf('.');
        if (!(dotIndex === -1 || dotIndex === (this._fileUrl.length - 1))) {
          extension = this._fileUrl.substr(this._fileUrl.lastIndexOf('.') + 1, this._fileUrl.length);
        }
      } else if (!this._file.type) {
        dotIndex = this._file.name.lastIndexOf('.');
        if (!(dotIndex === -1 || dotIndex === (this._file.name.length - 1))) {
          extension = this._file.name.substr(this._file.name.lastIndexOf('.'), this._file.name.length);
        }
      } else if (this._file.type && this._file.type.indexOf('/') === -1) {
        extension = this._file.type.replace('.', '');
      }
      if (extension && extensionToMime[extension]) {
        return extensionToMime[extension];
      } else {
        return null;
      }
    };

    FileWrapper.prototype._setImageDataUrlCordova = function() {
      var deferred, self;
      deferred = $.Deferred();
      if (!this._data) {
        return deferred.reject(null);
      }
      if (!this.isImage()) {
        return deferred.resolve(null);
      }
      self = this;
      self._getFileCordova().then(function(file) {
        var err, reader;
        try {
          reader = new FileReader();
          reader.onloadend = function(e) {
            self._dataUrl = this.result || e.target.result;
            return deferred.resolve(self._dataUrl);
          };
          return reader.readAsDataURL(file);
        } catch (_error) {
          err = _error;
          return errFn(err);
        }
      });
      return deferred;
    };

    FileWrapper.prototype._setImageDataUrlBrowser = function() {
      var deferred, err, reader, self;
      deferred = $.Deferred();
      if (!this._data) {
        return deferred.reject(null);
      }
      if (!this.isImage()) {
        return deferred.resolve(null);
      }
      self = this;
      try {
        reader = new FileReader();
        reader.onloadend = function() {
          self._dataUrl = reader.result;
          return deferred.resolve(reader.result);
        };
        reader.readAsDataURL(self._data);
      } catch (_error) {
        err = _error;
        deferred.reject(err);
      }
      return deferred;
    };

    FileWrapper.prototype._setBlobBrowser = function() {
      var deferred, err, reader, self;
      deferred = $.Deferred();
      if (!this._data) {
        return deferred.reject(null);
      }
      self = this;
      try {
        reader = new FileReader();
        reader.onloadend = function() {
          var blob;
          blob = new Blob([this.result], {
            type: self._data.type
          });
          self._blob = blob;
          return deferred.resolve(blob);
        };
        reader.readAsArrayBuffer(self._data);
      } catch (_error) {
        err = _error;
        self._blob = null;
        deferred.reject(null);
      }
      return deferred;
    };

    FileWrapper.prototype._setBlobCordova = function() {
      var deferred, self;
      deferred = $.Deferred();
      if (!this._data) {
        return deferred.reject(null);
      }
      self = this;
      self._getFileCordova().then(function(file) {
        var err, reader;
        try {
          reader = new FileReader();
          reader.onloadend = function(e) {
            var BlobBuilder, bb, blob, err;
            try {
              blob = new Blob([this.result || e.target.result], {
                type: file.type
              });
            } catch (_error) {
              err = _error;
              console.log(err.message);
              BlobBuilder = window.BlobBuilder || window.WebKitBlobBuilder || window.MozBlobBuilder || window.MSBlobBuilder;
              if (!BlobBuilder) {
                console.log('Blob builder not supported');
                return deferred.reject(null);
              }
              bb = new BlobBuilder();
              bb.append(this.result || e.target.result);
              blob = bb.getBlob(file.type);
            }
            self._blob = blob;
            return deferred.resolve(self.blob);
          };
          return reader.readAsArrayBuffer(file);
        } catch (_error) {
          err = _error;
          return deferred.reject(null);
        }
      });
      return deferred;
    };

    FileWrapper.prototype._getFileCordova = function() {
      var deferred, self;
      deferred = $.Deferred();
      if (this._file) {
        return deferred.resolve(this._file);
      }
      if (!this._data) {
        return deferred.reject(null);
      }
      self = this;
      window.resolveLocalFileSystemURL(this._data, function(fileEntry) {
        return fileEntry.file(function(file) {
          self._file = file;
          return deferred.resolve(self._file);
        });
      }, function(e) {
        return deferred.reject(null);
      });
      return deferred;
    };

    return FileWrapper;

  })();
  FileService = (function() {
    FileService.prototype._fileSelector = '#js-hidden-file-input';

    function FileService(app) {
      this.app = app;
    }

    FileService.prototype.upload = function(file, url, options) {
      if (options == null) {
        options = {};
      }
      if (!window.isCordova) {
        return this._uploadBrowser(file, url, options);
      } else {
        return this._uploadCordova(file, url, options);
      }
    };

    FileService.prototype._uploadCordova = function(file, url, opts) {
      var deferred, fKey, fVal, fileURL, ft, options, ref, self, uploadUrl;
      self = this;
      deferred = $.Deferred();
      fileURL = file.getUrl();
      options = new FileUploadOptions;
      options.fileKey = opts.fileName || 'file';
      options.fileName = fileURL.substr(fileURL.lastIndexOf('/') + 1);
      options.mimeType = file.getMimeType() || 'image/jpeg';
      options.chunkedMode = false;
      options.headers = {
        Connection: 'close'
      };
      if (opts.fields) {
        options.params = {};
        ref = opts.fields;
        for (fKey in ref) {
          fVal = ref[fKey];
          if (typeof fVal === 'string' && !fVal.length) {
            continue;
          }
          options.params[fKey] = fVal;
        }
      }
      uploadUrl = encodeURI(app.config.serverURLProtocol + '://' + app.config.serverURL + url);
      ft = new FileTransfer;
      ft.upload(file._data, uploadUrl, function(response) {
        var data, e;
        data = null;
        if (response && response.response) {
          data = response.response;
          if (opts.responseType === 'json' && data) {
            try {
              data = JSON.parse(data);
            } catch (_error) {
              e = _error;
              data = null;
            }
          }
        }
        if (response && response.responseCode === 200) {
          return deferred.resolve(data);
        } else {
          return deferred.reject(data);
        }
      }, function(error) {
        var data, e;
        data = null;
        if (error && error.body) {
          data = error.body;
          if (opts.responseType === 'json' && data) {
            try {
              data = JSON.parse(data);
            } catch (_error) {
              e = _error;
              data = null;
            }
          }
        }
        return deferred.reject(data);
      }, options);
      return deferred;
    };

    FileService.prototype._uploadBrowser = function(file, url, options) {
      var deferred, err, formData, name, ref, self, uploadUrl, value, xhr;
      self = this;
      deferred = $.Deferred();
      try {
        uploadUrl = encodeURI(self.app.config.serverURLProtocol + '://' + self.app.config.serverURL + url);
        formData = new FormData();
        formData.append(options.fileName || 'file', file._data, file._data.name);
        if (options.fields) {
          ref = options.fields;
          for (name in ref) {
            value = ref[name];
            formData.append(name, value);
          }
        }
        xhr = new XMLHttpRequest();
        xhr.open('POST', uploadUrl, true);
        xhr.withCredentials = true;
        xhr.onload = function() {
          var data, e;
          data = null;
          if (this.responseText) {
            data = this.responseText;
            if (options.responseType === 'json' && data) {
              try {
                data = JSON.parse(data);
              } catch (_error) {
                e = _error;
                data = null;
              }
            }
          }
          if (xhr.status === 200) {
            return deferred.resolve(data);
          } else {
            return deferred.reject(data);
          }
        };
        xhr.onerror = function() {
          return deferred.reject(null);
        };
        xhr.send(formData);
      } catch (_error) {
        err = _error;
        deferred.reject(null);
      }
      return deferred;
    };

    FileService.prototype.selectFile = function() {
      if (!window.isCordova) {
        return this._selectFileBrowser();
      } else {
        return this._selectFileCordova();
      }
    };

    FileService.prototype._selectFileBrowser = function() {
      var deferred, fileInputElement, self;
      deferred = $.Deferred();
      self = this;
      fileInputElement = $(this._fileSelector);
      if (!fileInputElement) {
        deferred.reject(null);
      }
      fileInputElement.trigger('click');
      fileInputElement.one('change', function() {
        var file;
        if (this.files.length < 1) {
          return deferred.reject(null);
        }
        file = new FileWrapper(TYPE_BROWSER, this.files[0]);
        return file.preloadInfo().then(function() {
          return deferred.resolve(file);
        }, function() {
          return deferred.reject(null);
        });
      });
      fileInputElement.one('blur', function() {
        if (deferred.state() === 'pending') {
          return deferred.reject(null);
        }
      });
      return deferred;
    };

    FileService.prototype._selectFileCordova = function() {
      var deferred, destType, self;
      deferred = $.Deferred();
      self = this;
      destType = navigator.camera.DestinationType.FILE_URI;
      if (self.app.getDeviceOs() === 'windows') {
        destType = navigator.camera.DestinationType.NATIVE_URI;
      }
      if (navigator.camera != null) {
        navigator.camera.getPicture((function(imageURI) {
          var file;
          if (!imageURI) {
            return deferred.reject(null);
          }
          file = new FileWrapper(TYPE_CORDOVA, imageURI);
          return file.preloadInfo().then(function() {
            return deferred.resolve(file);
          }, function() {
            return deferred.reject(null);
          });
        }), (function(message) {
          return deferred.reject(null);
        }), {
          quality: 50,
          destinationType: destType,
          sourceType: navigator.camera.PictureSourceType.PHOTOLIBRARY,
          mediaType: navigator.camera.MediaType.PICTURE
        });
      } else {
        deferred.reject(null);
      }
      return deferred;
    };

    return FileService;

  })();
  return FileService;
});
