var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

define(['jquery'], function($) {
  var PlatformPayments;
  PlatformPayments = (function() {
    PlatformPayments.prototype._paymentFinishUri = null;

    PlatformPayments.prototype._paymentVerifyUri = null;

    PlatformPayments.prototype._paymentFinishUriPath = '/payments/platform/finish';

    PlatformPayments.prototype._paymentVerifyUriPath = '/payments/platform/verify';

    PlatformPayments.prototype._currencyListUriPath = '/payments/platform/getVirtualCurrencyList';

    PlatformPayments.prototype._serverAttempts = 3;

    PlatformPayments.prototype._currentAttempts = {};

    PlatformPayments.prototype._inPurchase = {};

    PlatformPayments.prototype._readyDeferred = null;

    PlatformPayments.prototype._isReady = false;

    PlatformPayments.prototype._isEnabled = true;

    PlatformPayments.prototype._pendingPurchaseSuccessFn = null;

    PlatformPayments.prototype._pendingPurchaseErrorFn = null;

    PlatformPayments.prototype._refreshInProcess = false;

    PlatformPayments.prototype._storeRefreshTimeoutId = null;

    PlatformPayments.prototype._storeRefreshTimeout = 15000;

    PlatformPayments.prototype._storeUpdateIntervalId = null;

    PlatformPayments.prototype._storeUpdateInterval = 120000;

    PlatformPayments.prototype._names = {
      'android': 'Playstore',
      'ios': 'Appstore',
      'windows phone': 'Windows store'
    };

    PlatformPayments.prototype._currencyList = [];

    PlatformPayments.prototype._currencyCodes = {
      'руб.': 'RUB',
      'руб': 'RUB',
      'RUB': 'RUB',
      'usd': 'USD',
      'USD': 'USD',
      'грн': 'UAH',
      'грн.': 'UAH',
      'kr': 'DKK',
      'kr.': 'DKK',
      '$': 'USD',
      '₽': 'RUB',
      '€': 'EUR',
      '¥': 'CNY',
      '£': 'GBP',
      'Kč': 'CZK',
      '₪': 'ILS',
      '₸': 'KZT',
      '₫': 'VND',
      '₴': 'UAH',
      '฿': 'THB',
      '₯': 'GRD',
      '₳': 'ARA',
      '₲': 'PYG',
      '₹': 'INR',
      '₵': 'GHS',
      '৳': 'BDT',
      '₮': 'MNT'
    };

    function PlatformPayments(config) {
      this._onError = bind(this._onError, this);
      this._genericXHRErrorHandler = bind(this._genericXHRErrorHandler, this);
      this._finishPurchase = bind(this._finishPurchase, this);
      this._verifyPurchaseQuery = bind(this._verifyPurchaseQuery, this);
      this._verifyPurchase = bind(this._verifyPurchase, this);
      this._startupFinishPurchase = bind(this._startupFinishPurchase, this);
      this._storeOrder = bind(this._storeOrder, this);
      this._refreshStore = bind(this._refreshStore, this);
      this._loadVirtualCurrencyList = bind(this._loadVirtualCurrencyList, this);
      this.order = bind(this.order, this);
      this.ready = bind(this.ready, this);
      this._config = config;
      this._paymentFinishUri = (this._config.protocol || 'http') + '://' + this._config.host + this._paymentFinishUriPath;
      this._paymentVerifyUri = (this._config.protocol || 'http') + '://' + this._config.host + this._paymentVerifyUriPath;
      this._currencyListUri = (this._config.protocol || 'http') + '://' + this._config.host + this._currencyListUriPath;
      if (config != null ? config.testKey : void 0) {
        this._paymentFinishUri += '?__test=' + config.testKey;
        this._paymentVerifyUri += '?__test=' + config.testKey;
      }
      this._isReady = false;
      this._readyDeferred = $.Deferred();
    }

    PlatformPayments.prototype.getName = function() {
      if (this._names.hasOwnProperty(this._config.platform)) {
        return this._names[this._config.platform];
      } else {
        return app.tr('Store');
      }
    };

    PlatformPayments.prototype.isEnabled = function() {
      return this._isEnabled;
    };

    PlatformPayments.prototype.ready = function() {
      if (this._isReady === false) {
        this._init();
      }
      return this._readyDeferred;
    };

    PlatformPayments.prototype.refresh = function() {
      if (this._isReady) {
        if (this._config.platform === 'ios') {
          return store.trigger("refreshed");
        } else {
          return store.refresh();
        }
      }
    };

    PlatformPayments.prototype.setPendingPurchaseCallbacks = function(success, error) {
      this._pendingPurchaseSuccessFn = success;
      return this._pendingPurchaseErrorFn = error || null;
    };

    PlatformPayments.prototype.loadCurrencyList = function() {
      var i, item, len, product, products, ref;
      products = [];
      ref = this._currencyList;
      for (i = 0, len = ref.length; i < len; i++) {
        item = ref[i];
        product = store.get(item.id);
        if (product && product.canPurchase) {
          item.price = product.price ? product.price.replace('₽', 'руб.') : '-';
          item.price_ga = item.usd_price;
          item.currency_ga = 'USD';
          products.push(item);
        }
      }
      return products;
    };

    PlatformPayments.prototype.getCurrencyVgold = function(id) {
      var i, item, len, ref, vgold;
      vgold = 0;
      ref = this._currencyList;
      for (i = 0, len = ref.length; i < len; i++) {
        item = ref[i];
        if (item.id == id) {
          vgold = item.vgold;
          break;
        }
      }
      return vgold;
    };

    PlatformPayments.prototype.order = function(id) {
      return this._storeOrder(id);
    };

    PlatformPayments.prototype._init = function() {
      var self;
      self = this;
      return this._loadVirtualCurrencyList().always(function() {
        setTimeout((function() {
          if (self._readyDeferred.state() === 'pending') {
            return self._readyDeferred.resolve(false);
          }
        }), 5000);
        return document.addEventListener('deviceready', function() {
          if ((typeof store !== "undefined" && store !== null)) {
            return self._initStore();
          } else {
            self._isReady = false;
            return self._isEnabled = false;
          }
        });
      });
    };

    PlatformPayments.prototype._loadVirtualCurrencyList = function() {
      var self;
      self = this;
      return $.ajax({
        url: this._currencyListUri,
        success: function(data) {
          if (data && (data != null ? data.items : void 0)) {
            return self._currencyList = data.items;
          } else {

          }
        }
      });
    };

    PlatformPayments.prototype._initStore = function() {
      var i, item, len, ref, self;
      store.verbosity = app.config.debug ? store.DEBUG : store.ERROR;
      self = this;
      store.validator = function(product, callback) {
        return self._verifyPurchase(product).then(function(data) {
          return callback(true, data);
        }, function(data) {
          var ref, ref1;
          return callback(false, {
            code: (data != null ? (ref = data.error) != null ? ref.code : void 0 : void 0) || store.ERR_VERIFICATION_FAILED,
            message: (data != null ? (ref1 = data.error) != null ? ref1.msg : void 0 : void 0) || 'Verification Failed'
          });
        });
      };
      ref = this._currencyList;
      for (i = 0, len = ref.length; i < len; i++) {
        item = ref[i];
        store.register({
          id: item.id,
          alias: item.alias,
          type: store.CONSUMABLE
        });
      }
      store.when('product').approved(this._startupFinishPurchase);
      if (this._config.platform === 'ios') {
        store.trigger("refreshed");
      } else {
        store.refresh();
      }
      store.error(function(err) {
        self._refreshInProcess = false;
        return app.vent.trigger('store:error', err);
      });
      store.when("refreshed", function() {
        self._refreshInProcess = false;
        return app.vent.trigger('store:refreshed');
      });
      store.when("re-refreshed", function() {
        self._refreshInProcess = false;
        return app.vent.trigger('store:re-refreshed');
      });
      store.ready(function() {
        self._isReady = true;
        return self._readyDeferred.resolve(true);
      });
      return self._storeUpdateIntervalId = setInterval((function() {
        return self._refreshStoreDelayed();
      }), self._storeUpdateInterval);
    };

    PlatformPayments.prototype._refreshStoreDelayed = function() {
      var self;
      self = this;
      if (self._storeRefreshTimeoutId) {
        return;
      }
      return self._storeRefreshTimeoutId = setTimeout(function() {
        self._refreshStore();
        if (self._storeRefreshTimeoutId) {
          return self._storeRefreshTimeoutId = null;
        }
      }, self._storeRefreshTimeout);
    };

    PlatformPayments.prototype._refreshStore = function() {
      var id, inOrder, ref, status;
      inOrder = false;
      ref = this._inPurchase;
      for (id in ref) {
        status = ref[id];
        if (status) {
          inOrder = true;
          break;
        }
      }
      if (!inOrder && !this._refreshInProcess) {
        if (app.config.debug) {
          console.log("Store refresh by interval");
        }
        this._refreshInProcess = true;
        if (this._config.platform === 'ios') {
          store.trigger("refreshed");
        } else {
          store.refresh();
        }
      } else {
        if (app.config.debug) {
          console.log("Store refresh by interval canceled: product in order");
        }
      }
      return true;
    };

    PlatformPayments.prototype._storeOrder = function(id) {
      var deferred, errorFn, self, storeErrorFn;
      self = this;
      deferred = $.Deferred();
      this._inPurchase[id] = true;
      storeErrorFn = function(err) {
        if (deferred && deferred.state() === 'pending') {
          return deferred.reject(err);
        }
      };
      store.once(id).initiated(function(product) {
        product.canPurchase = false;
        return app.vent.on('store:error', storeErrorFn);
      });
      store.once(id).approved(function(product) {
        var promise;
        app.vent.off('store:error', storeErrorFn);
        promise = product.verify();
        promise.success(function(product, data) {
          return self._finishPurchase({
            payment_id: data.payment_id
          }).then(function(data) {
            self._inPurchase[id] = false;
            product.finish();
            return deferred.resolve(data);
          }, function(data) {
            data.isVerified = true;
            self._inPurchase[id] = false;
            return deferred.reject(data);
          });
        });
        return promise.error(function(data) {
          return deferred.reject(data);
        });
      });
      errorFn = function(data) {
        app.vent.off('store:error', storeErrorFn);
        self._inPurchase[id] = false;
        data.id = id;
        deferred.reject(data);
        app.vent.trigger('store:re-refreshed');
        return self._refreshStoreDelayed();
      };
      store.once(id).error(errorFn);
      store.once(id).cancelled(errorFn);
      store.once(id).finished(function() {
        app.vent.trigger('store:re-refreshed');
        return self._refreshStoreDelayed();
      });
      store.order(id);
      return deferred;
    };

    PlatformPayments.prototype._startupFinishPurchase = function(product) {
      var promise, self;
      if (!product) {
        return false;
      }
      if (!product.id) {
        if (app.config.debug) {
          console.log("INVALID PRODUCT: " + JSON.stringify(product));
        }
        product.finish();
      }
      if (this._inPurchase[product.id]) {
        return false;
      }
      self = this;
      promise = product.verify();
      promise.success(function(product, data) {
        return self._finishPurchase({
          payment_id: data.payment_id
        }).then(function(data) {
          product.finish();
          if (self._pendingPurchaseSuccessFn) {
            return self._pendingPurchaseSuccessFn(data);
          }
        }, function(data) {
          if (self._pendingPurchaseErrorFn) {
            return self._pendingPurchaseErrorFn(data);
          }
        });
      });
      return promise.error(function(err) {
        if (app.config.debug) {
          console.log(err);
        }
        if (err && (err.code = 'INVALID_PRODUCT')) {
          product.finish();
        }
        if (self._pendingPurchaseErrorFn) {
          return self._pendingPurchaseErrorFn(err);
        }
      });
    };

    PlatformPayments.prototype._verifyPurchase = function(product) {
      var productId, self;
      self = this;
      productId = product.id;
      this._currentAttempts[productId] = this._serverAttempts;
      return this._verifyPurchaseQuery(product).always(function(data) {
        if ((data != null ? data.error : void 0) && data.error.code === 'LOCK_ERROR' && self._currentAttempts[productId] > 0) {
          self._currentAttempts[productId]--;
          return self._verifyPurchaseQuery(product);
        } else {
          return data;
        }
      });
    };

    PlatformPayments.prototype._verifyPurchaseQuery = function(product) {
      var deferred, err, self, transactionId;
      deferred = $.Deferred();
      try {
        transactionId = product.transaction.id;
      } catch (_error) {
        err = _error;
        transactionId = null;
        if (app.config.debug) {
          console.log('INVALID PRODUCT TO VERIFY: ' + JSON.stringify(product));
        }
      }
      if (!transactionId) {
        this._setError('INVALID_PRODUCT', 'Invalid product to verify');
        deferred.reject({
          status: 'error',
          error: this.getError()
        });
        return deferred;
      }
      self = this;
      $.ajax({
        url: this._paymentVerifyUri,
        data: {
          product: JSON.stringify(product)
        },
        method: 'POST',
        success: function(data) {
          var resultData, success;
          success = false;
          resultData = {
            status: 'error',
            id: product.id
          };
          if (data && data.status === 'success') {
            success = true;
            product.finish();
            resultData.status = 'success';
            resultData.amount = data.amount;
            resultData.transaction_id = data.transaction_id;
            resultData.payment_id = data.payment_id;
          } else if (data && data.error) {
            self._setError(data.error.code, data.error.message);
            resultData.error = self.getError();
          } else {
            self._setError('FATAL_ERROR', 'Failed to create payment');
            resultData.error = self.getError();
          }
          if (!success) {
            return deferred.reject(resultData);
          } else {
            return deferred.resolve(resultData);
          }
        },
        error: this._getXHRErrorHandler(deferred, product.id)
      });
      return deferred;
    };

    PlatformPayments.prototype._finishPurchase = function(params) {
      var deferred, self;
      deferred = $.Deferred();
      self = this;
      $.ajax({
        url: this._paymentFinishUri,
        data: {
          payment_id: params.payment_id
        },
        method: 'POST',
        success: function(data) {
          var resultData, success;
          success = false;
          resultData = {
            status: 'error',
            id: params.payment_id
          };
          if (data && data.status === 'success') {
            success = true;
            resultData.status = 'success';
            resultData.amount = data.amount;
            resultData.transaction_id = data.transaction_id;
            resultData.payment_id = data.payment_id;
          }
          if (data && data.error) {
            self._setError(data.error.code, data.error.message);
            resultData.error = self.getError();
          } else {
            self._setError('FATAL_ERROR', 'Failed to create payment');
            resultData.error = self.getError();
          }
          if (!success) {
            return deferred.reject(resultData);
          } else {
            return deferred.resolve(resultData);
          }
        },
        error: this._getXHRErrorHandler(deferred, params.payment_id)
      });
      return deferred;
    };

    PlatformPayments.prototype._getXHRErrorHandler = function(deferred, id) {
      var errorFun;
      errorFun = this._genericXHRErrorHandler;
      return function(data) {
        data = errorFun(data);
        data.id = id;
        return deferred.reject(data);
      };
    };

    PlatformPayments.prototype._genericXHRErrorHandler = function(xhr) {
      var data, e, resultData;
      if ((xhr != null) && (xhr.responseText != null)) {
        try {
          data = JSON.parse(xhr.responseText);
        } catch (_error) {
          e = _error;
          data = {};
        }
      } else {
        data = {};
      }
      resultData = {
        status: 'error'
      };
      if (xhr != null) {
        resultData.httpCode = xhr.statusCode();
      }
      if ((data != null) && (data != null ? data.error : void 0)) {
        this._setError(data.error.code, data.error.message);
        resultData.error = this.getError();
      } else {
        this._setError('FATAL_ERROR', 'Failed to finish purchase');
        resultData.error = this.getError();
      }
      return resultData;
    };

    PlatformPayments.prototype._setError = function(code, msg) {
      this._errCode = code;
      return this._errMsg = msg;
    };

    PlatformPayments.prototype.getError = function() {
      return {
        code: this._errCode,
        msg: this._errMsg
      };
    };

    PlatformPayments.prototype._onError = function(data) {
      this._inPurchase[data.id] = false;
      if (!data && (data != null ? data.error_code : void 0)) {
        this._setError(data.error_code, data.error_msg);
      } else {
        this._setError('FATAL_ERROR', 'Fatal error');
      }
      return {
        status: 'error',
        error: this.getError()
      };
    };

    return PlatformPayments;

  })();
  return PlatformPayments;
});
