var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['jquery', 'services/social/base'], function($, BaseProvider) {
  var FBProvider;
  FBProvider = (function(superClass) {
    extend(FBProvider, superClass);

    function FBProvider(type, config) {
      this.share = bind(this.share, this);
      this.wallPost = bind(this.wallPost, this);
      FBProvider.__super__.constructor.call(this, type, config);
      this._storageKey = 'social_data_fb';
      this._tokenUri = 'https://www.facebook.com/dialog/oauth';
      this._methodUri = 'https://graph.facebook.com/v2.4/';
      this._scopeMapping = {};
      this._scopeMapping[this.SCOPE_ID] = 'public_profile';
      this._scopeMapping[this.SCOPE_NAME] = 'public_profile';
      this._scopeMapping[this.SCOPE_GENDER] = 'public_profile';
      this._scopeMapping[this.SCOPE_EMAIL] = 'email';
      this._scopeMapping[this.SCOPE_FRIENDS] = 'user_friends';
      this._scopeMapping[this.SCOPE_WALL] = 'public_profile';
      this._scopeMapping[this.SCOPE_MESSAGES] = 'public_profile';
      this._forceTokenData = {
        'auth_type': 'rerequest'
      };
      this._init(config);
    }

    FBProvider.prototype.wallPost = function(data) {
      var defData, uri;
      if (this._checkScopeGranted(this.SCOPE_WALL) === false) {
        return this.grantScopeRequest(this.SCOPE_WALL).then(this.wallPost, this._onError);
      }
      defData = {
        from: this._session.user_id,
        app_id: this._appId,
        redirect_uri: this._tokenRedirectUri
      };
      data = $.extend(defData, data);
      uri = 'https://www.facebook.com/dialog/feed';
      return this._showPopup(uri, data);
    };

    FBProvider.prototype.share = function(data) {
      var defData, uri;
      uri = 'https://www.facebook.com/dialog/feed';
      defData = {
        app_id: this._appId,
        display: 'popup',
        redirect_uri: this._tokenRedirectUri
      };
      if ((data != null ? data.url : void 0)) {
        defData.link = data.url;
      }
      if ((data != null ? data.title : void 0)) {
        defData.caption = data.title;
      }
      if ((data != null ? data.image : void 0)) {
        defData.picture = data.image;
      }
      if ((data != null ? data.description : void 0)) {
        defData.description = data.description;
      }
      return this._showPopup(uri, defData);
    };

    FBProvider.prototype._loadFriendIds = function(deferred) {
      var data, self;
      data = {
        access_token: this._token
      };
      self = this;
      return this._methodCall('me/friends', data).then(function(data) {
        var friendIds, resultData;
        resultData = {
          status: 'error'
        };
        if ((data != null) && (data != null ? data.error : void 0)) {
          self._setError(data.error.code, data.error.message);
          resultData.error = self.getError();
        } else if (data != null) {
          friendIds = [];
          if (data && data.summary.total_count > 0) {
            friendIds = data.data.map(function(n) {
              return n.id;
            });
          }
        }
        resultData.status = 'success';
        resultData.friendIds = friendIds;
        if (resultData.status === 'success') {
          return deferred.resolve(resultData);
        } else {
          return deferred.reject(resultData);
        }
      }, self._getXHRErrorHandler(deferred));
    };

    FBProvider.prototype._loadUserData = function(deferred) {
      var data, self;
      data = {
        fields: 'first_name,email,last_name,gender,id',
        access_token: this._token
      };
      self = this;
      return this._methodCall('me', data).then(function(data) {
        var resultData, userData;
        resultData = {
          status: 'error'
        };
        if ((data != null) && (data != null ? data.error : void 0)) {
          self._setError(data.error.code, data.error.message);
          resultData.error = self.getError();
        } else if (data != null) {
          userData = {
            user_id: data.id,
            email: (data != null ? data.email : void 0) ? data.email : null,
            first_name: data.first_name,
            last_name: data.last_name,
            full_name: (data.first_name + ' ' + data.last_name).trim(),
            birth_date: null,
            sex: (data != null ? data.gender : void 0) && data.gender === 'female' ? 'female' : 'male'
          };
          resultData.status = 'success';
          resultData.user = userData;
          self._storeUserData(userData);
        } else {
          self._setError('FATAL_ERROR', 'Failed to load userData');
          resultData.error = self.getError();
        }
        if (resultData.status === 'success') {
          return deferred.resolve(resultData);
        } else {
          return deferred.reject(resultData);
        }
      }, self._getXHRErrorHandler(deferred));
    };

    FBProvider.prototype._loadGrantedScope = function(deferred) {
      var data, self;
      data = {
        access_token: this._token
      };
      self = this;
      return this._methodCall('me/permissions', data).then(function(data) {
        var i, item, len, ref, resultData, scopeList;
        resultData = {
          status: 'error'
        };
        if ((data != null) && (data != null ? data.error : void 0)) {
          self._setError(data.error.code, data.error.message);
          resultData.error = self.getError();
        } else if (data != null) {
          scopeList = [];
          ref = data.data;
          for (i = 0, len = ref.length; i < len; i++) {
            item = ref[i];
            if (item.status === 'granted') {
              scopeList.push(item.permission);
            }
          }
          self._tokenVerified = true;
          self._session.scopeMask = self._scopeListToMask(scopeList);
          self._saveSessionData(self._session);
          resultData.status = 'success';
          resultData.scopeList = scopeList;
        }
        if (resultData.status === 'success') {
          return deferred.resolve(resultData);
        } else {
          return deferred.reject(resultData);
        }
      }, self._getXHRErrorHandler(deferred));
    };

    return FBProvider;

  })(BaseProvider);
  return FBProvider;
});
