var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['jquery', 'services/social/base'], function($, BaseProvider) {
  var VKProvider;
  VKProvider = (function(superClass) {
    extend(VKProvider, superClass);

    function VKProvider(type, config) {
      this._tokenRequest = bind(this._tokenRequest, this);
      VKProvider.__super__.constructor.call(this, type, config);
      this._storageKey = 'social_data_vk';
      this._tokenUri = 'https://oauth.vk.com/authorize';
      this._methodUri = 'https://api.vk.com/method/';
      this._scopeMapping = {};
      this._scopeMapping[this.SCOPE_EMAIL] = 'email';
      this._scopeMapping[this.SCOPE_FRIENDS] = 'friends';
      this._scopeMapping[this.SCOPE_WALL] = 'wall';
      this._scopeMapping[this.SCOPE_MESSAGES] = 'messages';
      this._scopeMapping[this.SCOPE_OFFLINE] = 'offline';
      this._scopeBitsMapping = {};
      this._scopeBitsMapping[this.SCOPE_EMAIL] = 4194304;
      this._scopeBitsMapping[this.SCOPE_FRIENDS] = 2;
      this._scopeBitsMapping[this.SCOPE_WALL] = 8192;
      this._scopeBitsMapping[this.SCOPE_MESSAGES] = 4096;
      this._scopeBitsMapping[this.SCOPE_OFFLINE] = 65536;
      this._forceTokenData = {
        'revoke': '1'
      };
      this._init(config);
    }

    VKProvider.prototype.share = function(data) {
      var uri;
      uri = 'http://vk.com/share.php';
      return this._showPopup(uri, data);
    };

    VKProvider.prototype.wallPost = function(data) {
      if (this._checkScopeGranted(this.SCOPE_WALL) === false) {
        return this.grantScopeRequest(this.SCOPE_WALL).then(this.wallPost, this._onError);
      }
      data = {
        owner_id: this._session.user_id,
        access_token: this._session.token
      };
      return this._methodCall('wall.post', data);
    };

    VKProvider.prototype._loadFriendIds = function(deferred) {
      var data, self;
      data = {
        user_id: this._session.user_id,
        access_token: this._session.token,
        fields: 'nickname,sex,country'
      };
      self = this;
      return this._methodCall('friends.get', data).then(function(data) {
        var friendIds, friends, resultData;
        resultData = {
          status: 'error'
        };
        if ((data != null) && (data != null ? data.error : void 0)) {
          self._setError(data.error.code, data.error.message);
          resultData.error = self.getError();
        } else if (data) {
          friends = data.response;
          friendIds = friends.filter(function(n) {
            return !n.deactivated;
          }).map(function(n) {
            return n.user_id;
          });
          resultData.status = 'success';
          resultData.friendIds = friendIds;
        }
        if (resultData.status === 'success') {
          return deferred.resolve(resultData);
        } else {
          return deferred.reject(resultData);
        }
      }, self._getXHRErrorHandler(deferred));
    };

    VKProvider.prototype._loadUserData = function(deferred) {
      var data, self;
      data = {
        user_ids: this._session.user_id,
        fields: 'sex,bdate,city,country,contacts',
        access_token: this._session.token
      };
      self = this;
      return this._jsonpCall('users.get', data).then(function(data) {
        var response, resultData, userData;
        resultData = {
          status: 'error'
        };
        if ((data != null) && (data != null ? data.error : void 0)) {
          self._setError(data.error.code, data.error.message);
          resultData.error = self.getError();
        } else if (data != null) {
          response = data.response[0];
          userData = {
            user_id: (response != null ? response.id : void 0) ? response.id : self._session.user_id,
            email: (response != null ? response.email : void 0) ? response.email : self._session.email,
            first_name: response.first_name,
            last_name: response.last_name,
            full_name: (response.first_name + ' ' + response.last_name).trim(),
            birth_date: null,
            sex: (response != null ? response.sex : void 0) && response.sex === 1 ? 'female' : 'male'
          };
          resultData.status = 'success';
          resultData.user = userData;
          self._storeUserData(userData);
        } else {
          self._setError('FATAL_ERROR', 'Failed to load userData');
          resultData.error = self.getError();
        }
        if (resultData.status === 'success') {
          return deferred.resolve(resultData);
        } else {
          return deferred.reject(resultData);
        }
      }, self._getXHRErrorHandler(deferred));
    };

    VKProvider.prototype._loadGrantedScope = function(deferred) {
      var data, self;
      data = {
        user_id: this._session.user_id,
        access_token: this._token
      };
      self = this;
      return this._jsonpCall('account.getAppPermissions', data).then(function(data) {
        var bit, ref, resultData, resultMask, scopeList, vkBit, vkMask;
        resultData = {
          status: 'error'
        };
        if ((data != null) && (data != null ? data.error : void 0)) {
          self._setError(data.error.code, data.error.message);
          resultData.error = self.getError();
        } else if (data != null) {
          scopeList = [];
          resultMask = 0;
          vkMask = data.response;
          ref = self._scopeBitsMapping;
          for (bit in ref) {
            vkBit = ref[bit];
            if (vkMask & vkBit) {
              resultMask = resultMask | bit;
              scopeList.push(self._scopeMapping[bit]);
            }
          }
          self._tokenVerified = true;
          self._session.scopeMask = resultMask;
          self._saveSessionData(self._session);
          resultData.status = 'success';
          resultData.scopeList = scopeList;
        }
        if (resultData.status === 'success') {
          return deferred.resolve(resultData);
        } else {
          return deferred.reject(resultData);
        }
      }, self._getXHRErrorHandler(deferred));
    };

    VKProvider.prototype._tokenRequest = function(scopeMask, force) {
      var data;
      data = this._getTokenRequestData(scopeMask, force);
      return this._showPopup(this._tokenUri, data).then(this._afterAuth, this._onError).then(this._getCurrentUserData);
    };

    VKProvider.prototype._prepareRequest = function(url, params) {
      var self;
      self = this;
      params['callback'] = '__';
      url = url + '?' + $.param(params);
      return $.ajax({
        url: url,
        dataType: "text"
      }).then(function(data) {
        var e;
        if (data) {
          data = data.substr(params['callback'].length + 1);
          data = data.substr(0, data.length - 2);
          try {
            data = JSON.parse(data);
            return data;
          } catch (_error) {
            e = _error;
            return null;
          }
        } else {
          return null;
        }
      });
    };

    return VKProvider;

  })(BaseProvider);
  return VKProvider;
});
