var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['underscore', 'app', 'views/item-view', 'text!templates/blueprints/create.tmpl', 'views/components/strings-helper'], function(_, app, ItemView, template, StringsHelper) {
  var BlueprintsCreateView;
  BlueprintsCreateView = (function(superClass) {
    extend(BlueprintsCreateView, superClass);

    function BlueprintsCreateView() {
      this._preprocessConfig = bind(this._preprocessConfig, this);
      this.getStickyScrollHandler = bind(this.getStickyScrollHandler, this);
      this.bindStickyHeader = bind(this.bindStickyHeader, this);
      this.onDomRefresh = bind(this.onDomRefresh, this);
      this._onScreenBack = bind(this._onScreenBack, this);
      return BlueprintsCreateView.__super__.constructor.apply(this, arguments);
    }

    BlueprintsCreateView.prototype.template = template;

    BlueprintsCreateView.prototype.className = 'no-bg-image';

    BlueprintsCreateView.prototype.data = {
      config: 'blueprints.get_config'
    };

    BlueprintsCreateView.prototype.events = {
      'click .js-next': 'onNextBtnClick',
      'click .js-roller-select': 'onInputClick',
      'click .js-blueprint-group-toggle': 'onPropertyClick'
    };

    BlueprintsCreateView.prototype.initialize = function(options) {
      BlueprintsCreateView.__super__.initialize.call(this, options);
      this._reset();
      this.off('dom:refresh', this.resetContentScrollPosition);
      this.off('screens:back', this.resetContentScrollPosition);
      this.on('screens:back', this._onScreenBack);
      return this.on('data:loaded', this._preprocessConfig);
    };

    BlueprintsCreateView.prototype.onDestroy = function() {
      return this._reset();
    };

    BlueprintsCreateView.prototype._reset = function() {
      this._config = null;
      this._types = null;
      this._classes = null;
      this._params = null;
      this._itemTypes = null;
      this._itemCategories = null;
      this._propertyItems = null;
      this._itemLevelMultipliers = null;
      this._foodCategoriesCoefficients = null;
      this._userValues = {};
      this._computedValues = {};
      return this._openedGroups = {};
    };

    BlueprintsCreateView.prototype._onScreenBack = function() {
      this.resetContentScrollPosition(false);
      return this.bindStickyHeader();
    };

    BlueprintsCreateView.prototype.onDomRefresh = function() {
      this.resetContentScrollPosition(false);
      return this.bindStickyHeader();
    };

    BlueprintsCreateView.prototype.onNextBtnClick = function(event) {
      var data, errors, name, prop, properties, ref;
      errors = this.validateUserValues();
      if (errors.length) {
        this.displayErrors(errors);
        return;
      }
      properties = {};
      ref = this._params.properties;
      for (name in ref) {
        prop = ref[name];
        properties[name] = prop.title || name;
      }
      data = {
        userValues: this._userValues,
        computedValues: this._computedValues,
        properties: properties
      };
      return app.screens.dialog('blueprints/create-finish', data);
    };

    BlueprintsCreateView.prototype.onPropertyClick = function(event) {
      var group, wrapper;
      group = event.currentTarget.dataset.group;
      wrapper = event.currentTarget.parentNode;
      wrapper.classList.toggle('c-blueprints-group--open');
      if (wrapper.classList.contains('c-blueprints-group--open')) {
        return this._openedGroups[group] = true;
      } else {
        return this._openedGroups[group] = false;
      }
    };

    BlueprintsCreateView.prototype.onInputClick = function(event) {
      var element, options, value;
      this.saveContentScrollPosition();
      element = event.currentTarget;
      if (element.dataset.value) {
        value = Number(element.dataset.value);
      } else {
        value = Number(element.textContent.trim());
      }
      options = this.getOptionsForElement(element);
      return app.screens.modal('common/simple-select-dialog', {
        values: options,
        selected: value,
        callback: (function(_this) {
          return function(val) {
            _this.setUserValueFromElement(element, val);
            _this.recompute();
            return _this.render();
          };
        })(this)
      });
    };

    BlueprintsCreateView.prototype.serializeData = function() {
      var data;
      data = BlueprintsCreateView.__super__.serializeData.call(this);
      if (this._types) {
        data.types = this._types;
        data.classes = this._classes;
        data.params = this._params;
        data.propertyItems = this._propertyItems;
        data.itemCategories = this._itemCategories;
      }
      data.userValues = this._userValues;
      data.computedValues = this._computedValues;
      data.openedGroups = this._openedGroups;
      return data;
    };

    BlueprintsCreateView.prototype.recompute = function() {
      var baseMaxRange, baseStrengthVal, durabilityCoefficient, fn, name, property, rangeCoefficient, ref, resources, value;
      this._computedValues = {
        properties: {},
        base_parameters: {}
      };
      if (!this._params) {
        return;
      }
      baseStrengthVal = 0;
      if (this._params.base_parameters.strength_val) {
        baseStrengthVal = this._params.base_parameters.strength_val;
      }
      durabilityCoefficient = 1;
      if (baseStrengthVal && this._userValues.base_parameters.strength_val) {
        this._computedValues.base_parameters.strength_val = this._userValues.base_parameters.strength_val;
        durabilityCoefficient = baseStrengthVal / this._userValues.base_parameters.strength_val;
      }
      baseMaxRange = 0;
      if (this._params.base_parameters.max_range) {
        baseMaxRange = this._params.base_parameters.max_range;
      }
      rangeCoefficient = 1;
      if (baseMaxRange && this._userValues.base_parameters.max_range) {
        this._computedValues.base_parameters.max_range = this._userValues.base_parameters.max_range;
        rangeCoefficient = this._computedValues.base_parameters.max_range;
      }
      ref = this._params.properties;
      for (name in ref) {
        property = ref[name];
        value = 0;
        resources = {};
        if (this._userValues.properties && this._userValues.properties[name]) {
          resources = this._userValues.properties[name];
        }
        fn = this._functions[property.fn];
        value = fn.apply(this, [property.fn_args, resources, this._itemTypes]) * durabilityCoefficient;
        if (name === 'max_damage') {
          value = value / rangeCoefficient;
        }
        if (name === 'prestige') {
          value = Math.floor(value);
        }
        this._computedValues.properties[name] = +(Math.round(value + "e+2") + "e-2");
      }
      this._computedValues.productionPoints = Math.round(this._functions['productionPointsRelation'].apply(this, [this._userValues.properties, this._itemTypes]));
      return this._computedValues.price = this._functions['priceRelation'].apply(this, [this._userValues.properties, this._itemTypes]);
    };

    BlueprintsCreateView.prototype.validateUserValues = function() {
      var baseMaxRange, baseStrengthVal, categoryId, errors, itemId, items, name, propConfig, quantity, quantityByCategory, ref, ref1, totalItemsCount, totalPropItemsCount, trParams;
      errors = [];
      baseStrengthVal = 0;
      if (this._params.base_parameters.strength_val) {
        baseStrengthVal = this._params.base_parameters.strength_val;
      }
      if (baseStrengthVal && (!this._userValues.base_parameters.strength_val || this._userValues.base_parameters.strength_val < baseStrengthVal)) {
        errors.push(app.tr('Select Durability within a valid range'));
      }
      baseMaxRange = 0;
      if (this._params.base_parameters.max_range) {
        baseMaxRange = this._params.base_parameters.max_range;
      }
      if (baseMaxRange && (!this._userValues.base_parameters.max_range || this._userValues.base_parameters.max_range < baseMaxRange)) {
        errors.push(app.tr('Select Distance within a valid range'));
      }
      totalItemsCount = 0;
      ref = this._params.properties;
      for (name in ref) {
        propConfig = ref[name];
        items = this._userValues.properties[name] || {};
        totalPropItemsCount = 0;
        quantityByCategory = {};
        for (itemId in items) {
          quantity = items[itemId];
          totalItemsCount += quantity;
          totalPropItemsCount += quantity;
          categoryId = this._itemTypes[itemId] ? Number(this._itemTypes[itemId].category_id) : null;
          if (categoryId) {
            if (!quantityByCategory[categoryId]) {
              quantityByCategory[categoryId] = quantity;
            } else {
              quantityByCategory[categoryId] += quantity;
            }
          }
        }
        if (propConfig.quantity_by_category_id) {
          ref1 = propConfig.quantity_by_category_id;
          for (categoryId in ref1) {
            quantity = ref1[categoryId];
            categoryId = Number(categoryId);
            trParams = {
              '{{category}}': this._itemCategories[categoryId] || '',
              '{{property}}': this._params.properties[name].title
            };
            if (quantity[0] > 0 && (!quantityByCategory[categoryId] || quantityByCategory[categoryId] < quantity[0])) {
              errors.push(StringsHelper.replace(trParams, app.tr('You need more resources of type {{category}} for {{property}}')));
            }
            if (quantity[1] > 0 && (quantityByCategory[categoryId] && quantityByCategory[categoryId] > quantity[1])) {
              errors.push(StringsHelper.replace(trParams, app.tr('You selected too many resources of type {{category}} for {{property}}')));
            }
          }
          if (this._params.properties[name].quantity_total) {
            if (this._params.properties[name].quantity_total[0] > 0 && totalPropItemsCount < this._params.properties[name].quantity_total[0]) {
              errors.push(StringsHelper.replace(trParams, app.tr('You need more resources for {{property}}')));
            }
            if (this._params.properties[name].quantity_total[1] > 0 && totalPropItemsCount > this._params.properties[name].quantity_total[1]) {
              errors.push(StringsHelper.replace(trParams, app.tr('You selected too many resources for {{property}}')));
            }
          }
        }
      }
      if (totalItemsCount < 1) {
        errors.push(app.tr('You need to use at least one resource'));
      }
      return errors;
    };

    BlueprintsCreateView.prototype.displayErrors = function(errors) {
      if (errors.length > 0) {
        return app.screens.modal('common/info-popup', {
          msg: errors[errors.length - 1]
        });
      }
    };

    BlueprintsCreateView.prototype.setUserValueFromElement = function(el, val) {
      var itemId, prop, type, uType;
      type = el.dataset.type;
      switch (type) {
        case 'type':
          this._userValues = {
            type: val,
            "class": Object.keys(this._classes[val])[0],
            properties: {},
            base_parameters: {}
          };
          this._rebuildConfigCache();
          if (this._params.base_parameters) {
            return _.extend(this._userValues.base_parameters, this._params.base_parameters);
          }
          break;
        case 'class':
          uType = this._userValues.type;
          this._userValues = {
            type: uType,
            "class": val,
            properties: {},
            base_parameters: {}
          };
          this._rebuildConfigCache();
          if (this._params.base_parameters) {
            return _.extend(this._userValues.base_parameters, this._params.base_parameters);
          }
          break;
        case 'strength_val':
          return this._userValues.base_parameters.strength_val = Number(val);
        case 'max_range':
          return this._userValues.base_parameters.max_range = Number(val);
        case 'property':
          prop = el.dataset.property;
          itemId = Number(el.dataset.item);
          if (!this._userValues.properties[prop]) {
            this._userValues.properties[prop] = {};
          }
          return this._userValues.properties[prop][itemId] = Number(val);
      }
    };

    BlueprintsCreateView.prototype.getOptionsForElement = function(el) {
      var categoryId, i, itemId, j, k, l, m, max, min, options, prop, ref, ref1, ref2, ref3, ref4, ref5, type;
      options = {};
      type = el.dataset.type;
      switch (type) {
        case 'type':
          options = this._types;
          break;
        case 'class':
          options = this._classes[this._userValues.type];
          break;
        case 'strength_val':
          min = 10;
          max = 100;
          if (this._params.base_parameters && this._params.base_parameters.strength_val) {
            min = this._params.base_parameters.strength_val;
          }
          for (i = j = ref = min, ref1 = max; j <= ref1; i = j += 10) {
            options[i] = i;
          }
          break;
        case 'max_range':
          min = 1;
          max = 10;
          if (this._params.base_parameters && this._params.base_parameters.max_range) {
            min = this._params.base_parameters.max_range;
          }
          for (i = k = ref2 = min, ref3 = max; ref2 <= ref3 ? k <= ref3 : k >= ref3; i = ref2 <= ref3 ? ++k : --k) {
            options[i] = i;
          }
          break;
        case 'property':
          min = 0;
          max = 1000;
          prop = el.dataset.property;
          itemId = Number(el.dataset.item);
          categoryId = this._itemTypes[itemId] ? Number(this._itemTypes[itemId].category_id) : null;
          if (this._params.parameters && this._params.parameters[prop]) {
            if (this._params.parameters[prop].quantity_by_category_id && this._params.parameters[prop].quantity_by_category_id[categoryId]) {
              max = this._params.parameters[prop].quantity_by_category_id[categoryId][1];
            } else if (this._params.parameters[prop].quantity_total) {
              max = this._params.parameters[prop].quantity_total[categoryId][1];
            }
          }
          for (i = l = ref4 = min, ref5 = max; l <= ref5; i = l += 1) {
            options[i] = i;
          }
          break;
        default:
          for (i = m = 1; m <= 100; i = ++m) {
            options[i] = i;
          }
      }
      return options;
    };

    BlueprintsCreateView.prototype.bindStickyHeader = function() {
      var el, stickyEl;
      if (!this.el.offsetParent) {
        return;
      }
      el = this.el.querySelector('.c-content-wrapper');
      if (el && !el.dataset.scrolling) {
        stickyEl = this.el.querySelector('#sticky-header');
        if (stickyEl) {
          el.addEventListener('scroll', this.getStickyScrollHandler(el, stickyEl));
          return el.dataset.scrolling = true;
        }
      }
    };

    BlueprintsCreateView.prototype.getStickyScrollHandler = function(wrapper, stickyEl) {
      var elOffset, fn, top;
      top = wrapper.getBoundingClientRect().top;
      elOffset = stickyEl.offsetTop - 10;
      fn = (function(_this) {
        return function(event) {
          arguments.callee.__called++;
          if (arguments.callee.__called % 2 !== 0) {
            return;
          }
          if (wrapper.scrollTop > elOffset) {
            if (stickyEl.style.position !== 'fixed') {
              stickyEl.style.position = 'fixed';
              stickyEl.style.top = top + 'px';
              stickyEl.nextElementSibling.style.display = 'block';
            }
          } else {
            stickyEl.nextElementSibling.style.display = 'none';
            stickyEl.style.position = 'relative';
            stickyEl.style.top = '';
          }
          return true;
        };
      })(this);
      fn.__called = 1;
      fn(null);
      return fn;
    };

    BlueprintsCreateView.prototype._preprocessConfig = function(data) {
      var body, categories, category, config, firstType, index, j, len, name, ref, ref1;
      if (!data.config) {
        return;
      }
      config = data.config;
      this._types = config.types;
      this._classes = {};
      ref = config.config;
      for (name in ref) {
        categories = ref[name];
        this._classes[name] = {};
        for (index = j = 0, len = categories.length; j < len; index = ++j) {
          category = categories[index];
          this._classes[name][index] = category.title;
        }
      }
      this._itemLevelMultipliers = config.itemLevelMultipliers;
      this._foodCategoriesCoefficients = config.foodCategoriesCoefficients;
      this._itemTypes = config.itemTypes;
      this._itemCategories = config.itemCategories;
      this._config = config.config;
      this._functions = {};
      ref1 = config.relations;
      for (name in ref1) {
        body = ref1[name];
        this._functions[name] = eval('(' + body + ')');
      }
      if (!this._userValues || !this._userValues.type) {
        firstType = Object.keys(this._types)[0];
        this._userValues = {
          type: firstType,
          "class": Object.keys(this._classes[firstType])[0],
          properties: {},
          base_parameters: {}
        };
        this._rebuildConfigCache();
        if (this._params.base_parameters) {
          _.extend(this._userValues.base_parameters, this._params.base_parameters);
        }
        this.recompute();
      }
      return data;
    };

    BlueprintsCreateView.prototype._rebuildConfigCache = function() {
      var id, item, name, prop, propertyItems, ref, ref1;
      this._params = null;
      if (this._userValues["class"] && this._userValues.type) {
        this._params = this._config[this._userValues.type][this._userValues["class"]];
        propertyItems = {};
        ref = this._params.properties;
        for (name in ref) {
          prop = ref[name];
          propertyItems[name] = [];
          ref1 = this._itemTypes;
          for (id in ref1) {
            item = ref1[id];
            if (prop.resources_category_id.indexOf(item.category_id) !== -1) {
              propertyItems[name].push(item);
            }
          }
          propertyItems[name].sort(function(a, b) {
            var so;
            so = a.category_id - b.category_id;
            if (so === 0) {
              so = a.level - b.level;
            }
            return so;
          });
          this._setPropResourceLimitsString(prop);
        }
        return this._propertyItems = propertyItems;
      }
    };

    BlueprintsCreateView.prototype._setPropResourceLimitsString = function(prop) {
      var categoryId, categoryLimits, limits, quantity, ref;
      limits = [];
      if (prop.quantity_by_category_id) {
        ref = prop.quantity_by_category_id;
        for (categoryId in ref) {
          quantity = ref[categoryId];
          if ((quantity[0] > 0 || quantity[1] > 0) && this._itemCategories[categoryId]) {
            categoryLimits = [];
            if (quantity[0] > 0) {
              categoryLimits.push(app.tr('min') + ' ' + quantity[0]);
            }
            if (quantity[1] > 0) {
              categoryLimits.push(app.tr('max') + ' ' + quantity[1]);
            }
            limits.push(this._itemCategories[categoryId] + ': ' + categoryLimits.join(', '));
          }
        }
      }
      if (prop.quantity_total && (prop.quantity_total[0] > 0 || prop.quantity_total[1] > 0)) {
        categoryLimits = [];
        if (prop.quantity_total[0] > 0) {
          categoryLimits.push(app.tr('min') + ' ' + prop.quantity_total[0]);
        }
        if (prop.quantity_total[1] > 0) {
          categoryLimits.push(app.tr('max') + ' ' + prop.quantity_total[1]);
        }
        limits.push(app.tr('Resources total') + ': ' + categoryLimits.join(', '));
      }
      if (limits.length) {
        return prop.resourceLimitsString = limits.join('; ');
      }
    };

    return BlueprintsCreateView;

  })(ItemView);
  return BlueprintsCreateView;
});
