define(['app', 'views/item-view', 'underscore', 'text!templates/business/capital.tmpl', 'views/components/currency'], function(app, ItemView, _, template, formatCurrency) {
  return ItemView.extend({
    template: template,
    data: {
      corporationInfo: {
        pointer: 'business.corporationInfo',
        corporationId: function() {
          return this.options.corporationId;
        }
      },
      corporationDividends: {
        pointer: 'business.corporationDividends',
        corporationId: function() {
          return this.options.corporationId;
        },
        limit: 3
      }
    },
    events: {
      'click .js-goto-company': 'gotoCompany',
      'click .js-goto-management': 'gotoManagement',
      'click .js-goto-corporation-storage': 'gotoCorporationStorage',
      'click .js-goto-shareholders': 'gotoShareholders',
      'click .js-create-company': 'createCompany',
      'click .js-invest': 'invest',
      'click .js-all-dividends': 'showAllDividends',
      'click @ui.close': 'dropdownBehaviour'
    },
    ui: {
      close: '.dropdown__title'
    },
    preprocessData: function(data) {
      var dividends, i, len, ref;
      if (data != null) {
        ref = data.corporationDividends.dividends_info;
        for (i = 0, len = ref.length; i < len; i++) {
          dividends = ref[i];
          dividends.CorporationSolution.solution.vd_amount_reserved = this.numberFormat(dividends.CorporationSolution.solution.vd_amount_reserved);
        }
      }
      return data;
    },
    notManagerAlert: function(event) {
      return app.screens.modal('common/info-popup', {
        msg: app.tr("You are not a company's manager")
      });
    },
    gotoCompany: function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('corporative_companies/common', {
          companyId: companyId
        });
      });
    },
    gotoManagement: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/management', {
        corporationId: corporationId
      });
    },
    gotoCorporationStorage: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/corp-storage', {
        corporationId: corporationId
      });
    },
    gotoShareholders: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/shareholders', {
        corporationId: corporationId
      });
    },
    createCompany: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('business/create-company', {
          corporationId: corporationId
        });
      });
    },
    invest: function(event) {
      var corporationId, vd_balance, vg_balance;
      this.lockUI();
      corporationId = this.options.corporationId;
      vd_balance = this._data.corporationInfo.currentCorporation.vd_balance;
      vg_balance = this._data.corporationInfo.currentCorporation.vg_balance;
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('business/corp-invest', {
          corporationId: corporationId,
          vd_balance: vd_balance,
          vg_balance: vg_balance
        });
      });
    },
    showAllDividends: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.dialog('business/corporation-dividends', {
        corporationId: corporationId,
        limit: 0,
        corporation: {
          name: this._data.corporationInfo.currentCorporation.name
        }
      });
    },
    dropdownBehaviour: function(e) {
      var dropdown;
      dropdown = $(e.currentTarget).closest('.dropdown');
      dropdown.toggleClass('is-active');
      dropdown.find('.dropdown__title icon').toggleClass('o-icon--down-arrow o-icon--up-arrow');
      return dropdown.find('.dropdown__details').toggle();
    },
    onDomRefresh: function() {
      return [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        if (el.dataset.precision) {
          return el.innerHTML = formatCurrency(el.innerHTML, void 0, el.dataset.precision);
        } else {
          return el.innerHTML = formatCurrency(el.innerHTML);
        }
      });
    }
  });
});
