define(['app', 'views/item-view', 'underscore', 'text!templates/business/initiative-emission.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      emission: {
        pointer: 'business.getEmissionPrice'
      }
    },
    events: {
      'click .js-apply': 'saveProposal',
      'change .js-amount': 'calculatePrice'
    },
    preprocessData: function(data) {
      this.options.emissionPrice = data.emission.emission_price.price;
      return data;
    },
    calculatePrice: function(event) {
      var amount, emissionPrice;
      emissionPrice = this.options.emissionPrice;
      amount = this.$el.find('.js-amount').val();
      if (!isNaN(amount)) {
        return this.$el.find('.price').html(emissionPrice * amount / 1000);
      }
    },
    saveProposal: function(event) {
      var amount, corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      amount = this.$el.find('.js-amount').val();
      if (amount === "") {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("You haven't input anything")
        });
      } else {
        if (isNaN(amount)) {
          return app.screens.modal('common/info-popup', {
            msg: app.tr("The amount may consist only of digits")
          });
        } else {
          return app.server.business.proposeEmmision({
            corporationId: corporationId,
            amount: amount,
            success: function(data) {
              return app.screens.modal('common/success-popup', {
                msg: data.setFlash[0].msg || app.tr("Action was successful")
              }, app.screens.back());
            },
            error: function(data) {
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            }
          });
        }
      }
    }
  });
});
