define(['app', 'views/item-view', 'underscore', 'text!templates/business/initiative-manager.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      corporationInfo: {
        pointer: 'business.corporationInfo',
        corporationId: function() {
          return this.options.corporationId;
        }
      },
      shareHolders: {
        pointer: 'business.shareHolders',
        corporationId: function() {
          return this.options.corporationId;
        }
      }
    },
    events: {
      'click .js-apply': 'submitSuggestion',
      'click .js-hire-manager': 'onSelectToHire',
      'click .js-fire-manager': 'onSelectToFire'
    },
    _maxManagers: 3,
    _userToHire: 0,
    _userToFire: 0,
    onSelectToHire: function(event) {
      var element, userId;
      this._resetSelection();
      element = event.currentTarget;
      userId = element.getAttribute('data-id');
      if (userId) {
        element.classList.remove('c-round-btn-ex--gray');
        element.classList.add('c-round-btn-ex--green');
        return this._userToHire = userId;
      }
    },
    onSelectToFire: function(event) {
      var element, userId;
      this._resetSelection();
      element = event.currentTarget;
      userId = element.getAttribute('data-id');
      if (userId) {
        element.classList.remove('c-round-btn-ex--gray');
        element.classList.add('c-round-btn-ex--red');
        return this._userToFire = userId;
      }
    },
    preprocessData: function(data) {
      var holder, i, len, managersToFire, ref, shareHoldersToHire;
      shareHoldersToHire = [];
      managersToFire = [];
      if (data.shareHolders && data.shareHolders.listStockholders) {
        ref = data.shareHolders.listStockholders;
        for (i = 0, len = ref.length; i < len; i++) {
          holder = ref[i];
          if (holder.status === 'manager') {
            managersToFire.push(holder);
          } else {
            shareHoldersToHire.push(holder);
          }
        }
      }
      data.shareHoldersToHire = shareHoldersToHire;
      data.managersToFire = managersToFire;
      data.canHire = data.managersToFire.length < this._maxManagers;
      return data;
    },
    _resetSelection: function() {
      var element, fire, hire, i, j, len, len1, results;
      this._userToHire = 0;
      this._userToFire = 0;
      fire = this.el.querySelectorAll('.js-fire-manager');
      for (i = 0, len = fire.length; i < len; i++) {
        element = fire[i];
        element.classList.remove('c-round-btn-ex--red');
        element.classList.add('c-round-btn-ex--gray');
      }
      hire = this.el.querySelectorAll('.js-hire-manager');
      results = [];
      for (j = 0, len1 = hire.length; j < len1; j++) {
        element = hire[j];
        element.classList.remove('c-round-btn-ex--green');
        results.push(element.classList.add('c-round-btn-ex--gray'));
      }
      return results;
    },
    submitSuggestion: function() {
      var fn, userId;
      if (!this._userToHire && !this._userToFire) {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Select manager you want to fire or shareholder you want to hire as new manager")
        });
        return;
      }
      if (this._userToFire) {
        userId = this._userToFire;
        fn = app.server.business.proposeChangeManagerDown;
      } else if (this._userToHire) {
        userId = this._userToHire;
        fn = app.server.business.proposeChangeManagerUp;
      }
      if (!userId) {
        return;
      }
      return fn({
        userId: userId,
        corporationId: this.options.corporationId,
        success: function(data) {
          return app.screens.modal('common/success-popup', {
            msg: data.setFlash[0].msg || app.tr("Action was successful")
          }, app.screens.back());
        },
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    }
  });
});
