define(['app', 'views/item-view', 'underscore', 'text!templates/business/management.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      corporationInfo: {
        pointer: 'business.corporationInfo',
        corporationId: function() {
          return this.options.corporationId;
        }
      },
      corporationVotes: {
        pointer: 'business.corporationVotes',
        corporationId: function() {
          return this.options.corporationId;
        }
      }
    },
    events: {
      'click .js-goto-capital': 'gotoCapital',
      'click .js-goto-corporation-storage': 'gotoCorporationStorage',
      'click .js-goto-shareholders': 'gotoShareholders',
      'click .js-goto-proposals': 'gotoProposals',
      'click .js-vote-positive': 'votePositive',
      'click .js-vote-negative': 'voteNegative',
      'click .js-buyout-stocks-accept': 'buyoutStocksAccept',
      'click .js-buyout-stocks-reject': 'buyoutStocksReject'
    },
    gotoCapital: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/capital', {
        corporationId: corporationId
      });
    },
    gotoCorporationStorage: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/corp-storage', {
        corporationId: corporationId
      });
    },
    gotoShareholders: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.tab('business/shareholders', {
        corporationId: corporationId
      });
    },
    gotoProposals: function(event) {
      var corporationId;
      this.lockUI();
      corporationId = this.options.corporationId;
      return app.screens.dialog('business/initiative', {
        corporationId: corporationId
      });
    },
    votePositive: function(event) {
      this.lockUI();
      return app.quests.doIfCompleted('social_passport', (function(_this) {
        return function() {
          var corporationId, loader, solutionId;
          solutionId = event.currentTarget.getAttribute('data-solution-id');
          corporationId = _this.options.corporationId;
          loader = _this.setLoaderOnElement(event.currentTarget, app.tr('Voting'));
          return app.server.business.proposeVotePositive({
            solutionId: solutionId,
            corporationId: corporationId,
            success: function(data) {
              return _this.listenToOnce(app.vent, 'business/management:dataLoaded', function() {
                loader.remove();
                return this.unlockUI();
              });
            },
            error: function(data) {
              loader.remove();
              _this.unlockUI();
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            }
          });
        };
      })(this));
    },
    voteNegative: function(event) {
      this.lockUI();
      return app.quests.doIfCompleted('social_passport', (function(_this) {
        return function() {
          var corporationId, loader, solutionId;
          solutionId = event.currentTarget.getAttribute('data-solution-id');
          corporationId = _this.options.corporationId;
          loader = _this.setLoaderOnElement(event.currentTarget, app.tr('Voting'));
          return app.server.business.proposeVoteNegative({
            solutionId: solutionId,
            corporationId: corporationId,
            success: function(data) {
              return _this.listenToOnce(app.vent, 'business/management:dataLoaded', function() {
                loader.remove();
                return this.unlockUI();
              });
            },
            error: function(data) {
              loader.remove();
              _this.unlockUI();
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            }
          });
        };
      })(this));
    },
    buyoutStocksAccept: function(event) {
      var corporationId, loader, solutionId;
      this.lockUI();
      solutionId = event.currentTarget.getAttribute('data-solution-id');
      corporationId = this.options.corporationId;
      loader = this.setLoaderOnElement(event.currentTarget, app.tr('Accepting'));
      return app.server.business.stocksBuyoutAccept({
        solutionId: solutionId,
        corporationId: corporationId,
        success: (function(_this) {
          return function(data) {
            loader.remove();
            return _this.unlockUI();
          };
        })(this),
        error: (function(_this) {
          return function(data) {
            loader.remove();
            _this.unlockUI();
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          };
        })(this)
      });
    },
    buyoutStocksReject: function(event) {
      var corporationId, loader, solutionId;
      this.lockUI();
      solutionId = event.currentTarget.getAttribute('data-solution-id');
      corporationId = this.options.corporationId;
      loader = this.setLoaderOnElement(event.currentTarget, app.tr('Rejecting'));
      return app.server.business.stocksBuyoutReject({
        solutionId: solutionId,
        corporationId: corporationId,
        success: (function(_this) {
          return function(data) {
            return _this.listenToOnce(app.vent, 'business/management:dataLoaded', function() {
              loader.remove();
              return this.unlockUI();
            });
          };
        })(this),
        error: (function(_this) {
          return function(data) {
            loader.remove();
            _this.unlockUI();
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          };
        })(this)
      });
    }
  });
});
