define(['app', 'views/item-view', 'underscore', 'text!templates/business/recruitment.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    events: {
      'click .js-save-vacancy': 'saveVacancy',
      'click .o-switcher-small': 'toggleSwither'
    },
    data: {
      companyWorkersInfo: {
        pointer: 'business.сompanyWorkersInfo',
        companyId: function() {
          return this.options.companyId;
        }
      }
    },
    toggleSwither: function(event) {
      if (this.$el.find('.js-set-state span').text() === app.tr('Recruitment open')) {
        this.$el.find('.js-set-state span').text(app.tr('There is no recruitment'));
      } else {
        this.$el.find('.js-set-state').text(app.tr('Recruitment open'));
      }
      return $(event.currentTarget).toggleClass('o-switcher-small--active');
    },
    saveVacancy: function(event) {
      var companyId, is_hiring, level, loader, salary;
      this.lockUI();
      loader = this.setLoaderOnElement(event.currentTarget, app.tr('Saving'));
      companyId = this.options.companyId;
      salary = this.$el.find('.js-salary').val();
      level = parseInt(this.$el.find('.js-level').val());
      is_hiring = this.$el.find('.o-switcher-small').hasClass('o-switcher-small--active') ? true : false;
      return app.server.business.saveVacancy({
        companyId: companyId,
        salary: salary,
        level: level,
        is_hiring: is_hiring,
        success: (function(_this) {
          return function(data) {
            unlockUI();
            loader.remove();
            if (is_hiring && app.gaEnabled) {
              return app.ga('send', 'event', 'business', 'hire', salary);
            }
          };
        })(this),
        error: function(data) {
          loader.remove();
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    },
    onDomRefresh: function() {
      var salary;
      if (this._data.companyWorkersInfo != null) {
        salary = this.$el.find('.js-salary').val();
        if (!isNaN(salary)) {
          salary = parseFloat(this._data.companyWorkersInfo.employment.salary).toFixed(2);
          this.$el.find('.js-salary').val(salary);
        }
        this.$el.find('.js-level').val(this._data.companyWorkersInfo.employment.level);
      }
      if ((this._data.companyWorkersInfo != null) && this._data.companyWorkersInfo.employment.is_hiring) {
        this.$el.find('.js-set-state span').text(app.tr('Recruitment open'));
        $('.o-switcher-small').addClass('o-switcher-small--active');
      }
      return this.$('.js-salary').change((function(_this) {
        return function(event) {
          var price;
          price = parseFloat($(event.currentTarget).val());
          if (!isNaN(price)) {
            return $(event.currentTarget).val(price.toFixed(2));
          } else {
            return $(event.currentTarget).val("0.00");
          }
        };
      })(this));
    }
  });
});
