define(['clusterize'], function(Clusterize) {

  /*
  	 * Helper to display large data sets easily
  	 * @param  {object} el        Container there should be done clusterize manipulations
  	 * @param  {number} rows      Amount of rows in block. Increase means browser will be more loaded, decrease means browser will have to update clusters more often.
  	 * @param  {boolean} autoHeight If specified, clusterize will not calculate max-height, this helpful for small screens
  	 * @return {object}           Clusterize block
   */
  return function(el, rows, autoHeight) {
    var clusterizeBlock;
    clusterizeBlock = function(el, rows, autoHeight) {
      var autoHeightParam, footerHeight, headerHeight, rowsInBlock, tabsHeight;
      autoHeightParam = autoHeight || false;
      rowsInBlock = rows || 20;
      if (el[0].querySelectorAll('.clusterize-scroll').length !== 0) {
        if (autoHeightParam) {
          if ($(window).height() > 540) {
            headerHeight = el.find('.c-header-wrapper').height() || 0;
            footerHeight = el.find('.c-footer').height() || 0;
            el.find('.clusterize-scroll').css('maxHeight', el.height() - headerHeight - footerHeight - 10);
          } else {
            el.find('.clusterize-scroll').css('maxHeight', 200);
          }
        } else {
          headerHeight = el.find('.c-header-wrapper').height() || 0;
          tabsHeight = el.find('.c-tabs').height() || 0;
          footerHeight = el.find('.c-footer').height() || 0;
          el.find('.clusterize-scroll').css('maxHeight', $('body').find('.o-main').height() - headerHeight - footerHeight + 24);
        }
        return $('.clusterize-scroll').each(function(id, el) {
          var clusterize;
          $(el).attr('id', 'scrollArea' + id);
          $(el).find('.clusterize-content').attr('id', 'contentArea' + id);
          return clusterize = new Clusterize({
            scrollId: 'scrollArea' + id,
            contentId: 'contentArea' + id,
            rows_in_block: rowsInBlock
          });
        });
      }
    };
    clusterizeBlock(el, rows, autoHeight);
    return $(window).resize(function() {
      return clusterizeBlock(el, rows, autoHeight);
    });
  };
});
