define(['modernizr'], function(Modernizr) {
  var HorizontalSwipe;
  return HorizontalSwipe = (function() {
    function HorizontalSwipe(el, arg) {
      this.onSwipeRight = arg.onSwipeRight, this.onSwipeLeft = arg.onSwipeLeft;
      this.el = el;
      this.$el = $(this.el);
      this.init();
    }


    /**
    		 * Function checks if touch events are supported by modernizr detection and initialize proper events
    		 * @param {obj} data - orbitary data can be passed here to extend method functionality
     */

    HorizontalSwipe.prototype.init = function(data) {
      if (window.navigator.pointerEnabled != null) {
        this.start = 'pointerdown';
        this.move = 'pointermove';
        this.end = 'pointerup';
        this.cancel = 'pointerout';
      } else if (window.navigator.msPointerEnabled != null) {
        this.start = 'MSPointerDown';
        this.move = 'MSPointerMove';
        this.end = 'MSPointerUp';
        this.cancel = 'MSPointerOut';
      } else if (Modernizr.touch) {
        this.start = 'touchstart';
        this.move = 'touchmove';
        this.end = 'touchend';
        this.cancel = 'touchcancel';
      } else {
        this.start = 'mousedown';
        this.move = 'mousemove';
        this.end = 'mouseup';
        this.cancel = 'mouseout';
      }
      this.touchStart = this.touchStart.bind(this);
      this.touchMove = this.touchMove.bind(this);
      this.touchEnd = this.touchEnd.bind(this);
      this.el.addEventListener(this.start, this.touchStart, false);
      this.el.addEventListener(this.move, this.touchMove, false);
      this.el.addEventListener(this.end, this.touchEnd, false);
      return this.el.addEventListener(this.cancel, this.touchEnd, false);
    };

    HorizontalSwipe.prototype.undelegate = function() {
      this.el.removeEventListener(this.start, this.touchStart, false);
      this.el.removeEventListener(this.move, this.touchMove, false);
      this.el.removeEventListener(this.end, this.touchEnd, false);
      return this.el.removeEventListener(this.cancel, this.touchEnd, false);
    };


    /**
    		 * touchStart
    		 * @param {event}
     */

    HorizontalSwipe.prototype.touchStart = function(event) {
      var ref;
      app.tabsScroll = false;
      this.startPos = (ref = event.clientX) != null ? ref : event.touches[0].pageX;
      this.startTime = Date.now();
      this.velocity = 0;
      return this.recognized = false;
    };


    /**
    		 * touchMove
    		 * @param {event}
     */

    HorizontalSwipe.prototype.touchMove = function(event) {
      var currentPos, ref;
      this.moved = true;
      currentPos = (ref = event.clientX) != null ? ref : event.touches[0].pageX;
      this.delta = currentPos - this.startPos;
      this.velocity = Math.max(this.velocity, Math.abs(this.delta / (Date.now() - this.startTime)));
      if (this.recognized) {
        event.stopPropagation();
        event.preventDefault();
      }
      if (this.velocity >= 0.9) {
        return this.recognized = true;
      } else {
        return this.recognized = false;
      }
    };


    /**
    		 * touchEnd
    		 * @param {event}
     */

    HorizontalSwipe.prototype.touchEnd = function(event) {
      if ($('body').hasClass('no-swipe')) {
        this.recognized = false;
      }
      if (app.tabsScroll) {
        this.recognized = false;
      }
      if (this.recognized) {
        event.stopPropagation();
        event.preventDefault();
        if (this.delta > 0 && (this.onSwipeRight != null)) {
          this.onSwipeRight(event);
        }
        if (this.delta < 0 && (this.onSwipeLeft != null)) {
          return this.onSwipeLeft(event);
        }
      }
    };

    return HorizontalSwipe;

  })();
});
