define([], function() {
  var NumberHelper, getDecimal;
  NumberHelper = {};
  NumberHelper.round = function(value, prec) {
    if (prec == null) {
      prec = 2;
    }
    return +(Math.round(value + ("e+" + prec.toString())) + ("e-" + prec.toString()));
  };
  NumberHelper.floor = function(value, prec) {
    if (prec == null) {
      prec = 2;
    }
    return +(Math.floor(value + ("e+" + prec.toString())) + ("e-" + prec.toString()));
  };
  NumberHelper.moneySpaced = function(num) {
    var val;
    val = num.toFixed(2).replace(/(\d)(?=(\d{3})+\.)/g, '$1 ');
    return val;
  };
  NumberHelper.moneyShort = function(value, precision) {
    var abs, d, modifiers, result;
    if (precision == null) {
      precision = 2;
    }
    abs = Math.abs(value);
    d = Math.pow(10, precision);
    modifiers = (function() {
      switch (false) {
        case !(abs < 10000):
          return [1, ""];
        case !(abs >= 10000 && abs < 1000000):
          return [1000, "K"];
        case !(abs >= 1000000 && abs < 1000000000):
          return [1000 * 1000, "M"];
        case !(abs >= 1000000000 && abs < 1000000000000):
          return [1000 * 1000 * 1000, "B"];
        case !(abs >= 1000000000000):
          return [1000 * 1000 * 1000 * 1000, "T"];
        default:
          return [1, ""];
      }
    })();
    result = ((parseInt((abs / modifiers[0]) * d)) / d).toFixed(precision) + modifiers[1];
    if (value > 0) {
      return result;
    } else {
      return -1 * result;
    }
  };
  NumberHelper.isInteger = function(value) {
    return typeof value === 'number' && isFinite(value) && Math.floor(value) === value;
  };
  NumberHelper.numberFormat = function(amount) {
    var i, j, num, number, ref, remainder, sym, tmp;
    number = amount;
    if (number >= 1000) {
      sym = [
        {
          value: 1e18,
          symbol: "E"
        }, {
          value: 1e15,
          symbol: "P"
        }, {
          value: 1e12,
          symbol: "T"
        }, {
          value: 1e9,
          symbol: "G"
        }, {
          value: 1e6,
          symbol: "M"
        }, {
          value: 1e3,
          symbol: "K"
        }
      ];
      remainder = getDecimal(amount / 1000) * 1000;
      for (i = j = 0, ref = sym.length; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
        if (number >= sym[i].value) {
          num = Math.floor(number / sym[i].value).toString().replace(/\.0+$|(\.[0-9]*[1-9])0+$/, "$1") + sym[i].symbol;
          if (number / 1000 >= 1000) {
            number -= Math.floor(number / sym[i].value) * sym[i].value;
            if (number > 0) {
              num = num + ' ' + this.numberFormat(number);
            }
          } else {
            if (remainder > 0) {
              tmp = getDecimal(remainder.toFixed(2));
              if (tmp > 0) {
                num = num + ' ' + remainder.toFixed(2);
              } else {
                num = num + ' ' + remainder;
              }
            }
          }
          return num;
        }
      }
    }
    return amount;
  };
  getDecimal = function(value) {
    var dotPos, str;
    str = '' + value;
    dotPos = str.indexOf('.');
    if (dotPos === -1) {
      return 0;
    }
    str = str.slice(dotPos);
    return +str;
  };
  return NumberHelper;
});
