define([], function() {
  var Strings;
  Strings = {};
  Strings.tr = function(text, locale) {
    if (locale == null) {
      locale = null;
    }
    return app.tr(text, locale);
  };
  Strings.avatar = function(str) {
    var avatar, remoteAvatar;
    avatar = str != null ? String(str).split('.')[0] + '.png' : '0.png';
    remoteAvatar = app.config.serverURLProtocol + '://' + app.config.serverURL + '/img_origin/avatars/' + avatar;
    return remoteAvatar;
  };
  Strings.minAvatar = function(str) {
    var avatarMin, remoteAvatar;
    avatarMin = str != null ? String(str).split('.')[0].split('_')[0] + '_avatar.png' : '0_min.png';
    remoteAvatar = app.config.serverURLProtocol + '://' + app.config.serverURL + '/img_origin/avatars/' + avatarMin;
    return remoteAvatar;
  };
  Strings.truncate = function(str, length) {
    if (str.length > length) {
      return str.substr(0, length - 1) + '&#133';
    }
    return str;
  };
  Strings.formatNumber = function(number, dec, dsep, tsep) {
    var decimals, fnums, parts;
    if (dec == null) {
      dec = 2;
    }
    if (isNaN(number) || number === null) {
      return '';
    }
    number = number.toFixed(~~dec);
    if (typeof tsep !== 'string') {
      tsep = ' ';
    }
    parts = number.split('.');
    fnums = parts[0];
    if (parts[1]) {
      decimals = (dsep || '.') + parts[1];
    } else {
      decimals = '';
    }
    return fnums.replace(/(\d)(?=(?:\d{3})+$)/g, '$1' + tsep) + decimals;
  };
  Strings.levenshtein = function(s1, s2, ignoreCase) {
    var a, b, buf, c, ch, cost, cutHalf, flip, i, ii, ii2, insertCost, j, k, l, l1, l2, m, minCost, minD, minI, ref, ref1, ref2, removeCost, replaceCost;
    ignoreCase = ignoreCase || false;
    l1 = s1.length;
    l2 = s2.length;
    replaceCost = 1;
    insertCost = 1;
    removeCost = 1;
    cutHalf = flip = Math.max(l1, l2);
    minCost = Math.min(removeCost, insertCost, replaceCost);
    minD = Math.max(minCost, (l1 - l2) * removeCost);
    minI = Math.max(minCost, (l2 - l1) * insertCost);
    buf = new Array((cutHalf * 2) - 1);
    for (i = k = 0, ref = l2; 0 <= ref ? k <= ref : k >= ref; i = 0 <= ref ? ++k : --k) {
      buf[i] = i * minD;
    }
    for (i = l = 0, ref1 = l1; 0 <= ref1 ? l < ref1 : l > ref1; i = 0 <= ref1 ? ++l : --l) {
      ch = s1[i];
      buf[flip] = (i + 1) * minI;
      ii = flip;
      ii2 = cutHalf - flip;
      for (j = m = 0, ref2 = l2; 0 <= ref2 ? m < ref2 : m > ref2; j = 0 <= ref2 ? ++m : --m) {
        if (ch === s2[j] || (ignoreCase && ch.toLowerCase() === s2[j].toLowerCase())) {
          cost = 0;
        } else {
          cost = replaceCost;
        }
        a = buf[ii2 + 1] + removeCost;
        b = buf[ii] + insertCost;
        c = buf[ii2] + cost;
        buf[ii + 1] = Math.min(a, b, c);
        ++ii;
        ++ii2;
      }
      flip = cutHalf - flip;
    }
    return buf[l2 + cutHalf - flip];
  };
  Strings.matchName = function(orignal, test, maxDiff) {
    var diff;
    maxDiff = maxDiff || 0;
    if (test.length < orignal.length) {
      orignal = orignal.substr(0, test.length);
    }
    diff = this.levenshtein(orignal, test, true);
    return diff <= maxDiff && (test.length > diff * 2);
  };
  Strings.replace = function(params, input) {
    var key, result, val;
    result = input;
    for (key in params) {
      val = params[key];
      result = result.replace(new RegExp(this.escapeRegexp(key), "g"), val);
    }
    return result;
  };
  Strings.stringReplace = function(search, replace, subject) {
    return subject.split(search).join(replace);
  };
  Strings.escapeRegexp = function(str) {
    return str.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');
  };
  Strings.declOfNum = function(number, titles) {
    var cases;
    cases = [2, 0, 1, 1, 1, 2];
    if (number % 100 > 4 && number % 100 < 20) {
      return titles[2];
    }
    if (number % 10 < 5) {
      return titles[cases[number % 10]];
    }
    return titles[cases[5]];
  };
  return Strings;
});
