var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['jquery', 'app', 'views/common/list-view', 'underscore', 'text!templates/friends/search.tmpl', 'text!templates/friends/blocks/search-list.tmpl', 'text!templates/friends/blocks/search-element.tmpl', 'velocity-ui'], function($, app, ItemView, _, template, listTemplate, elementTemplate) {
  var FriendsSearchView;
  FriendsSearchView = (function(superClass) {
    extend(FriendsSearchView, superClass);

    function FriendsSearchView() {
      this._onFriendAddExternal = bind(this._onFriendAddExternal, this);
      return FriendsSearchView.__super__.constructor.apply(this, arguments);
    }

    FriendsSearchView.prototype.template = template;

    FriendsSearchView.prototype.listTemplate = _.template(listTemplate);

    FriendsSearchView.prototype.events = {
      'change .js-name': 'onNameChange',
      'click #js-main-list-load-more': 'onLoadMore',
      'click .js-provider': 'onProviderFriends',
      'click .js-add-friend': 'onFriendAdd',
      'click .js-profile': 'onProfileClick'
    };

    FriendsSearchView.prototype.socialProviders = {
      'vk': {
        type: 'vk',
        'name': 'VK'
      },
      'fb': {
        type: 'fb',
        'name': 'Facebook'
      },
      'google': {
        type: 'google',
        'name': 'Google+'
      }
    };

    FriendsSearchView.prototype.data = {
      requests: 'friends.requests_count'
    };

    FriendsSearchView.prototype._usersList = [];

    FriendsSearchView.prototype._name = null;

    FriendsSearchView.prototype.initialize = function() {
      FriendsSearchView.__super__.initialize.apply(this, arguments);
      app.vent.on('friends:friendship_requested', this._onFriendAddExternal);
      return this._renderElement = (function(template, helpers) {
        return function(user) {
          user.min_avatar = helpers.minAvatar(user.User.avatar);
          return template({
            user: user
          });
        };
      })(_.template(elementTemplate), this.mixinTemplateHelpers());
    };

    FriendsSearchView.prototype.onBeforeDestroy = function() {
      return app.vent.off('friends:friendship_requested', this._onFriendAddExternal);
    };

    FriendsSearchView.prototype.serializeData = function() {
      var data;
      data = FriendsSearchView.__super__.serializeData.apply(this, arguments);
      data.renderElement = this._renderElement;
      data.accounts = {};
      data.socialProviders = this.socialProviders;
      if (data.requests && data.requests.requests_count) {
        data.requests_count = data.requests.requests_count;
      }
      return data;
    };

    FriendsSearchView.prototype.onProfileClick = function(event) {
      var hasProfile, userId;
      event.stopPropagation();
      this.lockUI();
      userId = event.currentTarget.getAttribute('data-id');
      hasProfile = event.currentTarget.getAttribute('data-has-profile') === 'true';
      if (hasProfile) {
        return app.screens.dialog('users/profile', {
          userId: userId
        });
      }
    };

    FriendsSearchView.prototype.onFriendAdd = function(event) {
      var friendId, self;
      event.stopPropagation();
      self = this;
      friendId = Number(event.currentTarget.getAttribute('data-id'));
      return app.server.friends.add_request({
        friendId: friendId,
        success: function(data) {
          var ref;
          self.unlockUI();
          app.hideLoader();
          if (!data.error) {
            app.vent.trigger('friends:friendship_requested', {
              user: self._getUserById(friendId)
            });
            self._disableUser(friendId);
          }
          return app.screens.modal('common/info-popup', {
            msg: (data != null ? (ref = data.setFlash[0]) != null ? ref.msg : void 0 : void 0) || app.tr('Server error')
          });
        },
        error: function(data) {
          var ref;
          self.unlockUI();
          app.hideLoader();
          return app.screens.modal('common/info-popup', {
            msg: (data != null ? (ref = data.setFlash[0]) != null ? ref.msg : void 0 : void 0) || app.tr('Server error')
          });
        }
      });
    };

    FriendsSearchView.prototype._onFriendAddExternal = function(event) {
      var id;
      if (event && event.user) {
        id = Number(event.user.User.id);
        return this._disableUser(id);
      }
    };

    FriendsSearchView.prototype.onNameChange = function(event) {
      var name;
      name = event.currentTarget.value;
      name = name.trim();
      event.currentTarget.value = name;
      if (name.length > 2 || !name) {
        this._name = name;
        return this._reloadMainList(name, 1);
      }
    };

    FriendsSearchView.prototype.onLoadMore = function(event) {
      var page;
      page = Number(event.currentTarget.getAttribute('data-page'));
      return this._appendPageToMainList(this._name, page);
    };

    FriendsSearchView.prototype.onProviderFriends = function(event) {
      var provider, providerName, self;
      self = this;
      providerName = event.currentTarget.getAttribute('data-type');
      provider = app.socialService.getProvider(providerName);
      if (provider) {
        app.showLoader();
        self.lockUI();
        return provider.getFriendIds().then(function(data) {
          self.unlockUI();
          app.hideLoader();
          if (data.status === 'success') {
            return self._reloadProviderList(providerName, data.friendIds);
          }
        }, function(data) {
          self.unlockUI();
          app.hideLoader();
          return app.screens.modal('common/info-popup', {
            msg: app.tr('Failed to load social friends')
          });
        });
      }
    };

    FriendsSearchView.prototype._setActiveProvider = function(provider, count) {
      var providerElement, title, toggle;
      this._resetProviders();
      providerElement = this.el.querySelector('#js-social-' + provider);
      title = providerElement.querySelector('#js-social-' + provider + '-title');
      toggle = providerElement.querySelector('#js-social-' + provider + '-toggle');
      title.innerHTML = app.tr('Users found') + ': ' + (count || 0);
      toggle.classList.remove('o-icon--right-arrow');
      return toggle.classList.add('o-icon--down-arrow');
    };

    FriendsSearchView.prototype._resetProviders = function() {
      var i, len, providerElement, providerElements, results, title, toggle;
      providerElements = this.el.querySelectorAll('.js-provider');
      results = [];
      for (i = 0, len = providerElements.length; i < len; i++) {
        providerElement = providerElements[i];
        title = providerElement.querySelector('#js-social-' + providerElement.dataset.type + '-title');
        toggle = providerElement.querySelector('#js-social-' + providerElement.dataset.type + '-toggle');
        title.innerHTML = title.dataset.title;
        toggle.classList.remove('o-icon--down-arrow');
        results.push(toggle.classList.add('o-icon--right-arrow'));
      }
      return results;
    };

    FriendsSearchView.prototype._getUserById = function(id) {
      var i, len, ref, resultUser, user;
      resultUser = null;
      ref = this._usersList;
      for (i = 0, len = ref.length; i < len; i++) {
        user = ref[i];
        if (user.User.id === id) {
          resultUser = user;
          break;
        }
      }
      return resultUser;
    };

    FriendsSearchView.prototype._disableUser = function(id) {
      var div, element, user;
      user = this._getUserById(id);
      if (!user) {
        return;
      }
      user.is_requested = 1;
      div = document.createElement('DIV');
      div.innerHTML = this._renderElement(user);
      element = this.el.querySelector('#js-user-' + id);
      return element.parentNode.replaceChild(div.firstElementChild, element);
    };

    FriendsSearchView.prototype._reloadMainList = function(name, page) {
      var container, self;
      container = this.el.querySelector('#js-main-list-content');
      self = this;
      self.lockUI();
      self._showListLoader(container);
      self._resetProviders();
      return $.when(self._clearAllLists(), self._loadFriends(name, page)).then(function(ign, data) {
        self.unlockUI();
        self._hideListLoader(container);
        self._usersList = data.users;
        return self._renderList(container, data.users, data.page, data.hasNext);
      });
    };

    FriendsSearchView.prototype._reloadProviderList = function(provider, friendIds) {
      var container, self;
      container = this.el.querySelector('#js-provider-list-content-' + provider);
      self = this;
      self.lockUI();
      self._showListLoader(container);
      self._resetProviders();
      return $.when(self._clearAllLists(), self._loadSocialFriends(provider, friendIds)).then(function(ign, data) {
        self.unlockUI();
        self._hideListLoader(container);
        self._usersList = data.users;
        self._setActiveProvider(provider, data.users.length);
        return self._renderList(container, data.users, data.page, data.hasNext);
      });
    };

    FriendsSearchView.prototype._appendPageToMainList = function(name, page) {
      var container, self;
      container = this.el.querySelector('#js-main-list-content');
      self = this;
      self.lockUI();
      self._showListLoader(container);
      return self._loadFriends(name, page).then(function(data) {
        self.unlockUI();
        self._hideListLoader(container);
        self._usersList = self._usersList.concat(data.users);
        return self._renderList(container, data.users, data.page, data.hasNext);
      });
    };

    FriendsSearchView.prototype._loadFriends = function(name, page) {
      var deferred, self;
      deferred = $.Deferred();
      self = this;
      app.server.friends.search({
        name: name,
        page: page,
        success: function(data) {
          var resultData;
          resultData = {
            users: data.users || []
          };
          resultData.page = page;
          resultData.hasNext = data.has_next || false;
          return deferred.resolve(resultData);
        },
        error: function() {
          return deferred.resolve({
            users: [],
            page: 1,
            hasNext: false
          });
        }
      });
      return deferred;
    };

    FriendsSearchView.prototype._loadSocialFriends = function(provider, friendIds) {
      var deferred, self;
      deferred = $.Deferred();
      self = this;
      app.server.friends.search_social({
        provider: provider,
        friendIds: friendIds,
        success: function(data) {
          var resultData;
          resultData = {
            users: data.users || []
          };
          resultData.page = 1;
          resultData.hasNext = false;
          return deferred.resolve(resultData);
        },
        error: function() {
          return deferred.resolve({
            users: [],
            page: 1,
            hasNext: false
          });
        }
      });
      return deferred;
    };

    return FriendsSearchView;

  })(ItemView);
  return FriendsSearchView;
});
