var extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/house.tmpl', 'views/components/currency', 'views/components/strings-helper'], function(app, ItemView, _, template, formatCurrency, StringsHelper) {
  var HouseView;
  HouseView = (function(superClass) {
    extend(HouseView, superClass);

    function HouseView() {
      return HouseView.__super__.constructor.apply(this, arguments);
    }

    HouseView.prototype.template = template;

    HouseView.prototype.data = {
      info: 'house.info',
      userFurniture: 'inventory.furniture'
    };

    HouseView.prototype.events = {
      'click .o-switcher': 'changeCurrency',
      'click .js-buy': 'buyHouse',
      'click .js-put-furniture': 'putFurniture',
      'click .js-remove-furniture': 'removeFurniture',
      'click .js-levelup-furniture-slots': 'levelUpFurnitureSlots'
    };

    HouseView.prototype.changeCurrency = function(event) {
      var $jsPrice, $newValue;
      if (!this.haveVd) {
        app.screens.modal('common/info-popup', {
          msg: app.tr("No vdollars lots in trade center")
        });
        return;
      }
      this.options.showVd = !this.options.showVd;
      this.$fromExchange = this.$el.find('.js-from-exchange');
      $(event.currentTarget).toggleClass('o-switcher--active');
      this.$fromExchange.find('.js-buy').toggleClass('c-btn--green c-btn--yellow');
      this.$fromExchange.find('.js-currency-icon').toggleClass('o-icon--vdollar o-icon--vgold');
      this.$fromExchange.find('.js-apply').toggleClass('c-btn--green c-btn--yellow');
      this.$fromExchange.find('.js-gold-only').toggleClass('hidden');
      $jsPrice = this.$fromExchange.find('.js-currency');
      if (this.options.showVd) {
        this.oldPrice = $jsPrice.html();
        $newValue = formatCurrency(this._data.info.flatExchange.price, ' ', 2);
      } else {
        $newValue = this.oldPrice;
      }
      return $jsPrice.html($newValue);
    };

    HouseView.prototype.preprocessData = function(data) {
      var arrId, item, ref, ref1, userHome;
      this.options.showVd = false;
      this.haveVd = Object.keys(data['info']['flatExchange']).length > 0;
      console.log('have VD', this.haveVd, data['info'], data['info']['flatExchange'], data['info']['flatExchange'].length);
      ref = data['userFurniture']['furniture']['itemsArray'];
      for (arrId in ref) {
        item = ref[arrId];
        item.id = item.UserItem.id;
        item.title = item.ItemType.name;
      }
      this.userItemsCollection = new Backbone.Collection(data['userFurniture']['furniture']['itemsArray']);
      ref1 = data['info']['userHomes'];
      for (arrId in ref1) {
        userHome = ref1[arrId];
        userHome.itemsCollection = new Backbone.Collection(userHome['HomeItem']);
      }
      return data;
    };

    HouseView.prototype.buyHouse = function(event) {
      var currency, exchangeId, homeTypeId, msg, price;
      this.lockUI();
      homeTypeId = event.currentTarget.getAttribute('data-homeTypeId');
      currency = this.options.showVd ? 'vd' : 'vg';
      exchangeId = event.currentTarget.getAttribute('data-exchange-id');
      price = $(event.currentTarget).parent().parent().find('.js-currency').html();
      msg = StringsHelper.replace({
        '{{item}}': this._data.info.homeTypeOffers[homeTypeId].UserHomeType.name,
        '{{price}}': price + currency
      }, app.tr("Do you want to buy {{item}} per {{price}} ?"));
      return app.screens.modal('common/confirmation-popup', {
        msg: msg,
        callback: (function(_this) {
          return function(count) {
            var loader;
            loader = _this.setLoaderOnElement(event.currentTarget, app.tr('Creating'));
            return app.server.house.buy({
              homeTypeId: homeTypeId,
              currency: currency,
              exchangeId: exchangeId,
              success: function(data) {
                var adjustEvent, housePrice, key;
                if (app.gaEnabled && currency === 'vg') {
                  housePrice = _this.$('.js-currency').val();
                  app.ga('send', 'event', 'house', 'vgoldbuy', 'buyhouse', housePrice);
                }
                if (app.adjustEnabled) {
                  key = '1a5k71';
                  adjustEvent = new app.adjust.AdjustEvent(key);
                  adjustEvent.addPartnerParameter('event_key', key);
                  app.adjust.Adjust.trackEvent(adjustEvent);
                }
                loader.remove();
                return _this.unlockUI();
              },
              error: function(data) {
                loader.remove();
                _this.unlockUI();
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    };

    HouseView.prototype.putFurniture = function(event) {
      var homeId, placeSlot;
      this.lockUI();
      if (this.userItemsCollection.length === 0) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("You have no furniture in the inventory.")
        });
      } else {
        placeSlot = event.currentTarget.getAttribute('data-slot');
        homeId = event.currentTarget.getAttribute('data-home-id');
        return app.screens.dialog('common/select-dialog', {
          collection: this.userItemsCollection,
          callback: (function(_this) {
            return function(itemId) {
              return app.server.house.putFurniture({
                placeSlot: placeSlot,
                itemId: itemId,
                homeId: homeId
              });
            };
          })(this)
        });
      }
    };

    HouseView.prototype.removeFurniture = function(event) {
      var homeId, placeSlot;
      this.lockUI();
      placeSlot = event.currentTarget.getAttribute('data-slot');
      homeId = event.currentTarget.getAttribute('data-home-id');
      return app.screens.modal('common/confirmation-popup', {
        msg: "Are you sure you want to remove this furniture housing ?",
        callback: (function(_this) {
          return function() {
            return app.server.house.removeFurniture({
              placeSlot: placeSlot,
              homeId: homeId,
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    };

    HouseView.prototype.levelUpFurnitureSlots = function(event) {
      var UserHomeId;
      this.lockUI();
      UserHomeId = event.currentTarget.getAttribute('data-home-id');
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('Do you want to upgrade the furniture slots?'),
        callback: (function(_this) {
          return function() {
            var loader;
            loader = _this.setLoaderOnElement(event.currentTarget, app.tr('Adding'));
            return app.server.house.levelUpFurnitureSlots({
              UserHomeId: UserHomeId,
              success: function(data) {
                loader.remove();
                return _this.unlockUI();
              },
              error: function(data) {
                loader.remove();
                _this.unlockUI();
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    };

    HouseView.prototype.onDomRefresh = function() {
      return [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        return el.innerHTML = formatCurrency(el.innerHTML);
      });
    };

    return HouseView;

  })(ItemView);
  return HouseView;
});
