define(['app', 'views/item-view', 'underscore', 'text!templates/job/office.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      licensesInfo: 'work.licenses.info'
    },
    events: {
      'click .js-goto-license-settings': 'gotoLicenseSettings',
      'click .js-accept-patients': 'toggleAcceptPatients',
      'click .js-accept-trainees': 'toggleAcceptTrainees',
      'click .js-renew-medical': 'renewMedical',
      'click .js-renew-sport': 'renewSport',
      'click .o-switcher-small': 'toggleSwither'
    },
    renewSport: function(event) {
      var cost_of_renewing, currency;
      this.lockUI();
      cost_of_renewing = this._data.licensesInfo['coach']['renew_cost'];
      currency = this._data.licensesInfo['coach']['renew_currency'];
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr("License renewal price") + (" " + cost_of_renewing + " " + currency),
        callback: (function(_this) {
          return function(count) {
            return app.server.work.trainerLicense.renew({
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Licence is prolonged")
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    },
    renewMedical: function(event) {
      var cost_of_renewing, currency;
      this.lockUI();
      cost_of_renewing = this._data.licensesInfo['doctor']['renew_cost'];
      currency = this._data.licensesInfo['doctor']['renew_currency'];
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr("License renewal price") + (" " + cost_of_renewing + " " + currency),
        callback: (function(_this) {
          return function(count) {
            return app.server.work.doctorLicense.renew({
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg || app.tr("Licence is prolonged")
                });
              },
              error: function(data) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                });
              }
            });
          };
        })(this)
      });
    },
    gotoLicenseSettings: function(event) {
      var licenseId;
      this.lockUI();
      licenseId = event.currentTarget.getAttribute('data-license-id');
      return app.screens.dialog('job/license-settings', {
        licenseId: licenseId
      });
    },
    turnAcceptPatientsOn: function() {
      this.el.querySelector('.js-accept-patients-message').classList.remove('hidden');
      return this.el.querySelector('.js-reject-patients-message').classList.add('hidden');
    },
    turnAcceptPatientsOff: function() {
      this.el.querySelector('.js-accept-patients-message').classList.add('hidden');
      return this.el.querySelector('.js-reject-patients-message').classList.remove('hidden');
    },
    toggleAcceptPatients: function(event) {
      var acceptPatients, licenseId;
      $(event.currentTarget).toggleClass('o-switcher-small--active');
      acceptPatients = $(event.currentTarget).hasClass('o-switcher-small--active') ? true : false;
      licenseId = event.currentTarget.getAttribute('data-license-id');
      if (acceptPatients) {
        this.turnAcceptPatientsOn();
        return app.server.work.doctorLicense.start({
          licenseId: licenseId,
          doesNotReload: true,
          success: (function(_this) {
            return function() {};
          })(this),
          error: (function(_this) {
            return function(err) {
              return _this.turnAcceptPatientsOff();
            };
          })(this)
        });
      } else {
        this.turnAcceptPatientsOff();
        return app.server.work.doctorLicense.stop({
          licenseId: licenseId,
          doesNotReload: true,
          success: (function(_this) {
            return function() {};
          })(this),
          error: (function(_this) {
            return function(err) {
              return _this.turnAcceptPatientsOn();
            };
          })(this)
        });
      }
    },
    turnAcceptTraineesOn: function() {
      this.el.querySelector('.js-accept-trainees-message').classList.remove('hidden');
      return this.el.querySelector('.js-reject-trainees-message').classList.add('hidden');
    },
    turnAcceptTraineesOff: function() {
      this.el.querySelector('.js-accept-trainees-message').classList.add('hidden');
      return this.el.querySelector('.js-reject-trainees-message').classList.remove('hidden');
    },
    toggleAcceptTrainees: function(event) {
      var acceptTrainees, licenseId;
      $(event.currentTarget).toggleClass('o-switcher-small--active');
      acceptTrainees = $(event.currentTarget).hasClass('o-switcher-small--active') ? true : false;
      licenseId = event.currentTarget.getAttribute('data-license-id');
      if (acceptTrainees) {
        this.turnAcceptTraineesOn();
        return app.server.work.trainerLicense.start({
          licenseId: licenseId,
          doesNotReload: true,
          success: (function(_this) {
            return function() {};
          })(this),
          error: (function(_this) {
            return function(err) {
              return _this.turnAcceptTraineesOff();
            };
          })(this)
        });
      } else {
        this.turnAcceptTraineesOff();
        return app.server.work.trainerLicense.stop({
          licenseId: licenseId,
          doesNotReload: true,
          success: (function(_this) {
            return function() {};
          })(this),
          error: (function(_this) {
            return function(err) {
              return _this.turnAcceptTraineesOn();
            };
          })(this)
        });
      }
    },

    /*
    			Center cloud
     */
    centerCloud: function() {
      var $cloud, $container;
      if ($('.c-cloud').length > 0) {
        $cloud = $('.c-cloud');
        $container = $('.js-current-screen');
        return $cloud.css('margin-top', ($container.height() / 2 - $cloud.height() / 2) / 2);
      }
    },
    onDomRefresh: function() {
      return this.centerCloud();
    }
  });
});
