define(['app', 'views/item-view', 'underscore', 'text!templates/job/vacancies.tmpl', 'views/components/clusterize-helper', 'jquery'], function(app, ItemView, _, template, ClusterizeHelper, $) {
  return ItemView.extend({
    template: template,
    required: ['professionId'],
    data: {
      'vacancies': {
        pointer: 'work.vacancies.forProfession',
        professionId: function() {
          return this.options.professionId;
        }
      }
    },
    events: {
      'click .js-accept-vacancy': 'acceptVacancy'
    },
    acceptVacancy: function(event) {
      var loader, msg, onConfirm, ref, ref1, ref2, self, vacancyId;
      this.lockUI();
      self = this;
      vacancyId = event.currentTarget.getAttribute('data-vacancy-id');
      loader = this.setLoaderOnElement(event.currentTarget, app.tr('Accepting'));
      if (self._data && (((ref = self._data) != null ? (ref1 = ref.vacancies) != null ? (ref2 = ref1.userWork) != null ? ref2.CompanyWorker : void 0 : void 0 : void 0) != null)) {
        onConfirm = function() {
          return self._resignFromPreviousJob(self._data.vacancies.userWork.CompanyWorker.id).then(function() {
            return self._acceptVacancy(vacancyId);
          }).then(function() {
            loader.remove();
            return app.screens.main('job');
          });
        };
        msg = app.tr('You already have a job. Do you want to change it?');
        return app.screens.modal('common/confirmation-popup', {
          msg: msg,
          callback: onConfirm
        });
      } else {
        return self._acceptVacancy(vacancyId).then(function(data) {
          loader.remove();
          app.vent.trigger('job:hired', {
            data: data
          });
          return app.screens.main('job');
        });
      }
    },
    _acceptVacancy: function(vacancyId) {
      var deferred;
      deferred = $.Deferred();
      app.server.work.vacancies.accept({
        vacancyId: vacancyId,
        success: function(data) {
          if (app.tutorial.checkInProgress(app.tutorial.TUTORIAL_JOB)) {
            return deferred.resolve(data);
          } else {
            return deferred.resolve();
          }
        },
        error: function(data) {
          var msg;
          msg = data.setFlash[0].msg || app.tr("Something went wrong");
          return app.screens.modal('common/info-popup', {
            msg: msg,
            callback: function() {
              return deferred.reject();
            }
          });
        }
      });
      return deferred;
    },
    _resignFromPreviousJob: function(workerId) {
      var deferred;
      deferred = $.Deferred();
      app.server.work.current.resign({
        workerId: workerId,
        success: function(data) {
          app.vent.trigger('job:fired', {
            data: data
          });
          return deferred.resolve();
        },
        error: function(data) {
          var msg;
          msg = data.setFlash[0].msg || app.tr("Something went wrong");
          return app.screens.modal('common/info-popup', {
            msg: msg,
            callback: function() {
              return deferred.reject();
            }
          });
        }
      });
      return deferred;
    },

    /*
    			Center cloud
     */
    centerCloud: function() {
      var $cloud, $container;
      if ($('.c-cloud').length > 0) {
        $cloud = $('.c-cloud');
        $container = $('.js-current-screen');
        return $cloud.css('margin-top', ($container.height() / 2 - $cloud.height() / 2) / 2);
      }
    },
    onDomRefresh: function() {
      this.centerCloud();
      return ClusterizeHelper(this.$el);
    },
    sendGAView: function() {
      if (this.app.config.googleAnalyticsEnabled && this.app.ga) {
        return this.app.ga('send', 'pageview', {
          page: '/scr/' + this.options.id + '/' + this.options.professionId,
          title: ''
        });
      }
    }
  });
});
