var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['underscore', 'views/item-view', 'text!templates/login.tmpl'], function(_, ItemView, template) {
  var LoginView;
  LoginView = (function(superClass) {
    extend(LoginView, superClass);

    function LoginView() {
      this.auth = bind(this.auth, this);
      this._loginExternal = bind(this._loginExternal, this);
      return LoginView.__super__.constructor.apply(this, arguments);
    }

    LoginView.prototype.className = 'sign-in-layout';

    LoginView.prototype.template = template;

    LoginView.prototype.events = {
      'submit .login-form': 'login',
      'click .js-login': 'login',
      'click .js-login-external': 'loginExternal',
      'click .js-quickstart': 'quickStart'
    };

    LoginView.prototype._reauthAttemptsLeft = 1;

    LoginView.prototype.initialize = function(options) {
      var login, password, ref;
      LoginView.__super__.initialize.call(this, options);
      if (this.app.screens.menu != null) {
        this.app.screens.menu.hs.undelegate();
      }
      this.app.menuRegion.reset();
      this.app.shortInfoRegion.reset();
      $('#startup-loader').hide();
      if (localStorage.auth != null) {
        ref = JSON.parse(localStorage.auth), login = ref.login, password = ref.password;
        return this.auth(login, password);
      }
    };

    LoginView.prototype.loginExternal = function(event) {
      var provider, type;
      this.lockUI();
      event.preventDefault();
      type = event.target.getAttribute('data-type');
      provider = app.socialService.getProvider(type);
      if (!provider) {
        this.app.screens.modal('common/info-popup', {
          msg: self.app.tr("Authentication failed")
        });
      }
      if (provider.isAuthenticated()) {
        return this._loginExternal(provider);
      } else {
        return provider.auth().then((function(_this) {
          return function() {
            return _this._loginExternal(provider);
          };
        })(this), (function(_this) {
          return function() {
            return _this.app.screens.modal('common/info-popup', {
              msg: self.app.tr("Authentication failed")
            });
          };
        })(this));
      }
    };

    LoginView.prototype._loginExternal = function(provider) {
      var self;
      self = this;
      return this.app.server.social.auth({
        provider: provider.getType(),
        userId: provider.getCurrentUserId(),
        token: provider.getCurrentToken(),
        success: function(data) {
          if (data && (data != null ? data.token : void 0)) {
            localStorage.setItem('auth_token', data.token);
            return self.app.screens.main('auto_login');
          } else {
            localStorage.removeItem('auth_token');
            return self.app.screens.modal('common/info-popup', {
              msg: self.app.tr("Authentication failed")
            });
          }
        },
        error: function(data) {
          var ref, username;
          if (data && (data != null ? data.error_code : void 0) && data.error_code === 'NO_USER') {
            username = (data != null ? data.data : void 0) && ((ref = data.data) != null ? ref.username : void 0) ? data.data.username : null;
            return provider.getCurrentUserData().then(function(data) {
              var userData;
              userData = data.user;
              userData.username = username;
              userData.avatar_id = userData.sex === 'male' ? 1 : 4;
              return self.app.screens.dialog('login/login-with-social', {
                user: userData,
                provider: provider.getType(),
                token: provider.getCurrentToken()
              });
            }, (function(_this) {
              return function() {
                return self.app.screens.modal('common/info-popup', {
                  msg: self.app.tr("Authentication failed")
                });
              };
            })(this));
          } else if (data && data.error_code === 'INVALID_TOKEN' && self._reauthAttemptsLeft > 0) {
            self._reauthAttemptsLeft--;
            return provider.reauth(true).then(function() {
              return self._loginExternal(provider);
            }, function() {
              return self.app.screens.modal('common/info-popup', {
                msg: self.app.tr("Authentication failed")
              });
            });
          } else {
            localStorage.removeItem('auth_token');
            return self.app.screens.modal('common/info-popup', {
              msg: self.app.tr("Authentication failed")
            });
          }
        }
      });
    };

    LoginView.prototype.login = function(event) {
      var login, password;
      this.lockUI();
      event.preventDefault();
      login = this.$el[0].querySelector('.js-user-login').value;
      password = this.$el[0].querySelector('.js-user-password').value;
      return this.auth(login, password);
    };

    LoginView.prototype.quickStart = function() {
      var device_uuid;
      this.lockUI();
      device_uuid = 'VIRCITIES DEFAULT';
      if (typeof device !== "undefined" && device !== null) {
        device_uuid = device.uuid;
      }
      return app.server.quickStart({
        device_uuid: device_uuid,
        success: function(data) {
          if (data != null) {
            localStorage.removeItem('tutorial_skipped');
            localStorage.auth = JSON.stringify({
              login: data.user_login,
              password: data.user_pass
            });
            return app.screens.main('auto_login');
          }
        },
        error: function(err) {
          if (err != null) {
            console.log('QuickRegistration error:');
            return console.log(err);
          }
        }
      });
    };

    LoginView.prototype.auth = function(login, password) {
      this.lockUI();
      return this.app.server.auth({
        login: login,
        password: password,
        success: (function(_this) {
          return function(data) {
            var tutorialCb;
            _this.app.setUserId(data.userId);
            _this.app.setUserRegistrationSource(data.registration_source != null ? data.registration_source : "");
            tutorialCb = function() {
              if (((data.trigger_tutorial != null) && data.trigger_tutorial) || app.tutorial.hasUnfinishedSteps()) {
                return _this.app.tutorial.start();
              }
            };
            if ((data.registration_bonus != null) && data.registration_bonus) {
              app.vent.listenToOnce(app.screens, 'view:ready:quests', function() {
                return app.screens.modal('common/registration-bonus', {
                  backCallback: tutorialCb
                });
              });
            } else {
              app.vent.listenToOnce(app.screens, 'view:ready:quests', tutorialCb);
            }
            _this.app.menu.init();
            _this.app.shortInfo.init();
            _this.app.pushNotifications.init();
            _this.app.ga('set', 'dimension', '2', data.level.toString());
            _this.app.ga('set', 'dimension', '3', data.cityName);
            _this.app.vent.trigger('auth:login', {
              user_id: data.userId
            });
            if (_this.options.user_id != null) {
              return _this.app.screens.main('users/profile', {
                userId: _this.options.user_id
              });
            } else {
              return _this.app.screens.main('quests');
            }
          };
        })(this),
        error: (function(_this) {
          return function(data) {
            var ref;
            if (data === "not json response") {
              _this.app.screens.modal('common/info-popup', {
                msg: _this.app.tr("Failed to connect to server")
              });
              return;
            }
            if (app.config.debug) {
              console.log('Error', data);
            }
            delete localStorage.auth;
            delete localStorage.auth_token;
            localStorage.removeItem("auth");
            localStorage.removeItem("auth_token");
            return _this.app.screens.modal('common/info-popup', {
              msg: ((ref = data.setFlash) != null ? ref[0].msg : void 0) || app.tr("Incorrect login or password")
            });
          };
        })(this)
      });
    };

    LoginView.prototype.onDomRefresh = function(options) {
      return this.$el.closest('body').addClass('hide-short-info no-swipe');
    };

    return LoginView;

  })(ItemView);
  return LoginView;
});
