var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/login/sign-up-social.tmpl'], function(app, ItemView, _, template) {
  var SignUpSocialView;
  SignUpSocialView = (function(superClass) {
    extend(SignUpSocialView, superClass);

    function SignUpSocialView() {
      this.signUpSubmit = bind(this.signUpSubmit, this);
      this._setCity = bind(this._setCity, this);
      this._setAvatar = bind(this._setAvatar, this);
      this._updateInputCounter = bind(this._updateInputCounter, this);
      this._stopCounterInterval = bind(this._stopCounterInterval, this);
      this._startCounterInterval = bind(this._startCounterInterval, this);
      this.onRender = bind(this.onRender, this);
      this.preprocessData = bind(this.preprocessData, this);
      return SignUpSocialView.__super__.constructor.apply(this, arguments);
    }

    SignUpSocialView.prototype.className = 'sign-up-social-layout no-bg-image';

    SignUpSocialView.prototype.template = template;

    SignUpSocialView.prototype.data = {
      data: 'user.registrationInfo'
    };

    SignUpSocialView.prototype.events = {
      'click .js-submit': 'signUpSubmit',
      'click .js-select-avatar': 'selectAvatar',
      'click .js-select-city': 'selectCity'
    };

    SignUpSocialView.prototype._currentInput = null;

    SignUpSocialView.prototype._inputCounterInterval = null;

    SignUpSocialView.prototype._setCityByDefault = false;

    SignUpSocialView.prototype.citiesLocale = {
      '3': 'on russian',
      '12': 'on polish',
      '14': 'on english'
    };

    SignUpSocialView.prototype.preprocessData = function(data) {
      var city, i, len, ref;
      this._cities = {};
      ref = data.data.cities;
      for (i = 0, len = ref.length; i < len; i++) {
        city = ref[i];
        this._cities[city.id] = city;
      }
      this._avatars = data.data.avatars;
      return data;
    };

    SignUpSocialView.prototype.onRender = function() {
      var counter, i, input, inputs, len, maxLength, results;
      this._avatarElement = this.el.querySelector('#js-avatar-img');
      this._cityElement = this.el.querySelector('#js-city-title');
      if (this._avatars) {
        this._setAvatar(this.options.user.avatar_id);
      }
      if (this._cities && this._setCityByDefault) {
        this._setCity(Object.keys(this._cities)[0]);
      }
      inputs = this.el.querySelectorAll('.c-input');
      results = [];
      for (i = 0, len = inputs.length; i < len; i++) {
        input = inputs[i];
        counter = this.el.querySelector('#' + input.name + '-counter');
        maxLength = parseInt(input.getAttribute('maxlength')) || 60;
        if (counter) {
          counter.innerHTML = input.value.length + ' / ' + maxLength;
          input.addEventListener('focus', this._startCounterInterval);
          results.push(input.addEventListener('blur', this._stopCounterInterval));
        } else {
          results.push(void 0);
        }
      }
      return results;
    };

    SignUpSocialView.prototype._startCounterInterval = function(event) {
      this._currentInput = event.currentTarget;
      return this._inputCounterInterval = setInterval(this._updateInputCounter, 100);
    };

    SignUpSocialView.prototype._stopCounterInterval = function(event) {
      this._currentInput = null;
      if (this._inputCounterInterval) {
        clearInterval(this._inputCounterInterval);
        return this._inputCounterInterval = 0;
      }
    };

    SignUpSocialView.prototype._updateInputCounter = function() {
      var counter, currentLength, input, maxLength;
      input = this._currentInput;
      currentLength = input.value.length;
      counter = this.el.querySelector('#' + input.name + '-counter');
      maxLength = parseInt(input.getAttribute('maxlength')) || 60;
      if (counter) {
        counter.innerHTML = currentLength + ' / ' + maxLength;
      }
      if (currentLength > maxLength) {
        input.value = input.value.substr(maxLength);
        return $(input).addClass("field-error");
      } else {
        return $(input).removeClass("field-error");
      }
    };

    SignUpSocialView.prototype.selectAvatar = function(event) {
      var current, newPos, range, step;
      step = parseInt(event.currentTarget.getAttribute('data-step', 10));
      range = Object.keys(this._avatars);
      current = range.indexOf(this.options.user.avatar);
      newPos = step + current;
      if (newPos >= range.length) {
        newPos = 0;
      }
      if (newPos < 0) {
        newPos = range.length - 1;
      }
      return this._setAvatar(range[newPos]);
    };

    SignUpSocialView.prototype._setAvatar = function(id) {
      var img;
      this.options.user.avatar = id;
      img = (this._avatars != null) && (this._avatars[id] != null) ? this._avatars[id].img : '/events/user.png';
      return this._avatarElement.setAttribute('src', './images' + img);
    };

    SignUpSocialView.prototype.selectCity = function(event) {
      var current, newPos, range, step;
      step = parseInt(event.currentTarget.getAttribute('data-step', 10));
      range = Object.keys(this._cities);
      current = range.indexOf(this.options.user.city_id);
      newPos = step + current;
      if (newPos >= range.length) {
        newPos = 0;
      }
      if (newPos < 0) {
        newPos = range.length - 1;
      }
      this._setCity(range[newPos]);
      this.$('#cityLang').html(app.tr(this.citiesLocale['' + this.options.user.city_id]));
      return this.$('.js-city-lang').show();
    };

    SignUpSocialView.prototype._setCity = function(id) {
      var title;
      this.options.user.city_id = id;
      title = this._cities[id].title;
      return this._cityElement.value = title;
    };

    SignUpSocialView.prototype.signUpSubmit = function(event) {
      var data, form, showValidationErrors;
      event.preventDefault();
      this.$('.js-field-error').addClass('u-hide').empty();
      if ((this.requestInProcess != null) && this.requestInProcess) {
        return false;
      }
      form = this.$el[0].querySelector('#social-sign-up-form');
      data = {
        city_id: this.options.user.city_id,
        avatar: this.options.user.avatar,
        username: form.elements.username.value,
        email: form.elements.email.value,
        fio: form.elements.full_name.value,
        ref_id: form.elements.ref_id.value,
        agreement: 1
      };
      this.requestInProcess = true;
      showValidationErrors = (function(_this) {
        return function(validationErrors) {
          var error, field, message, results;
          results = [];
          for (field in validationErrors) {
            error = validationErrors[field];
            if ((form.elements[field] != null)) {
              message = typeof error !== 'string' ? error.join('<br/>') : error;
              results.push(_this.$('#' + field + '-error').removeClass('u-hide').text(message));
            } else {
              results.push(void 0);
            }
          }
          return results;
        };
      })(this);
      return this.app.server.social.register({
        user: data,
        socialUser: this.options.user,
        provider: this.options.provider,
        token: this.options.token,
        success: (function(_this) {
          return function(data) {
            _this.requestInProcess = false;
            if (data.status === 'success' && (data != null ? data.token : void 0)) {
              localStorage.setItem('auth_token', data.token);
              return _this.app.screens.main('auto_login', {
                first_login: true
              });
            } else {
              return _this.app.screens.modal('common/info-popup', {
                msg: data.error_message || app.tr("Registration failed")
              });
            }
          };
        })(this),
        error: (function(_this) {
          return function(data) {
            _this.requestInProcess = false;
            if (data.error_code === 'INVALID_FIELDS') {
              return showValidationErrors(data.error_message);
            } else if (data.error_code === 'USER_EXISTS') {
              return _this.app.screens.main('login');
            } else {
              return _this.app.screens.modal('common/info-popup', {
                msg: data.error_message || app.tr("Registration failed")
              });
            }
          };
        })(this)
      });
    };

    return SignUpSocialView;

  })(ItemView);
  return SignUpSocialView;
});
