define(['app', 'views/item-view', 'underscore', 'text!templates/maria/add-funds.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    events: {
      'click .js-apply': 'addFunds',
      'change .amount': 'changeAmount'
    },
    changeAmount: function(event) {
      var amount;
      amount = this.$el.find('.js-amount').val();
      if (isNaN(amount)) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount may consist only of digits")
        });
      } else {
        return this.$el.find('.saved-amount').html(amount);
      }
    },
    addFunds: function(event) {
      var amount, companyId, currency, loader;
      this.lockUI();
      loader = this.setLoaderOnElement(event.currentTarget, app.tr('Adding'));
      amount = this.$el.find('.js-amount').val();
      companyId = this.options.companyId;
      currency = this.$el.find('.o-switcher').hasClass('o-switcher--active') ? 'vgold' : 'vdollars';
      if (amount === "") {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Specify the sum")
        });
      } else if (isNaN(amount)) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount can only consist of digits")
        });
      } else if (amount <= 0) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount must be greater than zero")
        });
      } else {
        return app.server.cityHall.addFunds({
          companyId: companyId,
          amount: amount,
          success: (function(_this) {
            return function(data) {
              app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Account refilled")
              }, app.screens.back());
              _this.unlockUI();
              return loader.remove();
            };
          })(this),
          error: (function(_this) {
            return function(data) {
              _this.unlockUI();
              loader.remove();
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            };
          })(this)
        });
      }
    }
  });
});
