var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/maria/company.tmpl', 'views/components/energy-slider', 'views/components/currency'], function(app, ItemView, _, template, EnergySlider, formatCurrency) {
  var Company;
  Company = (function(superClass) {
    extend(Company, superClass);

    function Company() {
      this.showReports = bind(this.showReports, this);
      return Company.__super__.constructor.apply(this, arguments);
    }

    Company.prototype.template = template;

    Company.prototype.data = {
      companyInfo: {
        pointer: 'business.companyInfo',
        companyId: function() {
          return this.options.companyId;
        }
      },
      effects: {
        pointer: 'business.company.effects',
        companyId: function() {
          return this.options.companyId;
        }
      },
      info: 'user.info.short'
    };

    Company.prototype.events = {
      'click .js-goto-employees': 'gotoEmployees',
      'click .js-goto-storage': 'gotoStorage',
      'click .js-add-funds': 'addFunds',
      'click .js-take-funds': 'takeFunds',
      'click .js-settings': 'settings',
      'click .js-change-prod': 'changeProd',
      'click .js-toggle-effects': 'showEffects',
      'click .js-reports-archive': 'showReports',
      'click .js-generate-report': 'generateReport'
    };

    Company.prototype.addFunds = function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('maria/add-funds', {
        companyId: companyId
      });
    };

    Company.prototype.takeFunds = function(event) {
      var companyId, withdrawTax;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      withdrawTax = event.currentTarget.getAttribute('data-withdraw-tax');
      return app.screens.dialog('maria/withdraw', {
        companyId: companyId,
        withdrawTax: withdrawTax
      });
    };

    Company.prototype.gotoEmployees = function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('maria/employees', {
        companyId: companyId
      });
    };

    Company.prototype.gotoStorage = function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.tab('maria/company-storage', {
        companyId: companyId
      });
    };

    Company.prototype.onDomRefresh = function() {
      this.toggleView('.js-reports-switcher', '.js-reports-buttons');
      return [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        return el.innerHTML = formatCurrency(el.innerHTML);
      });
    };

    Company.prototype.settings = function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/settings', {
        companyId: companyId
      });
    };

    Company.prototype.changeProd = function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/change-production', {
        companyId: companyId
      });
    };

    Company.prototype.showEffects = function(event) {
      return $('.js-effects').toggle(400).removeClass('u-hide');
    };

    Company.prototype.showReports = function(event) {
      var companyId;
      this.lockUI();
      companyId = event.currentTarget.getAttribute('data-company-id');
      return app.screens.dialog('business/company-reports/archive', {
        companyId: companyId,
        companyName: this._data.companyInfo.company.name
      });
    };

    Company.prototype.generateReport = function(event) {
      var companyId, msg, reportType;
      companyId = event.currentTarget.getAttribute('data-company-id');
      reportType = event.currentTarget.getAttribute('data-report-type');
      msg = app.tr('Are you sure you generate report?');
      return app.screens.modal('common/confirmation-popup', {
        msg: msg,
        callback: (function(_this) {
          return function() {
            _this.lockUI();
            return app.server.business.generateReport({
              companyId: companyId,
              reportType: reportType,
              success: function(data) {
                return app.screens.modal('business/company-reports/report', {
                  report: data.report
                });
              }
            });
          };
        })(this)
      });
    };

    return Company;

  })(ItemView);
  return Company;
});
