define(['app', 'views/item-view', 'underscore', 'text!templates/maria/new-bill.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      bills: 'cityHall.billList'
    },
    events: {
      'click .js-select': 'selectBill',
      'click .js-create-bill': 'addNewBill',
      'change .js-new-value': 'changeAmount'
    },
    description_length: 50,
    changeAmount: function(event) {
      var amount;
      amount = this.$el.find('.js-new-value').val();
      if (isNaN(amount)) {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("The amount may consist only of digits")
        });
      }
    },
    addNewBill: function(event) {
      var amount, billId, description, loader;
      amount = this.$el.find('.js-new-value').val();
      billId = this.$('.js-select').attr("data-id");
      description = this.$el.find('.js-description').val();
      if (description.length > this.description_length) {
        return this.$el.find('.js-description-error').show();
      } else {
        this.lockUI();
        loader = this.setLoaderOnElement(event.currentTarget, app.tr('Creating'));
        return app.server.cityHall.newBill({
          billId: billId,
          amount: amount,
          description: description,
          success: (function(_this) {
            return function(data) {
              loader.remove();
              if (app.gaEnabled) {
                app.ga('send', 'event', "city hall", "law draft");
              }
              return app.screens.modal('common/success-popup', {
                msg: data.setFlash[0].msg || app.tr("Project has been accepted")
              });
            };
          })(this),
          error: (function(_this) {
            return function(data) {
              loader.remove();
              _this.unlockUI();
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            };
          })(this)
        });
      }
    },
    preprocessData: function(data) {
      var i, item, len, ref;
      ref = data.bills.bills;
      for (i = 0, len = ref.length; i < len; i++) {
        item = ref[i];
        item.title = item.CityValueType.description || item.CityValueType.description_en;
        item.id = item.CityValueType.id;
      }
      this.billsCollection = new Backbone.Collection(data.bills.bills);
      return data;
    },
    selectBill: function(event) {
      this.lockUI();
      return app.screens.dialog('common/select-dialog', {
        collection: this.billsCollection,
        callback: (function(_this) {
          return function(itemId) {
            event.currentTarget.setAttribute('data-id', itemId);
            _this.$('.js-select .js-item-name').html(_this.billsCollection.get(itemId).get("title"));
            return _this.$('.js-current-value').html(_this.billsCollection.get(itemId).get("CityValue")["value"] + " " + _this.billsCollection.get(itemId).get("CityValueType")["measure"]);
          };
        })(this)
      });
    },
    updateInfo: function(id) {
      var element;
      element = _.filter(this._data.bills.bills, (function(_this) {
        return function(bill) {
          return bill.CityValueType.id === parseInt(id);
        };
      })(this));
      this.el.querySelector('.js-bill-name').innerHTML = element[0].CityValueType.description_ru || element[0].CityValueType.description_en;
      return this.el.querySelector('.js-current-value').innerHTML = parseInt(element[0].CityValue.value) + element[0].CityValueType.measure;
    }
  });
});
