var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/messages/conversations.tmpl'], function(app, ItemView, _, template) {
  var ConversationMessageView;
  ConversationMessageView = (function(superClass) {
    extend(ConversationMessageView, superClass);

    function ConversationMessageView() {
      this.onSendMessageFormSubmit = bind(this.onSendMessageFormSubmit, this);
      this.onRender = bind(this.onRender, this);
      this._triggerKeyboardHide = bind(this._triggerKeyboardHide, this);
      this._triggerKeyboardShow = bind(this._triggerKeyboardShow, this);
      this.initialize = bind(this.initialize, this);
      return ConversationMessageView.__super__.constructor.apply(this, arguments);
    }

    ConversationMessageView.prototype.className = 'messages-layout';

    ConversationMessageView.prototype.template = template;

    ConversationMessageView.prototype.data = {
      messages: {
        pointer: 'messages.fromUser',
        userId: function() {
          return this.options.userId;
        },
        page: 1
      },
      info: 'user.info.short'
    };

    ConversationMessageView.prototype.events = {
      'submit .js-send-message-form': 'onSendMessageFormSubmit',
      'click .js-send-message': 'sendMessage',
      'click .js-next-page': 'nextPage',
      'click .js-prev-page': 'prevPage',
      'click .js-goto-profile': 'gotoProfile'
    };

    ConversationMessageView.prototype.initialize = function(options) {
      this.options = options;
      ConversationMessageView.__super__.initialize.call(this, this.options);
      this.listenTo(app, "keyboard:show", this._triggerKeyboardShow);
      return this.listenTo(app, "keyboard:hide", this._triggerKeyboardHide);
    };

    ConversationMessageView.prototype._triggerKeyboardShow = function(keyboardHeight) {
      return this.$('.c-footer').css("bottom", keyboardHeight);
    };

    ConversationMessageView.prototype._triggerKeyboardHide = function() {
      return this.$('.c-footer').css("bottom", 0);
    };

    ConversationMessageView.prototype.onRender = function() {
      return this.scrollToBottom();
    };

    ConversationMessageView.prototype.onSendMessageFormSubmit = function(event) {
      event.preventDefault();
      return this.sendMessage();
    };

    ConversationMessageView.prototype.nextPage = function() {
      this.data.messages.page++;
      return this.loadData();
    };

    ConversationMessageView.prototype.prevPage = function() {
      this.data.messages.page--;
      return this.loadData();
    };

    ConversationMessageView.prototype.scrollToBottom = function() {
      return this.$el.scrollTop(this.el.scrollHeight);
    };

    ConversationMessageView.prototype.sendMessage = function(event) {
      var message, userId;
      this.lockUI();
      userId = this.options.userId;
      message = this.el.querySelector('.js-message').value;
      if (message.length === 0) {
        return this.app.screens.modal('common/info-popup', {
          msg: app.tr(' Message is empty')
        });
      } else {
        return this.app.server.messages.send({
          userId: userId,
          message: message,
          success: (function(_this) {
            return function(data) {
              if (data.setFlash.error === 1) {
                return app.screens.modal('common/info-popup', {
                  msg: data.setFlash[0].msg || app.tr("Something went wrong")
                }, app.screens.back());
              } else {
                return _this.reload();
              }
            };
          })(this),
          error: function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg
            });
          }
        });
      }
    };

    ConversationMessageView.prototype.gotoProfile = function(event) {
      var hasProfile, userId;
      this.lockUI();
      event.stopPropagation();
      userId = event.currentTarget.getAttribute('data-user-id');
      hasProfile = event.currentTarget.getAttribute('data-user-has-profile') === 'true';
      if (hasProfile) {
        return app.screens.dialog('users/profile', {
          userId: userId
        });
      }
    };

    ConversationMessageView.prototype.sendGAView = function() {
      if (this.app.config.googleAnalyticsEnabled && this.app.ga) {
        return this.app.ga('send', 'pageview', {
          page: '/scr/' + this.options.id + '/' + this.options.userId,
          title: ''
        });
      }
    };

    return ConversationMessageView;

  })(ItemView);
  return ConversationMessageView;
});
