var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/messages/new.tmpl'], function(app, ItemView, _, template) {
  var NewMessageView;
  NewMessageView = (function(superClass) {
    extend(NewMessageView, superClass);

    function NewMessageView() {
      this._triggerKeyboardHide = bind(this._triggerKeyboardHide, this);
      this._triggerKeyboardShow = bind(this._triggerKeyboardShow, this);
      this.initialize = bind(this.initialize, this);
      return NewMessageView.__super__.constructor.apply(this, arguments);
    }

    NewMessageView.prototype.className = 'messages-layout';

    NewMessageView.prototype.template = template;

    NewMessageView.prototype.options = {
      receiver: null,
      searchResult: null,
      previousSearchResult: null,
      searchParams: {
        query: '',
        onlyOnline: false
      },
      message: ''
    };

    NewMessageView.prototype.events = {
      'click .js-only-online': 'toggleOnlyOnline',
      'keyup .c-search-form': 'onQueryChange',
      'keyup .js-message': 'onMessageChange',
      'submit .c-search-form': 'onSearchFormSubmit',
      'click .js-set-receiver': 'setReceiver',
      'submit .js-send-message-form': 'onSendFormSubmit',
      'click .js-send-message': 'sendMessage',
      'click .js-goto-profile': 'gotoProfile'
    };

    NewMessageView.prototype.initialize = function(options) {
      this.options = options;
      NewMessageView.__super__.initialize.call(this, this.options);
      this.listenTo(app, "keyboard:show", this._triggerKeyboardShow);
      return this.listenTo(app, "keyboard:hide", this._triggerKeyboardHide);
    };

    NewMessageView.prototype._triggerKeyboardShow = function(keyboardHeight) {
      return this.$('.c-footer').css("bottom", keyboardHeight);
    };

    NewMessageView.prototype._triggerKeyboardHide = function() {
      return this.$('.c-footer').css("bottom", 0);
    };

    NewMessageView.prototype.jsBack = function(event) {
      if (this.options.receiver) {
        this.restorePreviousSearchResult();
        this.reload();
        return event.stopPropagation();
      } else {
        return NewMessageView.__super__.jsBack.call(this, event);
      }
    };

    NewMessageView.prototype.onQueryChange = function(event) {
      return this.options.searchParams.query = this.$('.js-query').val();
    };

    NewMessageView.prototype.toggleOnlyOnline = function(event) {
      var $onlyOnline;
      $onlyOnline = this.$('.js-only-online');
      $onlyOnline.toggleClass('o-switcher-small--active');
      this.options.searchParams.onlyOnline = $onlyOnline.hasClass('o-switcher-small--active');
      if (this.options.searchParams.query !== '') {
        return this.usersSearch();
      }
    };

    NewMessageView.prototype.onSearchFormSubmit = function(event) {
      event.preventDefault();
      return this.usersSearch();
    };

    NewMessageView.prototype.usersSearch = function() {
      this.lockUI();
      if (this.options.searchParams.query === '') {
        return;
      }
      return app.server.messages.usersSearch({
        query: this.options.searchParams.query,
        onlyOnline: this.options.searchParams.onlyOnline,
        success: (function(_this) {
          return function(data) {
            _this.options.searchResult = data;
            return _this.reload();
          };
        })(this),
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    };

    NewMessageView.prototype.setReceiver = function(event) {
      var userIndex;
      userIndex = event.currentTarget.getAttribute('data-searchResult-user-index');
      this.options.receiver = this.options.searchResult.users[userIndex];
      this.clearSearchResult();
      return this.reload();
    };

    NewMessageView.prototype.clearSearchResult = function() {
      this.options.previousSearchResult = this.options.searchResult;
      return this.options.searchResult = null;
    };

    NewMessageView.prototype.clearReceiver = function() {
      return this.options.receiver = null;
    };

    NewMessageView.prototype.clearSearchParams = function() {
      this.options.searchParams.query = '';
      return this.options.searchParams.onlyOnline = false;
    };

    NewMessageView.prototype.restorePreviousSearchResult = function() {
      this.clearReceiver();
      this.options.searchResult = this.options.previousSearchResult;
      return this.options.previousSearchResult = null;
    };

    NewMessageView.prototype.onMessageChange = function(event) {
      var message;
      message = this.$('.js-message').val();
      message = message.replace(/^[\s]+/g, '');
      message = message.replace(/[\s]+$/g, '');
      return this.options.message = message;
    };

    NewMessageView.prototype.onSendFormSubmit = function(event) {
      event.preventDefault();
      return this.sendMessage();
    };

    NewMessageView.prototype.sendMessage = function() {
      var message, userId;
      this.lockUI();
      if (this.options.message === '') {
        this.app.screens.modal('common/info-popup', {
          msg: app.tr(' Message is empty')
        });
      }
      userId = this.options.receiver.User.id;
      message = this.options.message;
      return this.app.server.messages.send({
        userId: userId,
        message: message,
        success: (function(_this) {
          return function(data) {
            if (data.setFlash.error === 1) {
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr(' Message is esent')
              }, app.screens.back());
            } else {
              userId = _this.options.receiver.User.id;
              _this.clearSearchResult();
              _this.clearReceiver();
              _this.clearSearchParams();
              _this.render();
              return _this.gotoConversations(userId);
            }
          };
        })(this),
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg
          });
        }
      });
    };

    NewMessageView.prototype.gotoConversations = function(userId) {
      return app.screens.tab('messages/conversations', {
        userId: userId
      });
    };

    NewMessageView.prototype.gotoProfile = function(event) {
      var hasProfile, userId;
      event.stopPropagation();
      userId = event.currentTarget.getAttribute('data-user-id');
      hasProfile = event.currentTarget.getAttribute('data-user-has-profile') === 'true';
      if (hasProfile) {
        return app.screens.dialog('users/profile', {
          userId: userId
        });
      }
    };


    /*
    			Center cloud
     */

    NewMessageView.prototype.centerCloud = function() {
      var $cloud, $container;
      if ($('.c-cloud').length > 0) {
        $cloud = $('.c-cloud');
        $container = $('.js-current-screen');
        return $cloud.css('margin-top', ($container.height() / 2 - $cloud.height() / 2) / 2);
      }
    };

    NewMessageView.prototype.onDomRefresh = function() {
      return this.centerCloud();
    };

    return NewMessageView;

  })(ItemView);
  return NewMessageView;
});
