define(['app', 'views/item-view', 'underscore', 'text!templates/military-base/blockpost-popup.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: function() {
      var pointers;
      pointers = {
        post: {
          pointer: 'military.at.areas.post',
          areaId: function() {
            return this.options.areaId;
          },
          postId: function() {
            return this.options.postId;
          }
        }
      };
      if (this.options.isRebelWar) {
        pointers.rebelInfo = {
          pointer: 'military.rebelWar.getInfo',
          rebelWarId: function() {
            return this.options.rebelWarId;
          }
        };
      }
      pointers.userInfo = {
        pointer: 'user.info.short'
      };
      return pointers;
    },
    events: {
      'click .js-fight': 'fight',
      'click .js-scout': 'scout',
      'click .js-last-scouting': 'lastScouting',
      'click .js-send-clones': 'sendClones',
      'keyup .js-clones-count': 'updateProgressBar'
    },
    fight: function() {
      this.lockUI();
      return app.server.military.at.checkClone({
        success: (function(_this) {
          return function(data) {
            return app.screens.dialog('profile', {
              from: 'military',
              areaId: _this.options.areaId,
              postId: _this.options.postId
            });
          };
        })(this)
      });
    },
    scout: function() {
      this.lockUI();
      return app.server.military.at.areas.scout({
        areaId: this.options.areaId,
        postId: this.options.postId,
        success: (function(_this) {
          return function(scoutingResult) {
            return _this.options.tacticalMap.setScoutNumbers(_this.options.postId, scoutingResult.assailantsClonesNumber, scoutingResult.defendersClonesNumber);
          };
        })(this)
      });
    },
    lastScouting: function() {
      var scoutingResult;
      scoutingResult = this._data.post.lastScoutingResult;
      return this.options.tacticalMap.setScoutNumbers(this.options.postId, scoutingResult.assailantsClonesNumber, scoutingResult.defendersClonesNumber);
    },
    sendClones: function() {
      var clonesCount, rebelData;
      this.lockUI();
      delete app.screens._cache['views/military-base/tactics'];
      delete app.screens._cache['views/common/info-popup'];
      clonesCount = parseInt(this.$('.js-clones-count').val());
      if (isNaN(clonesCount)) {
        clonesCount = 0;
      }
      if (clonesCount === 0) {
        return;
      }
      rebelData = this._data.rebelInfo.info.data;
      if ((rebelData.alive_rebels_count - rebelData.sent_to_post_count) <= 0) {
        return app.screens.modal('common/info-popup', {
          msg: "Has't left rebels"
        });
      }
      return app.screens.dialog('military-base/tactics', {
        from: 'military',
        areaId: this.options.areaId,
        postId: this.options.postId,
        clonesCount: clonesCount,
        isRebelWar: true,
        rebelWarId: this.options.rebelWarId
      });
    },
    onDomRefresh: function() {
      if (this.options.isRebelWar) {
        return this.updateProgressBar();
      }
    },
    updateProgressBar: function(event) {
      var clonesCount, percent, rebelData;
      clonesCount = parseInt(this.$('.js-clones-count').val());
      if (isNaN(clonesCount)) {
        clonesCount = 0;
      }
      rebelData = this._data.rebelInfo.info.data;
      if (clonesCount + rebelData.sent_to_post_count === 0) {
        percent = 0;
      } else {
        percent = (rebelData.sent_to_post_count + clonesCount) / rebelData.alive_rebels_count * 100;
      }
      return this.$('.c-progress .c-progress__inner').css('width', percent + '%');
    }
  });
});
