var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/news/article.tmpl'], function(app, ItemView, _, template) {
  var ArticleView;
  ArticleView = (function(superClass) {
    extend(ArticleView, superClass);

    function ArticleView() {
      this._triggerKeyboardHide = bind(this._triggerKeyboardHide, this);
      this._triggerKeyboardShow = bind(this._triggerKeyboardShow, this);
      this.initialize = bind(this.initialize, this);
      return ArticleView.__super__.constructor.apply(this, arguments);
    }

    ArticleView.prototype.template = template;

    ArticleView.prototype.data = {
      post: {
        pointer: 'news.post',
        postId: function() {
          return this.options.postId;
        }
      }
    };

    ArticleView.prototype.events = {
      'click .js-newspaper': 'goToNewspaper',
      'click .js-like': 'addLike',
      'click .js-add-comment': 'sendComment',
      'click .js-edit': 'editComment',
      'click .js-donate': 'donate'
    };

    ArticleView.prototype.initialize = function(options) {
      this.options = options;
      ArticleView.__super__.initialize.call(this, this.options);
      this.listenTo(app, "keyboard:show", this._triggerKeyboardShow);
      return this.listenTo(app, "keyboard:hide", this._triggerKeyboardHide);
    };

    ArticleView.prototype._triggerKeyboardShow = function(keyboardHeight) {
      return this.$('.c-footer').css("bottom", keyboardHeight);
    };

    ArticleView.prototype._triggerKeyboardHide = function() {
      return this.$('.c-footer').css("bottom", 0);
    };

    ArticleView.prototype.goToNewspaper = function(event) {};

    ArticleView.prototype.addLike = function(event) {
      var likes;
      this.lockUI();
      if (!$(event.currentTarget).hasClass('c-round-btn--green')) {
        $(event.currentTarget).toggleClass('c-round-btn--green c-round-btn--grey');
        $(event.currentTarget).toggleClass('js-like');
        $(event.currentTarget).children('.o-icon--like-2').toggleClass('o-icon--like-green o-icon--like-2');
        likes = parseInt($(event.currentTarget).children('.likes-count').html());
        $(event.currentTarget).children('.likes-count').html(likes + 1);
      }
      return app.server.news.add_like({
        postId: this.options.postId,
        success: (function(_this) {
          return function(data) {
            _this.unlockUI();
          };
        })(this),
        error: (function(_this) {
          return function(data) {
            _this.unlockUI();
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          };
        })(this)
      });
    };

    ArticleView.prototype.sendComment = function(event) {
      var commentText;
      this.lockUI();
      commentText = this.$el.find('.js-text-comment').val();
      if (commentText === "") {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Comment cannot be empty")
        });
      } else {
        return app.server.news.addComment({
          postId: this.options.postId,
          body: commentText,
          success: (function(_this) {
            return function(data) {
              _this.unlockUI();
              return _this.reload();
            };
          })(this),
          error: (function(_this) {
            return function(data) {
              _this.unlockUI();
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            };
          })(this)
        });
      }
    };

    ArticleView.prototype.editComment = function(event) {
      var commentId;
      commentId = event.currentTarget.getAttribute('data-comment-id');
      return app.screens.dialog('news/edit-comment', {
        commentId: commentId
      });
    };

    ArticleView.prototype.donate = function(event) {
      var newspaper_user_id;
      this.lockUI();
      newspaper_user_id = this._data.post.Newspaper.user_id;
      return app.screens.modal('news/donate-popup', {
        newspaper_user_id: newspaper_user_id,
        donate_tax: this._data.post.donate_tax
      });
    };

    ArticleView.prototype.sendGAView = function() {
      if (this.app.config.googleAnalyticsEnabled && this.app.ga) {
        return this.app.ga('send', 'pageview', {
          page: '/scr/' + this.options.id + '/' + this.options.postId,
          title: ''
        });
      }
    };

    return ArticleView;

  })(ItemView);
  return ArticleView;
});
