define(['app', 'views/item-view', 'underscore', 'text!templates/parties/common.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    data: {
      info: {
        pointer: 'party.info',
        partyId: function() {
          if (this.options.screen_options != null) {
            return this.options.screen_options;
          } else {
            return null;
          }
        }
      },
      friends: {
        pointer: 'party.friends',
        partyId: function() {
          if (this.options.screen_options != null) {
            return this.options.screen_options;
          } else {
            return null;
          }
        }
      },
      request_count: 'party.requests.count'
    },
    events: {
      'click .js-goto-party-manage': 'partyManage',
      'click .js-leave-party': 'leaveParty',
      'click .js-join-to-party': 'joinToParty',
      'click .js-disband-party': 'disbandParty',
      'click .js-friendly-select': 'friendlySelect',
      'click .js-goto-party-level-up': 'levelUp'
    },
    commonInfo: function(event) {
      var partyId;
      this.lockUI();
      partyId = event.currentTarget.getAttribute('data-party-id');
      return app.screens.dialog('parties/common', {
        partyId: partyId
      });
    },
    leaveParty: function(event) {
      this.lockUI();
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('Are you sure you want to leave the party? You will be excluded from the parliamentary list and lose the deputy chair.'),
        callback: (function(_this) {
          return function(count) {
            return app.server.party.leave({
              success: function(data) {
                return app.screens.modal('common/success-popup', {
                  msg: data.setFlash[0].msg
                }, app.screens.back());
              }
            });
          };
        })(this)
      });
    },
    levelUp: function(event) {
      var self;
      this.lockUI();
      self = this;
      return app.quests.doIfCompleted('social_passport', function() {
        return self._levelUp(event);
      });
    },
    _levelUp: function(event) {
      var partyId;
      partyId = event.currentTarget.getAttribute('data-party-id');
      return app.server.party.level.up.price({
        partyId: partyId,
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/confirmation-popup', {
              msg: app.tr("Purchase +25 seats in the party for ") + (data.price.price + " " + data.price.currency + "?"),
              callback: function(count) {
                return app.server.party.level.up({
                  partyId: partyId,
                  success: function(data) {
                    return app.screens.modal('common/success-popup', {
                      msg: data.setFlash[0].msg
                    }, app.screens.back());
                  }
                });
              }
            });
          };
        })(this)
      });
    },
    partyManage: function(event) {
      this.lockUI();
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.dialog('parties/manage');
      });
    },
    joinToParty: function(event) {
      var partyId;
      this.lockUI();
      partyId = event.currentTarget.getAttribute('data-party-id');
      return app.server.party.join({
        partyId: partyId,
        success: (function(_this) {
          return function(data) {
            return app.screens.modal('common/success-popup', {
              msg: data.setFlash[0].msg
            }, app.screens.back());
          };
        })(this)
      });
    },
    disbandParty: function(event) {
      var partyName, ref, ref1, ref2;
      this.lockUI();
      partyName = (ref = this._data.info) != null ? (ref1 = ref.party) != null ? (ref2 = ref1.Party) != null ? ref2.name : void 0 : void 0 : void 0;
      return app.quests.doIfCompleted('social_passport', function() {
        return app.screens.modal('common/confirmation-popup', {
          msg: app.tr('Are you sure you want to disband the party?'),
          callback: (function(_this) {
            return function(count) {
              return app.server.party.disband({
                success: function(data) {
                  if (app.gaEnabled) {
                    app.ga('send', 'event', "party", "dismiss", partyName);
                  }
                  return app.screens.modal('common/success-popup', {
                    msg: data.setFlash[0].msg
                  }, app.screens.back());
                }
              });
            };
          })(this)
        });
      });
    },
    friendlySelect: function(event) {
      this.lockUI();
      return app.quests.doIfCompleted('social_passport', function() {
        var partyId;
        partyId = event.currentTarget.getAttribute('data-party-id');
        return app.screens.dialog('parties/friendly-party', {
          partyId: partyId
        });
      });
    }
  });
});
