var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['underscore', 'views/item-view', 'text!templates/profile.tmpl', 'views/components/clusterize-helper', 'views/components/item-type-comparator'], function(_, ItemView, template, ClusterizeHelper, itemTypeComparatorComponent) {
  var ProfileView;
  ProfileView = (function(superClass) {
    extend(ProfileView, superClass);

    function ProfileView() {
      this.updateInventory = bind(this.updateInventory, this);
      return ProfileView.__super__.constructor.apply(this, arguments);
    }

    ProfileView.prototype.template = template;

    ProfileView.prototype.data = {
      info: 'user.info.short',
      inventory: 'inventory'
    };

    ProfileView.prototype.events = {
      'click .js-item-action': 'itemAction',
      'click .js-buy-slots': 'buySlots',
      'click .c-icon-injury--red': 'injuryPopup',
      'click .c-icon-injury--green': 'energyPopup',
      'click .js-tactics': 'chooseTactics'
    };

    ProfileView.prototype.initialize = function() {
      ProfileView.__super__.initialize.apply(this, arguments);
      this.itemTypeComparatorFactory = itemTypeComparatorComponent.itemTypeComparatorFactory;
      this.listenTo(app.vent, 'inventory:inventory_changed', this.updateInventory);
      this.listenTo(app.vent, 'inventory:item_unequipped', (function(_this) {
        return function(event) {
          var ref, ref1;
          if (event.data && ((ref = event.data.itemInfo) != null ? (ref1 = ref.ItemType) != null ? ref1.prestige : void 0 : void 0)) {
            return _this.updatePrestige(-event.data.itemInfo.ItemType.prestige);
          }
        };
      })(this));
      return this.listenTo(app.vent, 'inventory:item_equipped', (function(_this) {
        return function(event) {
          var ref, ref1;
          if (event.data && ((ref = event.data.itemInfo) != null ? (ref1 = ref.ItemType) != null ? ref1.prestige : void 0 : void 0)) {
            return _this.updatePrestige(event.data.itemInfo.ItemType.prestige);
          }
        };
      })(this));
    };

    ProfileView.prototype.updatePrestige = function(diff) {
      var initial, ref;
      if (((ref = this._data) != null ? ref.info : void 0) != null) {
        initial = Number(this._data.info.user.User.prestige) || 0;
        this._data.info.user.User.prestige = Math.max(initial + diff, 0);
        return this.render();
      }
    };

    ProfileView.prototype.updateInventory = function(event) {
      var ref, ref1, storage;
      if (!event || (event.data == null)) {
        return;
      }
      storage = event.data;
      if (this._data && (((ref = this._data) != null ? (ref1 = ref.inventory) != null ? ref1.storage : void 0 : void 0) != null)) {
        this._data.inventory.storage = storage;
        return this.render();
      }
    };

    ProfileView.prototype.injuryPopup = function(event) {
      var injured, ref, traumasEffect;
      if (((ref = this._data) != null ? ref.info : void 0) != null) {
        this.lockUI();
        injured = this._data.info.injured;
        traumasEffect = this._data.info.traumasEffect;
        return this.app.screens.modal('common/injury-popup', {
          injured: injured,
          traumasEffect: traumasEffect
        });
      }
    };

    ProfileView.prototype.energyPopup = function(event) {
      var items, recoveryTime, ref;
      if (((ref = this._data) != null ? ref.info : void 0) != null) {
        this.lockUI();
        recoveryTime = this._data.info.user.User.delta_recovery_energy;
        items = this._data.info.eatEffects;
        return this.app.screens.modal('common/energy-popup', {
          items: items,
          recoveryTime: recoveryTime
        });
      }
    };

    ProfileView.prototype.serializeData = function() {
      var data, itemTypeComparator;
      data = ProfileView.__super__.serializeData.apply(this, arguments);
      data.equippedItems = {};
      data.unequippedItems = [];
      if (data && (data.inventory != null) && data.inventory.storage.itemsArray.length !== 0) {
        data.inventory.storage.itemsArray.forEach(function(item) {
          if (data.inventory.storage.itemTypes != null) {
            item.ItemType = data.inventory.storage.itemTypes[item.UserItem.item_type_id];
          }
          if (item.UserItem.equipped === 1) {
            return data.equippedItems[item.UserItem.equipped_slot] = item;
          } else {
            return data.unequippedItems.push(item);
          }
        });
        itemTypeComparator = this.itemTypeComparatorFactory(data.inventory.categorySortWeight);
        data.unequippedItems = data.unequippedItems.sort(itemTypeComparator);
      }
      return data;
    };

    ProfileView.prototype.itemAction = function(event) {
      var energyDrinkId, i, itemId, itemTypeId, len, ref;
      this.lockUI();
      itemId = event.currentTarget.getAttribute('data-item-id');
      itemTypeId = event.currentTarget.getAttribute('data-item-type-id');
      if (this._data.inventory.energy_drinks_ids != null) {
        ref = this._data.inventory.energy_drinks_ids;
        for (i = 0, len = ref.length; i < len; i++) {
          energyDrinkId = ref[i];
          if (parseInt(itemTypeId) === energyDrinkId) {
            return app.screens.modal('inventory/energy-popup', {
              itemId: itemId,
              itemTypeId: itemTypeId
            });
          }
        }
      }
      return app.screens.modal('inventory/popup', {
        inventory: this._data.inventory.storage.itemsArray,
        needReload: false,
        itemId: itemId,
        itemTypeId: itemTypeId,
        isResetCert: parseInt(itemTypeId) === this._data.inventory.reset_certificate_id ? true : false
      });
    };

    ProfileView.prototype.buySlots = function(event) {
      var size;
      this.lockUI();
      size = this._data.inventory.storage.inventorySize + this._data.inventory.expandInfo.size_step;
      return app.screens.modal('common/confirmation-popup', {
        msg: app.tr('Buy additional slots?'),
        callback: function() {
          return app.server.inventory.buySlots({
            size: size,
            success: function(data) {
              return app.screens.modal('common/success-popup', {
                msg: data.setFlash[0].msg || app.tr("Well done")
              });
            },
            error: function(data) {
              return app.screens.modal('common/info-popup', {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              });
            }
          });
        }
      });
    };

    ProfileView.prototype.chooseTactics = function() {
      this.lockUI();
      return app.screens.back((function(_this) {
        return function() {
          return app.screens.dialog('military-base/tactics', {
            areaId: _this.options.areaId,
            postId: _this.options.postId
          });
        };
      })(this));
    };

    ProfileView.prototype.onDomRefresh = function() {
      return [].forEach.call(this.el.querySelectorAll('.js-currency'), function(el) {
        var position, value;
        value = el.innerHTML;
        position = value.indexOf(':') + 1;
        return el.innerHTML = position === 0 ? value : value.slice(position);
      });
    };

    return ProfileView;

  })(ItemView);
  return ProfileView;
});
