var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['jquery', 'app', 'views/item-view', 'underscore', 'text!templates/shop.tmpl'], function($, app, ItemView, _, template) {
  var ShopView;
  ShopView = (function(superClass) {
    extend(ShopView, superClass);

    function ShopView() {
      this.onBeforeDestroy = bind(this.onBeforeDestroy, this);
      this._updateTimer = bind(this._updateTimer, this);
      this._updateTimers = bind(this._updateTimers, this);
      this.onItemBuy = bind(this.onItemBuy, this);
      this.preprocessData = bind(this.preprocessData, this);
      return ShopView.__super__.constructor.apply(this, arguments);
    }

    ShopView.prototype.template = template;

    ShopView.prototype.data = {
      shop: {
        pointer: 'shop.list'
      }
    };

    ShopView.prototype.events = {
      'click .js-buy': 'onItemBuy',
      'click .js-vgold-buy': 'onVgoldBuy'
    };

    ShopView.prototype._timerIntervalId = 0;

    ShopView.prototype._goods = {};

    ShopView.prototype.preprocessData = function(data) {
      var energyDrinkId, energyGoods, goods, i, len, otherGoods, ref, ref1, timer;
      if ((data != null ? (ref = data.shop) != null ? ref.goods : void 0 : void 0)) {
        timer = false;
        energyGoods = [];
        otherGoods = [];
        energyDrinkId = 1166;
        ref1 = data.shop.goods;
        for (i = 0, len = ref1.length; i < len; i++) {
          goods = ref1[i];
          if (goods.discount) {
            goods.color = 'red';
          } else {
            goods.color = 'yellow';
          }
          if (goods.is_special) {
            goods.color = 'blue';
          }
          if (goods.published_end) {
            goods.time_left = this._intervalStringFromTimestamp(goods.published_end);
            timer = true;
          }
          if (goods.item_type_id === energyDrinkId) {
            energyGoods.push(goods);
          }
          if (goods.item_type_id !== energyDrinkId) {
            otherGoods.push(goods);
          }
          this._goods[goods.id] = goods;
        }
        data.goods = {};
        data.goods.otherGoods = otherGoods;
        data.goods.energyGoods = energyGoods.reverse();
        if (timer) {
          this._timerIntervalId = setInterval(this._updateTimers, 1000);
        }
      }
      return data;
    };

    ShopView.prototype.onVgoldBuy = function() {
      return this.app.shop.gotoVGoldPurchase();
    };

    ShopView.prototype.onItemBuy = function(event) {
      var itemId;
      itemId = event.currentTarget.getAttribute('data-item-id');
      return this.app.screens.modal('shop/purchase-popup', {
        item: this._goods[itemId],
        currency: 1
      });
    };

    ShopView.prototype._updateTimers = function() {
      var element, elements, i, len, results;
      elements = this.el.querySelectorAll('.js-shop-timer');
      results = [];
      for (i = 0, len = elements.length; i < len; i++) {
        element = elements[i];
        results.push(this._updateTimer(element));
      }
      return results;
    };

    ShopView.prototype._updateTimer = function(el) {
      var end, id, item, str;
      end = parseInt(el.getAttribute('data-timestamp')) || 0;
      str = this._intervalStringFromTimestamp(end);
      if (str) {
        return el.innerHTML = str;
      } else {
        id = el.getAttribute('data-item-id');
        item = this.el.querySelector('#js-shop-item-' + id);
        return item.parentNode.removeChild(item);
      }
    };

    ShopView.prototype._intervalStringFromTimestamp = function(timestamp) {
      var diff, div, key, now, part, parts, strParts, strTime;
      now = Math.floor((new Date()).getTime() / 1000);
      diff = timestamp - now;
      if (diff <= 0) {
        return null;
      }
      parts = {
        'days': 3600 * 24,
        'hours': 3600,
        'minutes': 60
      };
      strParts = {};
      for (key in parts) {
        div = parts[key];
        strParts[key] = Math.floor(diff / div);
        diff = diff - strParts[key] * div;
      }
      strParts['seconds'] = diff;
      for (key in strParts) {
        part = strParts[key];
        part = part.toString();
        strParts[key] = part.length < 2 ? '0' + part : part;
      }
      strTime = '';
      if (strParts['days'] !== '00') {
        strTime = strTime + strParts['days'] + ' ';
      }
      strTime = strTime + ' ' + strParts['hours'] + ':' + strParts['minutes'] + ':' + strParts['seconds'];
      return strTime;
    };

    ShopView.prototype.onBeforeDestroy = function() {
      if (this._timerIntervalId) {
        return clearInterval(this._timerIntervalId);
      }
    };


    /*
    			Center cloud
     */

    ShopView.prototype.centerCloud = function() {
      var $cloud, $container;
      if ($('.c-cloud').length > 0) {
        $cloud = $('.c-cloud');
        $container = $('.js-current-screen');
        return $cloud.css('margin-top', ($container.height() / 2 - $cloud.height() / 2) / 2);
      }
    };

    ShopView.prototype.onDomRefresh = function() {
      return this.centerCloud();
    };

    return ShopView;

  })(ItemView);
  return ShopView;
});
