var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/shop/purchase-popup.tmpl'], function(app, ItemView, _, template) {
  var ShopPurchasePopupView;
  ShopPurchasePopupView = (function(superClass) {
    extend(ShopPurchasePopupView, superClass);

    function ShopPurchasePopupView() {
      this._updatePrice = bind(this._updatePrice, this);
      this._stopPriceUpdateInterval = bind(this._stopPriceUpdateInterval, this);
      this._startPriceUpdateInterval = bind(this._startPriceUpdateInterval, this);
      this.onItemBuy = bind(this.onItemBuy, this);
      return ShopPurchasePopupView.__super__.constructor.apply(this, arguments);
    }

    ShopPurchasePopupView.prototype.template = template;

    ShopPurchasePopupView.prototype.events = {
      'click .js-buy': 'onItemBuy'
    };

    ShopPurchasePopupView.prototype.onRender = function() {
      var quantityElement;
      quantityElement = this.el.querySelector('#purchase-quantity');
      quantityElement.addEventListener('focus', this._startPriceUpdateInterval);
      quantityElement.addEventListener('blur', this._stopPriceUpdateInterval);
      return quantityElement.addEventListener('change', this._updatePrice);
    };

    ShopPurchasePopupView.prototype.onItemBuy = function(event) {
      var adjustEvent, currency, itemId, pageId, price, quantity;
      this.lockUI();
      pageId = this.options.id;
      itemId = this.options.item.id;
      currency = this.options.currency;
      quantity = parseInt(this.$('.js-items-number').val()) || 1;
      price = (quantity * parseFloat(this.options.item.price)).toFixed(2);
      if (app.gaEnabled) {
        app.ga('send', 'pageview', {
          page: '/scr/' + pageId + '/item-purchase/' + itemId + '/' + quantity,
          title: ''
        });
        app.ga('send', 'event', 'shop', 'goodsbuybutton', itemId, price);
      }
      if (app.adjustEnabled) {
        adjustEvent = new app.adjust.AdjustEvent("goodsbuybutton");
        app.adjust.Adjust.trackEvent(adjustEvent);
      }
      return this.app.shop.buyItem(itemId, quantity, currency).then(function() {
        if (app.gaEnabled) {
          if (currency === app.shop.CURRENCY_PVP_BADGES_ID) {
            app.ga('send', 'pageview', {
              page: '/scr/' + pageId + '/item-success/' + itemId + '/' + quantity,
              title: ''
            });
            app.ga('send', 'event', 'pvptokenbuy', '' + itemId, '' + quantity, parseInt(price));
          } else {
            app.ga('send', 'pageview', {
              page: '/scr/' + pageId + '/item-success/' + itemId + '/' + quantity,
              title: ''
            });
            app.ga('send', 'event', 'shop', 'goodsbuy', '' + itemId, parseInt(price));
          }
        }
        app.screens.back();
        app.shortInfo.refresh();
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Items purchased")
        });
      }, function(data) {
        var ref, ref1;
        if (app.gaEnabled) {
          app.ga('send', 'event', 'shop', 'goodsbuyabort', (data != null ? (ref = data.error) != null ? ref.code : void 0 : void 0) || 'SERVER_ERROR', price);
        }
        if (app.adjustEnabled) {
          adjustEvent = new app.adjust.AdjustEvent("goodsbuyabort");
          app.adjust.Adjust.trackEvent(adjustEvent);
        }
        app.screens.back();
        return app.screens.modal('common/info-popup', {
          msg: (data != null ? (ref1 = data.error) != null ? ref1.message : void 0 : void 0) || app.tr('Purchase failed')
        });
      });
    };

    ShopPurchasePopupView.prototype._startPriceUpdateInterval = function() {
      return this._inputCounterInterval = setInterval(this._updatePrice, 100);
    };

    ShopPurchasePopupView.prototype._stopPriceUpdateInterval = function() {
      this._currentInput = null;
      if (this._inputCounterInterval) {
        clearInterval(this._inputCounterInterval);
        return this._inputCounterInterval = 0;
      }
    };

    ShopPurchasePopupView.prototype._updatePrice = function() {
      var priceElement, quantity, quantityElement;
      quantityElement = this.el.querySelector('#purchase-quantity');
      priceElement = this.el.querySelector('#purchase-price');
      quantity = parseInt(quantityElement.value, 10) || 1;
      if (quantity > 100) {
        quantity = 100;
      }
      if (quantity < 1) {
        quantity = 1;
      }
      quantityElement.value = quantity;
      return priceElement.innerHTML = (quantity * parseFloat(this.options.item.price)).toFixed(2);
    };

    return ShopPurchasePopupView;

  })(ItemView);
  return ShopPurchasePopupView;
});
