var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/stadium.tmpl', 'views/components/energy-slider'], function(app, ItemView, _, template, EnergySlider) {
  var StadiumView;
  StadiumView = (function(superClass) {
    extend(StadiumView, superClass);

    function StadiumView() {
      this.initialize = bind(this.initialize, this);
      return StadiumView.__super__.constructor.apply(this, arguments);
    }

    StadiumView.prototype.template = template;

    StadiumView.prototype.data = {
      'info': 'user.info.sport'
    };

    StadiumView.prototype.options = {
      selectedSkillId: null
    };

    StadiumView.prototype.events = {
      'click .js-select-skill': 'selectSkill',
      'click .js-goto-choose-trainer': 'gotoChooseTrainer',
      'click .js-train': 'train',
      'click .js-delete-trainer': 'deleteTrainer',
      'click .c-btn-group__button': 'changeEnergy'
    };

    StadiumView.prototype.initialize = function(options1) {
      this.options = options1;
      this.listenTo(app.userEvents, "energy:updated", this.updateEnergyField);
      this.listenTo(app.userEvents, "popup:closed", this.setMaxButton);
      if ((this.options.activeEnergy != null) === false) {
        this.options.activeEnergy = 50;
      }
      this.setMaxButton();
      this.listenTo(app.vent, "stadium:trainer_chosen", (function(_this) {
        return function(arg) {
          _this.programId = arg.programId, _this.licenseId = arg.licenseId, _this.coefficient = arg.coefficient, _this.price = arg.price, _this.currency = arg.currency;
          _this.$el.find('.c-show-hide').attr('data-show', 'second');
          _this.updateTrainerInfo();
          return _this.updateExperience();
        };
      })(this));
      return StadiumView.__super__.initialize.call(this, this.options);
    };

    StadiumView.prototype.onBeforeRender = function() {
      if (this.options.selectedSkillId === null && this._dataLoaded && this._data.info) {
        return this.options.selectedSkillId = this._data.info.user.UserSportSkill[0].sport_skill_type_id;
      }
    };


    /*
    			This method triggers then energy is updated
     */

    StadiumView.prototype.updateEnergyField = function(newEnergy) {
      this.invalidateCacheAndReload();
      return this.buttonsEnergyState();
    };

    StadiumView.prototype.setMaxButton = function() {
      var btn, btnEnergyValue, buttons, i, len, maxValue, results, valuesArr;
      buttons = this.el.querySelectorAll('.c-btn-group--energy .c-btn-group__button');
      valuesArr = this.buttonsEnergyState();
      maxValue = Math.max.apply(this, valuesArr);
      results = [];
      for (i = 0, len = buttons.length; i < len; i++) {
        btn = buttons[i];
        btnEnergyValue = parseInt(btn.querySelector('.js-energy-value').innerHTML);
        if (btnEnergyValue === maxValue) {
          $(btn).addClass('c-btn-group__button--active');
          results.push(this.options.activeEnergy = maxValue);
        } else {
          results.push($(btn).removeClass('c-btn-group__button--active'));
        }
      }
      return results;
    };


    /*
    			Set state for energy buttons depends on energy value
     */

    StadiumView.prototype.buttonsEnergyState = function() {
      var btn, btnEnergyValue, buttons, experienceEl, i, len, redZone, ref, valuesArr;
      if (((ref = this._data) != null ? ref.info : void 0) != null) {
        buttons = this.el.querySelectorAll('.c-btn-group--energy .c-btn-group__button');
        redZone = parseInt(this._data.info.user.User.energy);
        experienceEl = this.el.querySelector('.js-experience-value');
        valuesArr = [];
        this.maxValue = 0;
        for (i = 0, len = buttons.length; i < len; i++) {
          btn = buttons[i];
          btnEnergyValue = parseInt(btn.querySelector('.js-energy-value').innerHTML);
          if (btnEnergyValue > redZone) {
            $(btn).addClass('c-btn-group__button--disabled');
          } else {
            $(btn).removeClass('c-btn-group__button--disabled');
            valuesArr.push(btnEnergyValue);
            if (btnEnergyValue > this.maxValue) {
              this.maxValue = btnEnergyValue;
            }
          }
        }
        return valuesArr;
      }
    };

    StadiumView.prototype.selectSkill = function(event) {
      this.skillId = event.currentTarget.getAttribute('data-skill-id');
      this.options.selectedSkillId = this.skillId;
      return [].slice.call(this.el.querySelectorAll('.js-select-skill')).forEach(function(el) {
        if (el === event.currentTarget) {
          return $(el).addClass('c-panel__col--tab-active');
        } else {
          return $(el).removeClass('c-panel__col--tab-active');
        }
      });
    };

    StadiumView.prototype.gotoChooseTrainer = function(event) {
      this.lockUI();
      return this.app.screens.dialog('stadium/trainers-coefficients');
    };

    StadiumView.prototype.deleteTrainer = function(event) {
      this.programId = void 0;
      this.$el.find('.c-show-hide').attr('data-show', 'first');
      return this.reload();
    };

    StadiumView.prototype.train = function(event) {
      var basic_practice_energy, energy, loader, options;
      this.lockUI();
      this.skillId = this.skillId || this.$('.c-panel__col--tab-active').attr('data-skill-id');
      energy = parseInt(this.$el.find('.c-btn-group--energy .c-btn-group__button--active .js-energy-value').text());
      if ((this.maxValue != null) && this.maxValue < energy) {
        energy = this.maxValue;
        this.setMaxButton();
      }
      this.options.activeEnergy = energy;
      if (isNaN(energy)) {
        app.screens.modal('common/info-popup', {
          msg: app.tr("Not enough energy")
        });
        return;
      }
      options = {
        repeat: {
          method: this.train,
          context: this,
          event: event
        }
      };
      loader = this.setLoaderOnElement('.js-train', app.tr('Training'));
      if (this.programId != null) {
        basic_practice_energy = this._data.info.basic_practice_energy;
        return this.app.server.stadium.trainWithTrainer({
          skillId: this.skillId,
          licenseId: this.licenseId,
          programId: this.programId,
          energy: energy,
          success: (function(_this) {
            return function(data) {
              _this.listenToOnce(app.vent, 'short-info:dataLoaded', function() {
                loader.remove();
                app.vent.trigger('stadium:trained', {
                  injured: false
                });
                return app.screens.modal('stadium/training-popup', options);
              });
              if (app.gaEnabled) {
                app.ga('send', 'event', 'training_coaching', energy, _this.skillId, (energy * _this.price / basic_practice_energy).toFixed(2));
              }
              return options.data = data;
            };
          })(this),
          error: function(data) {
            loader.remove();
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          }
        });
      } else {
        return this.app.server.stadium.train({
          skillId: this.skillId,
          energy: energy,
          success: (function(_this) {
            return function(data) {
              loader.remove();
              if (app.gaEnabled) {
                app.ga('send', 'event', 'training', _this.skillId, Number(energy));
              }
              options.data = data;
              if (data.traumasEffect > 0) {
                app.screens.modal('stadium/injury-short-popup', {
                  data: data
                });
              }
              app.vent.trigger('stadium:trained', {
                injured: data.traumasEffect > 0
              });
              return app.screens.modal('stadium/training-popup', options);
            };
          })(this),
          error: function(data) {
            loader.remove();
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          }
        });
      }
    };


    /*
    			Center cloud
     */

    StadiumView.prototype.centerCloud = function() {
      var height;
      if ($('.c-cloud').length > 0) {
        height = $('.js-current-screen').outerHeight() - $('.c-header-wrapper').outerHeight() - $('.c-cloud').outerHeight();
        return $('.c-cloud').css('margin-top', height / 2);
      }
    };

    StadiumView.prototype.onDomRefresh = function() {
      this.centerCloud();
      this.buttonsEnergyState();
      if (this.programId) {
        this.el.querySelector('.c-show-hide').setAttribute('data-show', 'second');
        this.updateTrainerInfo();
        return this.updateExperience();
      }
    };

    StadiumView.prototype.changeEnergy = function(event) {
      var activeStateClass, btn, buttons, disabledStateClass, el, i, len;
      btn = event.currentTarget;
      buttons = btn.parentNode.querySelectorAll('.c-btn-group__button');
      activeStateClass = 'c-btn-group__button--active';
      disabledStateClass = 'c-btn-group__button--disabled';
      if (!$(btn).hasClass(disabledStateClass)) {
        for (i = 0, len = buttons.length; i < len; i++) {
          el = buttons[i];
          if (el.classList) {
            el.classList.remove(activeStateClass);
          } else {
            el.activeStateClass = el.activeStateClass.replace(new RegExp('(^|\\b)' + activeStateClass.split(' ').join('|') + '(\\b|$)', 'gi'), ' ');
          }
        }
        if (btn.classList) {
          btn.classList.add(activeStateClass);
        } else {
          btn.activeStateClass += ' ' + activeStateClass;
        }
        this.updateExperience();
        return this.updateTrainerInfo();
      }
    };

    StadiumView.prototype.updateExperience = function() {
      var energyValue;
      this.experienceValueEl = this.el.querySelector('.js-experience-value');
      energyValue = parseInt(this.$el.find('.c-btn-group--energy .c-btn-group__button--active .js-energy-value').text());
      if (isNaN(energyValue)) {
        energyValue = 0;
      }
      if (this.programId != null) {
        return this.experienceValueEl.innerHTML = Math.round(energyValue * this.coefficient);
      } else {
        return this.experienceValueEl.innerHTML = energyValue;
      }
    };

    StadiumView.prototype.updateTrainerInfo = function() {
      var $currencyEl, energyValue;
      if (this.programId != null) {
        energyValue = parseFloat(this.$('.c-btn-group--energy .c-btn-group__button--active .js-energy-value').text());
        if (isNaN(energyValue)) {
          energyValue = 0;
        }
        this.$('.js-price').html((energyValue * this.price / this._data.info.basic_practice_energy).toFixed(2));
        this.$('.js-coefficient').html(this.coefficient);
        $currencyEl = $(this.el.querySelector('.js-currency'));
        if (this.currency === 'vg') {
          $currencyEl.removeClass('o-icon--vdollar');
          return $currencyEl.addClass('o-icon--vgold');
        } else {
          $currencyEl.addClass('o-icon--vdollar');
          return $currencyEl.removeClass('o-icon--vgold');
        }
      }
    };

    return StadiumView;

  })(ItemView);
  return StadiumView;
});
