var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/suggestions/suggestion.tmpl', 'moment'], function(app, ItemView, _, template, moment) {
  var SuggestionView;
  SuggestionView = (function(superClass) {
    extend(SuggestionView, superClass);

    function SuggestionView() {
      this._triggerKeyboardHide = bind(this._triggerKeyboardHide, this);
      this._triggerKeyboardShow = bind(this._triggerKeyboardShow, this);
      this.initialize = bind(this.initialize, this);
      return SuggestionView.__super__.constructor.apply(this, arguments);
    }

    SuggestionView.prototype.template = template;

    SuggestionView.prototype.data = {
      post: {
        pointer: 'suggestions.post',
        suggestionId: function() {
          return this.options.suggestionId;
        }
      },
      cities: 'cities'
    };

    SuggestionView.prototype.events = {
      'click .js-add-like': 'addLike',
      'click .js-add-dislike': 'addDisLike',
      'click .js-add-comment': 'sendComment',
      'click .js-edit': 'editComment'
    };

    SuggestionView.prototype.initialize = function(options) {
      this.options = options;
      SuggestionView.__super__.initialize.call(this, this.options);
      this.listenTo(app, "keyboard:show", this._triggerKeyboardShow);
      return this.listenTo(app, "keyboard:hide", this._triggerKeyboardHide);
    };

    SuggestionView.prototype._triggerKeyboardShow = function(keyboardHeight) {
      return this.$('.c-footer').css("bottom", keyboardHeight);
    };

    SuggestionView.prototype._triggerKeyboardHide = function() {
      return this.$('.c-footer').css("bottom", 0);
    };

    SuggestionView.prototype.addLike = function(event) {
      var suggestionId;
      this.lockUI();
      suggestionId = this.options.suggestionId;
      if (!$(event.currentTarget).hasClass('c-round-btn--green')) {
        return app.server.suggestions.addLike({
          suggestionId: this.options.suggestionId,
          success: (function(_this) {
            return function(data) {
              if (app.gaEnabled) {
                app.ga('send', 'event', "suggestion:yes", app.userId, suggestionId);
              }
            };
          })(this),
          error: function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          }
        });
      }
    };

    SuggestionView.prototype.addDisLike = function(event) {
      var suggestionId;
      this.lockUI();
      suggestionId = this.options.suggestionId;
      return app.server.suggestions.addDislike({
        suggestionId: this.options.suggestionId,
        success: (function(_this) {
          return function(data) {
            if (app.gaEnabled) {
              app.ga('send', 'event', "suggestion:no", app.userId, suggestionId);
            }
          };
        })(this),
        error: function(data) {
          return app.screens.modal('common/info-popup', {
            msg: data.setFlash[0].msg || app.tr("Something went wrong")
          });
        }
      });
    };

    SuggestionView.prototype.sendComment = function(event) {
      var commentText, suggestionId;
      this.lockUI();
      commentText = this.$el.find('.js-text-comment').val();
      if (commentText === "") {
        return app.screens.modal('common/info-popup', {
          msg: app.tr("Comment cannot be empty")
        });
      } else {
        suggestionId = this.options.suggestionId;
        return app.server.suggestions.addComment({
          suggestionId: this.options.suggestionId,
          message: commentText,
          success: (function(_this) {
            return function(data) {
              if (app.gaEnabled) {
                app.ga('send', 'event', "suggestion:comment", app.userId, suggestionId);
              }
              return _this.reload();
            };
          })(this),
          error: function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Something went wrong")
            });
          }
        });
      }
    };

    SuggestionView.prototype.editComment = function(event) {
      var commentId;
      commentId = event.currentTarget.getAttribute('data-comment-id');
      return app.screens.dialog('suggestions/edit-comment', {
        commentId: commentId,
        callback: (function(_this) {
          return function() {
            return _this.reload();
          };
        })(this)
      });
    };

    return SuggestionView;

  })(ItemView);
  return SuggestionView;
});
