var extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

define(['app', 'views/item-view', 'underscore', 'text!templates/trade-center/lot-settings.tmpl', 'views/common/precision-check'], function(app, ItemView, _, template, precisionCheck) {
  var LotSettingsView;
  LotSettingsView = (function(superClass) {
    extend(LotSettingsView, superClass);

    function LotSettingsView() {
      return LotSettingsView.__super__.constructor.apply(this, arguments);
    }

    LotSettingsView.prototype.template = template;

    LotSettingsView.prototype.events = {
      'click .o-switcher': 'changeCurrency',
      'click .js-change-lot': 'changeLot',
      'keyup .js-items-amount': 'calcCommission',
      'keyup .js-items-price': 'calcCommission'
    };

    LotSettingsView.prototype.initialize = function(options) {
      options.payedCommision = parseFloat(this.options.model.get('number') * this.options.model.get('price') * this.options.commission / 100);
      options.payedCommisionCurrency = this.options.model.get('currency');
      return LotSettingsView.__super__.initialize.call(this, options);
    };

    LotSettingsView.prototype.changeCurrency = function(event) {
      var currency;
      $(event.currentTarget).toggleClass('o-switcher--active');
      currency = this.$el.find('.o-switcher').hasClass('o-switcher--active') ? 'vgold' : 'vdollars';
      if (currency === 'vdollars') {
        this.$el.find('.js-commission-currency').addClass('o-icon--vdollar');
        this.$el.find('.js-commission-currency').removeClass('o-icon--vgold');
      }
      if (currency === 'vgold') {
        this.$el.find('.js-commission-currency').addClass('o-icon--vgold');
        this.$el.find('.js-commission-currency').removeClass('o-icon--vdollar');
      }
      return this.calcCommission();
    };

    LotSettingsView.prototype.changeLot = function(event) {
      var appServerQuery, currency, exchangeId, price;
      this.lockUI();
      exchangeId = this._data.model['id'];
      price = parseFloat(this.$('.js-items-price').val());
      currency = this.$el.find('.o-switcher').hasClass('o-switcher--active') ? 'vgold' : 'vdollars';
      if (precisionCheck(price)) {
        if (this.options.companyId != null) {
          appServerQuery = app.server.tradeCenter.editCompanyLot;
        } else {
          appServerQuery = app.server.tradeCenter.editLot;
        }
        return appServerQuery({
          exchangeId: exchangeId,
          price: price,
          currency: currency,
          companyId: this.options.companyId != null ? this.options.companyId : null,
          success: function(data) {
            return app.screens.modal('common/info-popup', {
              msg: data.setFlash[0].msg || app.tr("Lot edited")
            }, app.screens.back());
          },
          error: (function(_this) {
            return function(data) {
              var options;
              options = {
                msg: data.setFlash[0].msg || app.tr("Something went wrong")
              };
              return app.screens.modal('common/info-popup', options);
            };
          })(this)
        });
      }
    };

    LotSettingsView.prototype.onRender = function() {
      return this.calcCommission();
    };

    LotSettingsView.prototype.calcCommission = function() {
      var commissionPercent, commissionValue, currency, formattedCommissionValue, itemsCount, pricePerItem;
      itemsCount = this.options.model.get('number');
      pricePerItem = parseFloat(this.$el.find('.js-items-price').val());
      currency = this.$el.find('.o-switcher').hasClass('o-switcher--active') ? 'vgold' : 'vdollars';
      commissionPercent = this.options.commission;
      if (isNaN(pricePerItem)) {
        pricePerItem = 0;
        this.$el.find('.js-items-price').val('');
      }
      commissionValue = parseFloat(itemsCount * pricePerItem * commissionPercent / 100);
      if (currency === this.options.payedCommisionCurrency) {
        if (commissionValue > this.options.payedCommision) {
          commissionValue = commissionValue - this.options.payedCommision;
        } else {
          commissionValue = 0;
        }
      }
      formattedCommissionValue = this.templateHelpers().formatNumber(commissionValue);
      return this.$el.find('.js-commission').html(formattedCommissionValue);
    };

    return LotSettingsView;

  })(ItemView);
  return LotSettingsView;
});
