define(['app', 'views/item-view', 'underscore', 'text!templates/users/profile.tmpl'], function(app, ItemView, _, template) {
  return ItemView.extend({
    template: template,
    events: {
      'click .js-goto-conversation': 'gotoConversation',
      'click .js-add-friend': 'onFriendAdd'
    },
    data: {
      info: {
        pointer: 'user.profile',
        userId: function() {
          return this.options.userId;
        }
      },
      equippedItems: {
        pointer: 'user.profile.equippedItems',
        userId: function() {
          return this.options.userId;
        }
      }
    },
    preprocessData: function(data) {
      var equippedItemsBySlot;
      equippedItemsBySlot = {};
      data.unequippedItems = [];
      if (data.equippedItems.items.length !== 0) {
        data.equippedItems.items.forEach(function(item) {
          return equippedItemsBySlot[item.UserItem.equipped_slot] = item;
        });
      }
      data.equippedItems = equippedItemsBySlot;
      return data;
    },
    gotoConversation: function(event) {
      return app.screens.dialog('messages/conversations', {
        userId: this.options.userId
      });
    },
    onFriendAdd: function(event) {
      var friendId, self;
      event.stopPropagation();
      self = this;
      friendId = event.currentTarget.getAttribute('data-id');
      return app.server.friends.add_request({
        friendId: friendId,
        success: function(data) {
          var ref;
          if (!data.error) {
            app.vent.trigger('friends:friendship_requested', {
              user: self._data.info.user
            });
            event.currentTarget.parentNode.removeChild(event.currentTarget);
          }
          return app.screens.modal('common/info-popup', {
            msg: (data != null ? (ref = data.setFlash[0]) != null ? ref.msg : void 0 : void 0) || app.tr('Server error')
          });
        }
      });
    }
  });
});
